@@ -23,10 +23,6 @@
 
 #include"bytestream.h"
 
-#ifdef CS_NAMESPACE
-namespace CS_NAMESPACE {
-#endif
-
 class BConsole : public ByteStream
 {
 	Q_OBJECT
@@ -49,8 +45,4 @@ private:
 	Private *d;
 };
 
-#ifdef CS_NAMESPACE
-}
-#endif
-
 #endif
