@@ -23,6 +23,7 @@
 #include "iconwidget.h"
 #include "iconset.h"
 
+#include <qlayout.h>
 #include <qpopupmenu.h>
 #include <qtooltip.h>
 #include <qobjectlist.h>
@@ -71,7 +72,7 @@ public slots:
 
 			QMap<QPopupMenu *, int>::Iterator it = popups.begin();
 			for ( ; it != popups.end(); ++it ) {
-				if ( (int)it.key() == (int)obj ) {
+				if ( it.key() == obj ) {
 					dirty = true;
 					popups.remove( it );
 					break;
@@ -164,7 +165,7 @@ const QString &IconAction::iconName() const
 
 bool IconAction::addTo(QWidget *w)
 {
-	if ( w->inherits("QToolBar") ) {
+	if ( w->inherits("QToolBar") || w->isA("QWidget") ) {
 		QCString bname = name() + QCString("_action_button");
 		IconToolButton *btn = new IconToolButton ( w, bname );
 		d->buttons.append ( btn );
@@ -181,6 +182,10 @@ bool IconAction::addTo(QWidget *w)
 
 		QToolTip::add (btn, toolTipFromMenuText());
 
+		if ( w->isA("QWidget") )
+			if ( w->layout() )
+				w->layout()->add( btn );
+
 		connect(btn, SIGNAL(clicked()), this, SIGNAL(activated()));
 		connect(btn, SIGNAL(toggled(bool)), this, SLOT(setOn(bool)));
 
