@@ -526,10 +526,9 @@ public:
 			connect(icon, SIGNAL(pixmapChanged(const QPixmap &)), SLOT(iconUpdated(const QPixmap &)));
 			if ( activate )
 				icon->activated(true); // FIXME: should icon play sound when it's activated on button?
-			iconUpdated( icon->pixmap() );
 		}
-		else
-			iconUpdated( QPixmap() );
+
+		updateIcon();
 #endif
 	}
 
@@ -555,11 +554,21 @@ public:
 #endif
 	}
 
+	void updateIcon()
+	{
+#ifndef WIDGET_PLUGIN
+		if ( icon )
+			iconUpdated( icon->pixmap() );
+		else
+			iconUpdated( QPixmap() );
+#endif
+	}
+
 public slots:
 	void iconUpdated(const QPixmap &pix)
 	{
 		button->setUpdatesEnabled(FALSE);
-		if ( textVisible )
+		if ( textVisible || button->text().isEmpty() )
 			button->setIconSet(pix);
 		else
 			button->setPixmap(pix);
@@ -638,6 +647,7 @@ void IconButton::setText(const QString &text)
 #endif
 
 	QPushButton::setText( text );
+	d->updateIcon();
 }
 
 bool IconButton::textVisible() const
@@ -648,7 +658,7 @@ bool IconButton::textVisible() const
 void IconButton::setTextVisible(bool v)
 {
 	d->textVisible = v;
-	d->update();
+	d->updateIcon();
 }
 
 void IconButton::drawButtonLabel(QPainter *p)
