@@ -312,7 +312,7 @@ public:
 	{
 		const UserAccount &acc = pa->userAccount();
 		setText(0, pa->name());
-		setPixmap(0, IconsetFactory::icon("psi/account"));
+		//setPixmap(0, IconsetFactory::icon("psi/account"));
 		Jid j = acc.jid;
 		setText(1, acc.opt_host ? acc.host : j.host());
 		setText(2, pa->isActive() ? AccountManageDlg::tr("Active") : AccountManageDlg::tr("Not active"));
@@ -321,26 +321,9 @@ public:
 
 	void stateChange( bool s)
 	{
-		if (!s) {
-			if (pa->eventQueue()->count()) {
-				setOn(!s);
-				QMessageBox::information(listView(), AccountManageDlg::tr("Error"), AccountManageDlg::tr("Unable to disable the account, as it has pending events."));
-				return;
-			}
-
-			if (pa->isActive()) {
-				if (QMessageBox::information(listView(), AccountManageDlg::tr("Disable Account"), AccountManageDlg::tr("The account is currently active.\nDo you want to log out ?"),QMessageBox::Yes,QMessageBox::No | QMessageBox::Default | QMessageBox::Escape, QMessageBox::NoButton) == QMessageBox::Yes) {
-					pa->logout();
-				}
-				else {
-					setOn(!s);
-					return;
-				}
-			}
-		}
-
 		if (pa->enabled()!=s)
 			pa->setEnabled(s);
+		updateInfo();
 	}
 
 	int rtti() const
@@ -593,19 +576,16 @@ AccountModifyDlg::AccountModifyDlg(PsiAccount *_pa, QWidget *parent, const char
 	const UserAccount &acc = pa->userAccount();
 
 	connect(pb_close, SIGNAL(clicked()), SLOT(reject()));
-	connect(ck_pass, SIGNAL(toggled(bool)), le_pass, SLOT(setEnabled(bool)));
 	connect(ck_host, SIGNAL(toggled(bool)), SLOT(hostToggled(bool)));
 	connect(pb_key, SIGNAL(clicked()), SLOT(chooseKey()));
 	connect(pb_keyclear, SIGNAL(clicked()), SLOT(clearKey()));
 	connect(pb_save, SIGNAL(clicked()), SLOT(save()));
 
-	le_pass->setEnabled(false);
+	le_pass->setEnabled(true);
 	le_host->setEnabled(false);
 	le_port->setEnabled(false);
 
 	gb_pgp->setEnabled(false);
-	connect(ck_pp, SIGNAL(toggled(bool)), SLOT(optpp_toggled(bool)));
-	le_pp->setEnabled(false);
 
 	connect(pb_vcard, SIGNAL(clicked()), SLOT(detailsVCard()));
 	connect(pb_changepw, SIGNAL(clicked()), SLOT(detailsChangePW()));
@@ -616,10 +596,8 @@ AccountModifyDlg::AccountModifyDlg(PsiAccount *_pa, QWidget *parent, const char
 	ck_ssl->setChecked(acc.opt_ssl);
 	connect(ck_ssl, SIGNAL(toggled(bool)), SLOT(sslToggled(bool)));
 
-	if(acc.opt_pass) {
-		ck_pass->setChecked(true);
+	if (acc.opt_pass)
 		le_pass->setText(acc.pass);
-	}
 
 	ck_host->setChecked(acc.opt_host);
 	le_host->setText(acc.host);
@@ -640,15 +618,10 @@ AccountModifyDlg::AccountModifyDlg(PsiAccount *_pa, QWidget *parent, const char
 	updateUserID();
 	if(pa->psi()->pgp()) {
 		gb_pgp->setEnabled(true);
-		if(acc.opt_passphrase) {
-			ck_pp->setChecked(true);
-			le_pp->setText(acc.pgpPassphrase);
-		}
 	}
 
 	pc = pa->psi()->proxy()->createProxyChooser(gb_proxy);
 	replaceWidget(lb_proxychooser, pc);
-	pc->fixTabbing(le_pp, ck_ssl);
 	pc->setCurrentItem(acc.proxy_index);
 
 	if(le_name->text().isEmpty())
@@ -695,12 +668,6 @@ AccountModifyDlg::AccountModifyDlg(PsiAccount *_pa, QWidget *parent, const char
 		"server supports it and if you have the necessary QSSL "
 		"plugin installed.  For more information, check the "
 		"Psi homepage."));
-	QWhatsThis::add(ck_pass,
-		tr("Check this option if you want Psi to remember your Jabber "
-		"account password. Don't use this feature if you want "
-		"maximum security and don't want to be compromised even "
-		"if someone would break in your system and steal your "
-		"configuration files."));
 	QWhatsThis::add(ck_host,
 		tr("Use this option for manual configuration of your Jabber host "
 		"if it is not the same as the host you are connecting to.  This option is mostly useful "
@@ -764,15 +731,12 @@ void AccountModifyDlg::setKeyID(bool b, const QString &s)
 		lb_keyicon->setEnabled(true);
 		lb_keyname->setEnabled(true);
 		pb_keyclear->setEnabled(true);
-		ck_pp->setEnabled(true);
 	}
 	else {
 		lb_keyname->setText(tr("No Key Selected"));
 		lb_keyicon->setEnabled(false);
 		lb_keyname->setEnabled(false);
 		pb_keyclear->setEnabled(false);
-		ck_pp->setChecked(false);
-		ck_pp->setEnabled(false);
 	}
 }
 
@@ -783,24 +747,14 @@ void AccountModifyDlg::pgpToggled(bool b)
 	}
 	else {
 		gb_pgp->setEnabled(false);
-		ck_pp->setChecked(false);
 	}
 	updateUserID();
 }
 
-void AccountModifyDlg::optpp_toggled(bool b)
-{
-	if(b)
-		le_pp->setEnabled(true);
-	else {
-		le_pp->setEnabled(false);
-		le_pp->setText("");
-	}
-}
-
 void AccountModifyDlg::setPassword(const QString &pw)
 {
-	le_pass->setText(pw);
+	if (!le_pass->text().isEmpty())
+		le_pass->setText(pw);
 }
 
 void AccountModifyDlg::sslToggled(bool on)
@@ -834,7 +788,6 @@ void AccountModifyDlg::chooseKey()
 	if(!key.isEmpty()) {
 		keyID = key;
 		updateUserID();
-		ck_pp->setChecked(false);
 	}
 }
 
@@ -889,11 +842,8 @@ void AccountModifyDlg::save()
 
 	acc.name = le_name->text();
 	acc.jid = le_jid->text();
-	acc.opt_pass = ck_pass->isChecked();
-	if(acc.opt_pass)
-		acc.pass = le_pass->text();
-	else
-		acc.pass = "";
+	acc.pass = le_pass->text();
+	acc.opt_pass = !acc.pass.isEmpty();
 
 	acc.opt_host = ck_host->isChecked();
 	acc.host = le_host->text();
@@ -912,11 +862,6 @@ void AccountModifyDlg::save()
 	acc.dtProxy = le_dtProxy->text();
 
 	acc.pgpSecretKeyID = keyID;
-	acc.opt_passphrase = ck_pp->isChecked();
-	if(acc.opt_passphrase)
-		acc.pgpPassphrase = le_pp->text();
-	else
-		acc.pgpPassphrase = "";
 
 	acc.proxy_index = pc->currentItem();
 
