@@ -42,26 +42,13 @@
 #include"psicon.h"
 #include"psitoolbar.h"
 #include"iconaction.h"
-//#include"avatars.h"
+#include"avatars.h"
+#include"tabdlg.h"
 
 #ifdef Q_WS_WIN
 #include<windows.h>
 #endif
 
-//----------------------------------------------------------------------------
-// Some required actions
-//----------------------------------------------------------------------------
-
-class StretchWidget : public QWidget
-{
-public:
-	StretchWidget(QWidget *parent)
-	: QWidget(parent)
-	{
-		setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
-	}
-};
-
 //----------------------------------------------------------------------------
 // ChatDlg
 //----------------------------------------------------------------------------
@@ -83,8 +70,9 @@ public:
 	ChatView *log;
 	ChatEdit *mle;
 
-	// Avatars
-	//QLabel *avatar;
+#ifdef AVATARS
+	QLabel *avatar;
+#endif 
 
 	QLabel *lb_ident;
 	IconLabel *lb_status;
@@ -92,15 +80,15 @@ public:
 	QLCDNumber *lcd_count;
 	QPopupMenu *pm_settings;
 
+	QLabel *lb_composing;
+
 	PsiToolBar *toolbar;
-	IconAction *act_send, *act_clear, *act_history, *act_info, *act_pgp, *act_icon, *act_file;
+	IconAction *act_send, *act_clear, *act_history, *act_info, *act_pgp, *act_icon, *act_file, *act_compact;
 
 	int pending;
 	bool keepOpen, warnSend;
 
 	QTimer *selfDestruct;
-	QTimer *flashTimer;
-	int flashCount;
 
 	QString key;
 	int transid;
@@ -123,7 +111,7 @@ public slots:
 	void addEmoticon(const Icon *icon) {
 		if ( !dlg->isActiveWindow() )
 		     return;
-
+		
 		QString text;
 
 		QDict<QString> itext = icon->text();
@@ -140,7 +128,7 @@ public slots:
 	}
 
 	void addEmoticon(QString text) {
-		if ( !dlg->isActiveWindow() )
+		if ( !pa->psi()->isChatActiveWindow(dlg) )
 		     return;
 
 		mle->insert( text + " " );
@@ -175,7 +163,6 @@ public slots:
 };
 
 ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
-:QWidget(0, 0)
 {
 	d = new Private(this);
 	d->jid = jid;
@@ -185,7 +172,6 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 	d->keepOpen = false;
 	d->warnSend = false;
 	d->selfDestruct = 0;
-	d->flashTimer = 0;
 	d->transid = -1;
 	d->key = "";
 	d->lastWasEncrypted = false;
@@ -193,12 +179,21 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 	setAcceptDrops(TRUE);
 
 	QVBoxLayout *vb1 = new QVBoxLayout(this, 4);
-	QSplitter *sp = new QSplitter(Vertical, this);
-	vb1->addWidget(sp);
+
+	QWidget *sp;
+	if ( !option.chatLineEdit ) {
+		sp = new QSplitter(Vertical, this);
+		vb1->addWidget(sp);
+	}
+	else
+		sp = this;
 
 	QWidget *sp_top = new QWidget(sp);
+	sp_top->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+	if ( option.chatLineEdit )
+		vb1->addWidget( sp_top );
 	// first row
-	QVBoxLayout *vb2 = new QVBoxLayout(sp_top, 4);
+	QVBoxLayout *vb2 = new QVBoxLayout(sp_top, 0, 4);
 	d->lb_ident = d->pa->accountLabel(sp_top, true);
 	d->lb_ident->setSizePolicy(QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum ));
 
@@ -220,10 +215,14 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 	// mid area
 	d->log = new ChatView(sp_top);
 	vb2->addWidget(d->log);
+#ifdef Q_WS_MAC
+	connect(d->log,SIGNAL(selectionChanged()),SLOT(logSelectionChanged()));
+#endif
 
 	QWidget *sp_bottom = new QWidget(sp);
+	sp_bottom->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Maximum );
 	// tool area
-	QVBoxLayout *vb3 = new QVBoxLayout(sp_bottom, 4);
+	QVBoxLayout *vb3 = new QVBoxLayout(sp_bottom);
 	QHBoxLayout *hb3 = new QHBoxLayout(vb3);
 
 	d->toolbar = new PsiToolBar(tr("Chat toolbar"), 0, sp_bottom);
@@ -243,11 +242,14 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 
 	d->act_pgp = new IconAction( tr( "Toggle encryption" ), "psi/cryptoNo", tr( "Toggle encryption" ), 0, this, 0, true );
 
-	d->act_info = new IconAction( tr( "User info" ), "psi/vCard", tr( "User info" ), 0, this );
+	d->act_info = new IconAction( tr( "User info" ), "psi/vCard", tr( "User info" ), CTRL+Key_I, this );
 	connect( d->act_info, SIGNAL( activated() ), SLOT( doInfo() ) );
 
-	d->act_history = new IconAction( tr( "Message history" ), "psi/history", tr( "Message history" ), 0, this );
+	d->act_history = new IconAction( tr( "Message history" ), "psi/history", tr( "Message history" ), CTRL+Key_H, this );
 	connect( d->act_history, SIGNAL( activated() ), SLOT( doHistory() ) );
+	
+	d->act_compact = new IconAction( tr( "Toggle Compact/Full size" ), "psi/compact", tr( "Toggle Compact/Full size" ), 0, this );
+	connect( d->act_compact, SIGNAL( activated() ), SLOT( toggleSmallChat() ) );
 
 	d->act_clear->addTo( d->toolbar );
 	d->toolbar->setStretchableWidget(new StretchWidget(d->toolbar));
@@ -258,30 +260,55 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 	d->act_info->addTo( d->toolbar );
 	d->act_history->addTo( d->toolbar );
 
+	// Bottom but one row (composing notification)
+	QHBoxLayout *hb_comp = new QHBoxLayout(vb3);
+	d->lb_composing = new QLabel(sp_bottom,"composing");
+	d->lb_composing->setPaletteBackgroundColor(Qt::yellow.light(190));
+	hb_comp->addWidget(d->lb_composing);
+	d->lb_composing->hide();
+
 	// Bottom row
 	QHBoxLayout *hb4 = new QHBoxLayout(vb3);
 
 	// Text input
-	d->mle = new ChatEdit(sp_bottom);
-	hb4->addWidget(d->mle);
+	if ( !option.chatLineEdit ) {
+		d->mle = new ChatEdit(sp_bottom);
+		hb4->addWidget(d->mle);
+	}
+	else {
+		vb1->addWidget( sp_bottom );
+		QHBoxLayout *hb5 = new QHBoxLayout( vb1 );
+		d->mle = new LineEdit(sp);
+#ifdef Q_WS_MAC
+		hb5->addSpacing( 16 );
+#endif
+		hb5->addWidget( d->mle );
+#ifdef Q_WS_MAC
+		hb5->addSpacing( 16 );
+#endif
+	}
+
 	connect(d->mle, SIGNAL(textChanged()), d, SLOT(updateCounter()));
 
 	// Avatars
-	//d->avatar = new QLabel(sp_bottom);
-	//hb4->addWidget(d->avatar);
-	//updateAvatar();
+#ifdef AVATARS
+	d->avatar = new QLabel(sp_bottom);
+	hb4->addWidget(d->avatar);
+	updateAvatar();
 	// FIXME: Maybe the psiaccount should do this, to avoid a signal to each
 	// open window when an avatar changes.
-	//connect(d->pa->avatarFactory(),SIGNAL(avatarChanged(const Jid&)), this, SLOT(updateAvatar(const Jid&)));
-	//connect(d->pa->psi(),SIGNAL(emitOptionsUpdate()), this, SLOT(updateAvatar()));
-
-	d->pm_settings=new QPopupMenu(this);
+	connect(d->pa->avatarFactory(),SIGNAL(avatarChanged(const Jid&)), this, SLOT(updateAvatar(const Jid&)));
+	connect(d->pa->psi(),SIGNAL(emitOptionsUpdate()), this, SLOT(updateAvatar()));
+#endif
 
+	d->pm_settings = new QPopupMenu(this);
 	connect(d->pm_settings, SIGNAL(aboutToShow()), SLOT(buildMenu()));
+
 	QValueList<int> list;
 	list << 324;
 	list << 96;
-	sp->setSizes(list);
+	if ( !option.chatLineEdit )
+		((QSplitter *)sp)->setSizes(list);
 
 	d->status = -1;
 	d->pa->dialogRegister(this, d->jid);
@@ -296,7 +323,7 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 
 	updateContact(d->jid, true);
 
-	d->smallChat=option.smallChats;
+	d->smallChat = option.smallChats;
 	X11WM_CLASS("chat");
 	setLooks();
 
@@ -306,6 +333,8 @@ ChatDlg::ChatDlg(const Jid &jid, PsiAccount *pa)
 #ifdef Q_WS_X11
 	d->le_jid->setFocusPolicy(QWidget::NoFocus);
 	d->log->setFocusPolicy(QWidget::NoFocus);
+#elif defined(Q_WS_MAC)
+	d->log->setFocusPolicy(QWidget::NoFocus);
 #endif
 	d->mle->setFocus();
 	resize(option.sizeChatDlg);
@@ -324,21 +353,19 @@ ChatDlg::~ChatDlg()
 
 void ChatDlg::contextMenuEvent(QContextMenuEvent *)
 {
-	        d->pm_settings->exec(QCursor::pos());
+	d->pm_settings->exec(QCursor::pos());
 }
 
 void ChatDlg::keyPressEvent(QKeyEvent *e)
 {
-	if(e->key() == Key_Escape)
+	if(e->key() == Key_Escape && !option.useTabs)
 		close();
-#ifdef Q_WS_MAC
-	else if(e->key() == Key_W && e->state() & ControlButton)
+//#ifdef Q_WS_MAC //this is a standard on other platforms too
+	else if(e->key() == Key_W && e->state() & ControlButton && !option.useTabs)
 		close();
-#endif
+//#endif
 	else if(e->key() == Key_Return || e->key() == Key_Enter || (e->key() == Key_S && (e->state() & AltButton)))
 		doSend();
-	else if(e->key() == Key_H && (e->state() & ControlButton))
-		doHistory();
 	else if(e->key() == Key_PageUp && (e->state() & ShiftButton))
 		d->log->setContentsPos(d->log->contentsX(), d->log->contentsY() - d->log->visibleHeight()/2);
 	else if(e->key() == Key_PageDown && (e->state() & ShiftButton))
@@ -406,23 +433,39 @@ void ChatDlg::windowActivationChange(bool oldstate)
 	QWidget::windowActivationChange(oldstate);
 
 	// if we're bringing it to the front, get rid of the '*' if necessary
-	if(isActiveWindow()) {
-		if(d->pending > 0) {
-			d->pending = 0;
-			messagesRead(d->jid);
-			updateCaption();
-		}
-		doFlash(false);
-
-		if(option.showCounter && !d->smallChat)
-			d->lcd_count->show();
-		else
-			d->lcd_count->hide();
-
-		d->mle->setFocus();
+	if( isActiveWindow() && !isHidden() ) { //this is a tab hack
+		activated();
 	}
 }
 
+void ChatDlg::logSelectionChanged()
+{
+#ifdef Q_WS_MAC
+	// A hack to only give the message log focus when text is selected
+	if (d->log->hasSelectedText()) 
+		d->log->setFocus();
+	else 
+		d->mle->setFocus();
+#endif
+}
+
+void ChatDlg::activated()
+{
+	if(d->pending > 0) {
+		d->pending = 0;
+		messagesRead(d->jid);
+		updateCaption();
+	}
+	doFlash(false);
+
+	if(option.showCounter && !d->smallChat)
+		d->lcd_count->show();
+	else
+		d->lcd_count->hide();
+
+	d->mle->setFocus();
+}
+
 
 void ChatDlg::dropEvent(QDropEvent* event)
 {
@@ -453,9 +496,14 @@ void ChatDlg::setJid(const Jid &jid)
 	}
 }
 
+const QString& ChatDlg::getDisplayNick()
+{
+	return d->dispNick;
+}
+
 QSize ChatDlg::defaultSize()
 {
-	return QSize(380, 420);
+	return QSize(320, 280);
 }
 
 void ChatDlg::updateContact(const Jid &jid, bool fromPresence)
@@ -562,41 +610,42 @@ void ChatDlg::updateContact(const Jid &jid, bool fromPresence)
 }
 
 
-// Avatars
-//void ChatDlg::updateAvatar(const Jid& j)
-//{
-//	if (j.compare(d->jid,false))
-//		updateAvatar();
-//}
+void ChatDlg::updateAvatar(const Jid& j)
+{
+	if (j.compare(d->jid,false))
+		updateAvatar();
+}
 
-//void ChatDlg::updateAvatar()
-//{
-//	QString res;
-//	QString client;
+void ChatDlg::updateAvatar()
+{
+#ifdef AVATARS
+	QString res;
+	QString client;
 
-//	if (!option.avatarsEnabled || !option.avatarsChatdlgEnabled) {
-//		d->avatar->hide();
-//		return;
-//	}
-//
-//	UserListItem *ul = d->pa->findFirstRelavent(d->jid);
-//	if (ul && !ul->userResourceList().isEmpty()) {
-//		UserResourceList::Iterator it = ul->userResourceList().find(d->jid.resource());
-//		if(it == ul->userResourceList().end())
-//			it = ul->userResourceList().priority();
-//
-//		res = (*it).name();
-//		client = (*it).clientName();
-//	}
-//	QPixmap p = d->pa->avatarFactory()->getAvatar(d->jid.withResource(res),client);
-//	if (p.isNull()) {
-//		d->avatar->hide();
-//	}
-//	else {
-//		d->avatar->setPixmap(p);
-//		d->avatar->show();
-//	}
-//}
+	if (option.chatLineEdit || !option.avatarsEnabled || !option.avatarsChatdlgEnabled) {
+		d->avatar->hide();
+		return;
+	}
+
+	UserListItem *ul = d->pa->findFirstRelavent(d->jid);
+	if (ul && !ul->userResourceList().isEmpty()) {
+		UserResourceList::Iterator it = ul->userResourceList().find(d->jid.resource());
+		if(it == ul->userResourceList().end())
+			it = ul->userResourceList().priority();
+
+		res = (*it).name();
+		client = (*it).clientName();
+	}
+	QPixmap p = d->pa->avatarFactory()->getAvatar(d->jid.withResource(res),client);
+	if (p.isNull()) {
+		d->avatar->hide();
+	}
+	else {
+		d->avatar->setPixmap(p);
+		d->avatar->show();
+	}
+#endif
+}
 
 
 void ChatDlg::setLooks()
@@ -638,7 +687,16 @@ void ChatDlg::setLooks()
 
 	// update the widget icon
 #ifndef Q_WS_MAC
-	setIcon(IconsetFactory::icon("psi/chat"));
+	setIcon(IconsetFactory::icon("psi/start-chat"));
+#endif
+
+	/*QBrush brush;
+	brush.setPixmap( QPixmap( option.chatBgImage ) );
+	d->log->setPaper(brush);
+	d->log->setStaticBackground(true);*/
+
+#if QT_VERSION >= 0x030300
+	setWindowOpacity(double(option.chatOpacity)/100);
 #endif
 }
 
@@ -648,7 +706,7 @@ void ChatDlg::optionsUpdate()
 	{
 		d->smallChat=option.smallChats;
 	}
-	
+
 	setLooks();
 
 	if(isHidden()) {
@@ -747,56 +805,10 @@ void ChatDlg::updateCaption()
 	if (d->contactIsComposing)
 		cap = tr("%1 (Composing ...)").arg(cap);
 
-	// if taskbar flash, then we need to erase first and redo
-#ifdef Q_WS_WIN
-	bool on = false;
-	if(d->flashTimer)
-		on = d->flashCount & 1;
-	if(on)
-		FlashWindow(winId(), true);
-#endif
 	setCaption(cap);
-#ifdef Q_WS_WIN
-	if(on)
-		FlashWindow(winId(), true);
-#endif
-}
 
-#ifdef Q_WS_WIN
-void ChatDlg::doFlash(bool yes)
-{
-	if(yes) {
-		if(d->flashTimer)
-			return;
-		d->flashTimer = new QTimer(this);
-		connect(d->flashTimer, SIGNAL(timeout()), SLOT(flashAnimate()));
-		d->flashCount = 0;
-		flashAnimate(); // kick the first one immediately
-		d->flashTimer->start(500);
-	}
-	else {
-		if(d->flashTimer) {
-			delete d->flashTimer;
-			d->flashTimer = 0;
-			// comment this out to fix titlebar repaint on Windows??
-			//FlashWindow(winId(), false);
-		}
-	}
-}
-#else
-void ChatDlg::doFlash(bool)
-{
-}
-#endif
-
-void ChatDlg::flashAnimate()
-{
-#ifdef Q_WS_WIN
-	FlashWindow(winId(), true);
-	++d->flashCount;
-	if(d->flashCount == 5)
-		d->flashTimer->stop();
-#endif
+	emit captionChanged(this);
+	emit unreadMessageUpdate(this, d->pending);
 }
 
 void ChatDlg::doSend()
@@ -1017,7 +1029,7 @@ void ChatDlg::appendMessage(const Message &m, bool local)
 		deferredScroll();
 
 	// if we're not active, notify the user by changing the title
-	if(!isActiveWindow()) {
+	if(!isActiveWindow() || isHidden()) { //isHidden==tab hack
 		++d->pending;
 		updateCaption();
 		doFlash(true);
@@ -1077,15 +1089,22 @@ void ChatDlg::updateIsComposing(bool c)
 void ChatDlg::updateContactIsComposing(bool c)
 {
 	d->contactIsComposing = c;
+	emit contactIsComposing(this, c);
 	updateCaption();
+	/*if (c)
+	{
+		d->lb_composing->setText(QString(d->dispNick+" "+tr("is composing a reply.")));
+		d->lb_composing->show();
+	}
+	else
+	{
+		d->lb_composing->hide();
+	}*/
 }
 
 void ChatDlg::toggleSmallChat()
 {
-	if (d->smallChat)
-		d->smallChat=false;
-	else
-		d->smallChat=true;
+	d->smallChat = !d->smallChat;
 	setLooks();
 }
 
@@ -1098,8 +1117,7 @@ void ChatDlg::buildMenu()
 {
 	// Dialog menu
 	d->pm_settings->clear();
-	d->pm_settings->insertItem(tr("Toggle Compact/Full Size"), this, SLOT(toggleSmallChat()));
-
+	d->act_compact->addTo( d->pm_settings );
 	d->act_clear->addTo( d->pm_settings );
 	d->pm_settings->insertSeparator();
 
