@@ -26,15 +26,15 @@
 #include"psievent.h"
 
 QString PROG_NAME = "Psi";
-//QString PROG_VERSION = "0.10-CVS" " (" __DATE__ ")"; //CVS Builds are dated
-QString PROG_VERSION = "0.9.3";
+//QString PROG_VERSION = "0.11-dev" " (" __DATE__ ")"; //CVS Builds are dated
+QString PROG_VERSION = "0.10";
 
 #ifdef HAVE_CONFIG
-#include"config.h"
+#include "config.h"
 #endif
 
-#ifndef LIBDIR
-#define LIBDIR "/usr/local/share/psi"
+#ifndef PSI_DATADIR
+#define PSI_DATADIR "/usr/local/share/psi"
 #endif
 
 #include<qregexp.h>
@@ -68,10 +68,10 @@ QString PROG_VERSION = "0.9.3";
 
 QString activeProfile;
 
-QStringList dtcp_hostList;
-int dtcp_port;
-QString dtcp_proxy;
-bool link_test = false;
+//QStringList dtcp_hostList;
+//int dtcp_port;
+//QString dtcp_proxy;
+//bool link_test = false;
 bool use_gpg = true;
 bool no_gpg_agent = false;
 uint psi_dialog_flags = (Qt::WStyle_SysMenu | Qt::WStyle_MinMax);
@@ -749,7 +749,7 @@ Icon category2icon(const QString &category, const QString &type)
 			trans = "msn";
 		else if (type == "yahoo")
 			trans = "yahoo";
-		else if (type == "gadugadu" || type == "x-gadugadu")
+		else if (type == "gadu-gadu" || type == "x-gadugadu")
 			trans = "gadugadu";
 		else if (type == "sms")
 			trans = "sms";
@@ -1137,6 +1137,7 @@ static void getSysInfo()
 		LinuxSuSE,
 		LinuxConectiva,
 		LinuxCaldera,
+		LinuxLFS,
 
 		LinuxASP, // Russian Linux distros
 		LinuxALT,
@@ -1165,6 +1166,7 @@ static void getSysInfo()
 		{ LinuxPLD,		OsUseFile,	"/etc/pld-release",		"PLD Linux"		},
 		{ LinuxAurox,		OsUseName,	"/etc/aurox-release",		"Aurox Linux"		},
 		{ LinuxArch,		OsUseFile,	"/etc/arch-release",		"Arch Linux"		},
+		{ LinuxLFS,		OsAppendFile,	"/etc/lfs-release",		"LFS Linux"		},
 
 		// untested
 		{ LinuxSuSE,		OsUseFile,	"/etc/SuSE-release",		"SuSE Linux"		},
@@ -1204,7 +1206,7 @@ static void getSysInfo()
 		}
 	}
 #elif defined(Q_WS_MAC)
-	os_str = "MacOS X";
+	os_str = "Mac OS X";
 #endif
 
 #if defined(Q_WS_WIN)
@@ -1278,7 +1280,7 @@ QString getTZString()
 #ifdef Q_WS_X11
 QString getResourcesDir()
 {
-	return LIBDIR;
+	return PSI_DATADIR;
 }
 
 QString getHomeDir()
@@ -1451,27 +1453,6 @@ bool fileCopy(const QString &src, const QString &dest)
 	return TRUE;
 }
 
-#ifdef Q_WS_MAC
-static bool isDockTileBouncing = false;
-static NMRec bounceRec;
-
-void stopDockTileBounce()
-{
-	if(isDockTileBouncing) {
-		NMRemove(&bounceRec);
-		isDockTileBouncing = false;
-	}
-}
-
-void bounceDockTile()
-{
-	stopDockTileBounce();
-	bounceRec.qType = nmType;
-	bounceRec.nmMark = 1;
-	NMInstall(&bounceRec);
-	isDockTileBouncing = true;
-}
-#endif
 
 void soundPlay(const QString &str)
 {
