@@ -31,6 +31,8 @@
 #include<qiconset.h>
 #include<qdragobject.h>
 #include<qfiledialog.h>
+#include<qlayout.h>
+#include<stdlib.h>
 #include"im.h"
 #include"common.h"
 #include"userlist.h"
@@ -38,7 +40,7 @@
 #include"psicon.h"
 #include"iconaction.h"
 #include"alerticon.h"
-//#include"avatars.h"
+#include"avatars.h"
 
 //----------------------------------------------------------------------------
 // ContactProfile
@@ -61,8 +63,9 @@ public:
 	Icon anim;
 };
 
-class ContactProfile::Private
+class ContactProfile::Private : public QObject
 {
+	Q_OBJECT
 public:
 	Private() {}
 
@@ -77,6 +80,17 @@ public:
 	QTimer *t;
 	PsiAccount *pa;
 	bool v_enabled;
+
+public slots:
+	/*
+	 * \brief This slot is toggled when number of active accounts is changed
+	 *
+	 * At the moment, it tries to recalculate the roster size.
+	 */
+	void numAccountsChanged()
+	{
+		cv->recalculateSize();
+	}
 };
 
 ContactProfile::ContactProfile(PsiAccount *pa, const QString &name, ContactView *cv, bool unique)
@@ -89,6 +103,7 @@ ContactProfile::ContactProfile(PsiAccount *pa, const QString &name, ContactView
 	d->cv->link(this);
 	d->t = new QTimer;
 	connect(d->t, SIGNAL(timeout()), SLOT(updateGroups()));
+	connect(pa->psi(), SIGNAL(accountCountChanged()), d, SLOT(numAccountsChanged()));
 
 	d->roster.setAutoDelete(true);
 
@@ -386,8 +401,16 @@ ContactViewItem *ContactProfile::addContactItem(Entry *e, ContactViewItem *group
 	return i;
 }
 
+/*
+ * \brief Ensures that specified Entry is present in contactlist
+ *
+ * \param e - Entry with the necessary data about item
+ * \param group_item - ContactViewItem that will be the group for this item
+ */
 ContactViewItem *ContactProfile::ensureContactItem(Entry *e, ContactViewItem *group_item)
 {
+	d->cv->recalculateSize();
+
 	QPtrListIterator<ContactViewItem> it(e->cvi);
 	for(ContactViewItem *i; (i = it.current()); ++it) {
 		ContactViewItem *g = (ContactViewItem *)static_cast<QListViewItem *>(i)->parent();
@@ -397,8 +420,16 @@ ContactViewItem *ContactProfile::ensureContactItem(Entry *e, ContactViewItem *gr
 	return addContactItem(e, group_item);
 }
 
+/*
+ * \brief Removes specified item from ContactView
+ *
+ * \param e - Entry with item's data
+ * \param i - ContactViewItem corresponding to the e
+ */
 void ContactProfile::removeContactItem(Entry *e, ContactViewItem *i)
 {
+	d->cv->recalculateSize();
+
 	ContactViewItem *group_item = (ContactViewItem *)static_cast<QListViewItem *>(i)->parent();
 	//printf("ContactProfile: removing [%s] from group [%s]\n", e->u.jid().full().latin1(), group_item->groupName().latin1());
 	e->cvi.removeRef(i);
@@ -831,20 +862,13 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 		QPopupMenu pm;
 
 		QPopupMenu *am = new QPopupMenu(&pm);
-		am->insertItem(is->transportStatus("transport", STATUS_ONLINE), tr("Online Users"), 5);
+		am->insertItem(IconsetFactory::iconPixmap("psi/disco"), tr("Online Users"), 5);
 		am->insertItem(IconsetFactory::iconPixmap("psi/sendMessage"), tr("Send server message"), 1);
 		am->insertSeparator();
 		am->insertItem(/*IconsetFactory::iconPixmap("psi/edit"),*/ tr("Set MOTD"), 2);
 		am->insertItem(/*IconsetFactory::iconPixmap("psi/edit/clear"),*/ tr("Update MOTD"), 3);
 		am->insertItem(IconsetFactory::iconPixmap("psi/remove"), tr("Delete MOTD"), 4);
 
-		QPopupMenu *bm = new QPopupMenu(&pm);
-		bm->insertItem(is->transportStatus("transport", STATUS_ONLINE), tr("Service &Discovery"), 9);
-		bm->insertSeparator();
-		bm->insertItem(IconsetFactory::iconPixmap("psi/sendMessage"), tr("New &blank message"), 6);
-		bm->insertItem(IconsetFactory::iconPixmap("psi/addContact"), tr("&Add a contact"), 7);
-		bm->insertItem(IconsetFactory::iconPixmap("psi/xml"), tr("&XML Console"), 10);
-
 		const int status_start = 16;
 		QPopupMenu *sm = new QPopupMenu(&pm);
 		sm->insertItem(is->status(STATUS_ONLINE),	status2txt(STATUS_ONLINE),	STATUS_ONLINE		+ status_start);
@@ -860,7 +884,12 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 		pm.insertItem(tr("&Status"), sm);
 
 		pm.insertSeparator();
-		pm.insertItem(tr("A&ctions"), bm);
+		pm.insertItem(IconsetFactory::iconPixmap("psi/addContact"), tr("&Add a contact"), 7);
+		pm.insertItem(IconsetFactory::iconPixmap("psi/disco"), tr("Service &Discovery"), 9);
+		pm.insertItem(IconsetFactory::iconPixmap("psi/sendMessage"), tr("New &blank message"), 6);
+		pm.insertSeparator();
+		pm.insertItem(IconsetFactory::iconPixmap("psi/xml"), tr("&XML Console"), 10);
+		pm.insertSeparator();
 		pm.insertItem(IconsetFactory::iconPixmap("psi/account"), tr("&Modify Account..."), 0);
 		pm.insertSeparator();
 		pm.insertItem(tr("&Admin"), am);
@@ -1010,7 +1039,7 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 		bool isAgent = e ? e->u.isTransport() : false;
 		bool avail = e ? e->u.isAvailable() : false;
 		QString groupNameCache = ((ContactViewItem *)static_cast<QListViewItem *>(i)->parent())->groupName();
-		
+
 		QPopupMenu pm;
 
 		if(!self && !inList && !isPrivate && !option.lockdown.roster) {
@@ -1072,7 +1101,7 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 		if(!isPrivate)
 			pm.insertItem(tr("Send message to"), s2m, 17);
 
-		d->cv->qa_chat->setIconSet(IconsetFactory::iconPixmap("psi/chat"));
+		d->cv->qa_chat->setIconSet(IconsetFactory::iconPixmap("psi/start-chat"));
 		d->cv->qa_chat->addTo(&pm);
 
 		if(!isPrivate)
@@ -1185,7 +1214,7 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 					if(g == ContactView::tr("Hidden"))
 						gm->setItemChecked(n+base_group, true);
 					gm->insertSeparator();
-					gm->insertItem(IconsetFactory::iconPixmap("psi/edit/clear"), tr("&Create new..."), 9);
+					gm->insertItem(/*IconsetFactory::iconPixmap("psi/edit/clear"),*/ tr("&Create new..."), 9);
 					pm.insertItem(tr("&Group"), gm, 5);
 
 					if(!online)
@@ -1212,7 +1241,7 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 
 			authm->insertItem(tr("Resend authorization to"), 6);
 			authm->insertItem(tr("Rerequest authorization from"), 11);
-			authm->insertItem(IconsetFactory::iconPixmap("psi/edit/delete"), tr("Remove authorization from"), 15);
+			authm->insertItem(/*IconsetFactory::iconPixmap("psi/edit/delete"),*/ tr("Remove authorization from"), 15);
 
 			pm.insertItem (IconsetFactory::iconPixmap("psi/register"), tr("Authorization"), authm, 20);
 			if(!online)
@@ -1232,32 +1261,32 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 		}
 
 		// Avatars
-		//QPopupMenu *avpm = new QPopupMenu(&pm);
-		//d->cv->qa_assignAvatar->addTo(avpm);
-		//d->cv->qa_clearAvatar->setEnabled(d->pa->avatarFactory()->hasManualAvatar(u->jid()));
-		//d->cv->qa_clearAvatar->addTo(avpm);
-		//pm.insertItem(tr("&Avatar"), avpm);
-		//avpm->setEnabled(option.avatarsEnabled);
+#ifdef AVATARS
+		QPopupMenu *avpm = new QPopupMenu(&pm);
+		d->cv->qa_assignAvatar->addTo(avpm);
+		d->cv->qa_clearAvatar->setEnabled(d->pa->avatarFactory()->hasManualAvatar(u->jid()));
+		d->cv->qa_clearAvatar->addTo(avpm);
+		pm.insertItem(tr("&Avatar"), avpm);
+		avpm->setEnabled(option.avatarsEnabled);
+#endif
 
 		if(d->pa->psi()->pgp()) {
 			if(u->publicKeyID().isEmpty())
-				pm.insertItem(IconsetFactory::iconPixmap("psi/keySingle"), tr("Assign Open&PGP key"), 21);
+				pm.insertItem(IconsetFactory::iconPixmap("psi/gpg-yes"), tr("Assign Open&PGP key"), 21);
 			else
-				pm.insertItem(IconsetFactory::iconPixmap("psi/keySingle"), tr("Unassign Open&PGP key"), 22);
+				pm.insertItem(IconsetFactory::iconPixmap("psi/gpg-no"), tr("Unassign Open&PGP key"), 22);
 		}
 
-		pm.insertItem(/*IconsetFactory::iconPixmap("psi/info"),*/ tr("Check &Status"), 4);
-
-		pm.insertItem(IconsetFactory::iconPixmap("psi/vCard"), tr("User &Info"), 12);
+		d->cv->qa_vcard->addTo( &pm );
 
 		if(!isPrivate) {
 			d->cv->qa_hist->addTo(&pm);
 		}
 
-		if(link_test) {
-			pm.insertSeparator();
-			pm.insertItem(tr("Link Test"), 13);
-		}
+		//if(link_test) {
+		//	pm.insertSeparator();
+		//	pm.insertItem(tr("Link Test"), 13);
+		//}
 
 		QString name = u->jid().full();
 		QString show = jidnick(u->jid().full(), u->name());
@@ -1288,9 +1317,6 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 		else if(x == 2) {
 			actionSendUrl(u->jid());
 		}
-		else if(x == 4) {
-			actionStatusShow(u->jid());
-		}
 		else if(x == 6) {
 			if(online) {
 				actionAuth(u->jid());
@@ -1351,9 +1377,6 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 				tr("Rerequested authorization from <b>%1</b>.").arg(name));
 			}
 		}
-		else if(x == 12) {
-			actionInfo(u->jid());
-		}
 		else if(x == 13) {
 			actionTest(u->jid());
 		}
@@ -1368,8 +1391,10 @@ void ContactProfile::doContextMenu(ContactViewItem *i, const QPoint &pos)
 			}
 		}
 		else if(x == 16) {
-			if(online)
-				actionAgentSetStatus(u->jid(), STATUS_OFFLINE);
+			if(online) {
+				Status s=makeStatus(STATUS_OFFLINE,"");
+				actionAgentSetStatus(u->jid(), s);
+			}
 		}
 		else if(x == 21) {
 			actionAssignKey(u->jid());
@@ -1496,6 +1521,12 @@ void ContactProfile::scRename(ContactViewItem *i)
 	}
 }
 
+void ContactProfile::scVCard(ContactViewItem *i)
+{
+	if(i->type() == ContactViewItem::Contact)
+		actionInfo(i->u()->jid());
+}
+
 void ContactProfile::scHistory(ContactViewItem *i)
 {
 	if(i->type() == ContactViewItem::Contact)
@@ -1508,7 +1539,7 @@ void ContactProfile::scOpenChat(ContactViewItem *i)
 		actionOpenChat(i->u()->jid());
 }
 
-void ContactProfile::scAgentSetStatus(ContactViewItem *i, int s)
+void ContactProfile::scAgentSetStatus(ContactViewItem *i, Status &s)
 {
 	if(i->type() != ContactViewItem::Contact)
 		return;
@@ -1680,6 +1711,7 @@ public:
 		: QObject(_cv)
 	{
 		cv = _cv;
+		autoRosterResizeInProgress = false;
 
 		// type ahead
 		typeAheadTimer = new QTimer(cv);
@@ -1687,10 +1719,12 @@ public:
 	}
 
 	ContactView *cv;
-	QTimer *animTimer;
+	QTimer *animTimer, *recalculateSizeTimer;
 	QPtrList<ContactProfile> profiles;
 	QString typeAhead;
 	QTimer *typeAheadTimer;
+	QSize lastSize;
+	bool autoRosterResizeInProgress;
 
 	bool doTypeAhead(QKeyEvent *e)
 	{
@@ -1746,7 +1780,88 @@ public:
 		return true;
 	}
 
+public slots:
+	/*
+	 * \brief Recalculates the size of ContactView and resizes it accordingly
+	 */
+	void recalculateSize()
+	{
+		// save some CPU
+		if ( !cv->allowResize() )
+			return;
+
+		if ( !cv->isUpdatesEnabled() )
+			return;
+
+		QSize oldSize = cv->size();
+		QSize newSize = cv->sizeHint();
+
+		if ( newSize.height() != oldSize.height() ) {
+			lastSize = newSize;
+			QWidget *topParent = cv->topLevelWidget();
+
+			if ( cv->allowResize() ) {
+				topParent->layout()->setEnabled( false ); // try to reduce some flicker
+
+				int dh = newSize.height() - oldSize.height();
+				topParent->resize( topParent->width(),
+						   topParent->height() + dh );
+
+				autoRosterResizeInProgress = true;
+
+				QRect desktop = qApp->desktop()->availableGeometry( (QWidget *)topParent );
+				if ( option.autoRosterSizeGrowTop ) {
+					int newy = topParent->y() - dh;
+
+					// check, if we need to move roster lower
+					if ( dh > 0 && ( topParent->frameGeometry().top() <= desktop.top() ) ) {
+						newy = desktop.top();
+					}
+
+					topParent->move( topParent->x(), newy );
+				}
+
+				// check, if we need to move roster upper
+				if ( dh > 0 && ( topParent->frameGeometry().bottom() >= desktop.bottom() ) ) {
+					int newy = desktop.bottom() - topParent->frameGeometry().height();
+					topParent->move( topParent->x(), newy );
+				}
+
+				QTimer::singleShot( 0, this, SLOT( resetAutoRosterResize() ) );
+
+				topParent->layout()->setEnabled( true );
+			}
+
+			// issue a layout update
+			topParent->layout()->activate();
+		}
+	}
+
+	/*
+	 * \brief Determine in which direction to grow Psi roster window when autoRosterSize is enabled
+	 */
+	void determineAutoRosterSizeGrowSide()
+	{
+		if ( autoRosterResizeInProgress )
+			return;
+
+		QWidget *topParent = cv->topLevelWidget();
+		QRect desktop = qApp->desktop()->availableGeometry( (QWidget *)topParent );
+
+		int top_offs    = abs( desktop.top()    - topParent->frameGeometry().top() );
+		int bottom_offs = abs( desktop.bottom() - topParent->frameGeometry().bottom() );
+
+		option.autoRosterSizeGrowTop = bottom_offs < top_offs;
+		//qWarning("growTop = %d", option.autoRosterSizeGrowTop);
+	}
+
 private slots:
+	void resetAutoRosterResize()
+	{
+		//qWarning("resetAutoRosterResize");
+		autoRosterResizeInProgress = false;
+	}
+
 	void resetTypeAhead()
 	{
 		typeAhead = QString::null;
@@ -1762,10 +1877,12 @@ ContactView::ContactView(QWidget *parent, const char *name)
 	setAllColumnsShowFocus(true);
 	setShowToolTips(false);
 	setHScrollBarMode(AlwaysOff);
-	setMinimumSize(96,64);
+	setMinimumSize(96,32);
 	setTreeStepSize(4);
 	setSorting(0,true);
 
+	topLevelWidget()->installEventFilter( this );
+
 	// create the column and hide the header
 	addColumn("");
 	header()->hide();
@@ -1786,21 +1903,27 @@ ContactView::ContactView(QWidget *parent, const char *name)
 	v_showAgents = true;
 	v_showSelf = true;
 
+	d->lastSize = QSize( 0, 0 );
+
 	// animation timer
 	d->animTimer = new QTimer(this);
 	d->animTimer->start(120 * 5);
 
+	d->recalculateSizeTimer = new QTimer;
+	connect(d->recalculateSizeTimer, SIGNAL(timeout()), d, SLOT(recalculateSize()));
+
 	// actions
 	qa_send = new IconAction("", "psi/sendMessage", tr("Send &message"), QListView::CTRL+QListView::Key_M, this);
 	connect(qa_send, SIGNAL(activated()), SLOT(doSendMessage()));
 	qa_ren = new IconAction("", /*"psi/edit/clear",*/ tr("Re&name"), QListView::Key_F2, this);
 	connect(qa_ren, SIGNAL(activated()), SLOT(doRename()));
-	// Avatars
-	//qa_assignAvatar = new IconAction("", tr("&Assign Avatar"),QKeySequence(), this);
-	//connect(qa_assignAvatar, SIGNAL(activated()), SLOT(doAssignAvatar()));
-	//qa_clearAvatar = new IconAction("", tr("&Clear Avatar"), QKeySequence(), this);
-	//connect(qa_clearAvatar, SIGNAL(activated()), SLOT(doClearAvatar()));
-	qa_chat = new IconAction("", "psi/chat", tr("Open &chat window"), QListView::CTRL+QListView::Key_C, this);
+#ifdef AVATARS
+	qa_assignAvatar = new IconAction("", tr("&Assign Custom Avatar"),QKeySequence(), this);
+	connect(qa_assignAvatar, SIGNAL(activated()), SLOT(doAssignAvatar()));
+	qa_clearAvatar = new IconAction("", tr("&Clear Custom Avatar"), QKeySequence(), this);
+	connect(qa_clearAvatar, SIGNAL(activated()), SLOT(doClearAvatar()));
+#endif
+	qa_chat = new IconAction("", "psi/start-chat", tr("Open &chat window"), QListView::CTRL+QListView::Key_C, this);
 	connect(qa_chat, SIGNAL(activated()), SLOT(doOpenChat()));
 	qa_hist = new IconAction("", "psi/history", tr("&History"), QListView::CTRL+QListView::Key_H, this);
 	connect(qa_hist, SIGNAL(activated()), SLOT(doHistory()));
@@ -1810,6 +1933,8 @@ ContactView::ContactView(QWidget *parent, const char *name)
 	connect(qa_recv, SIGNAL(activated()), SLOT(doRecvEvent()));
 	qa_rem = new IconAction("", "psi/remove", tr("Rem&ove"), QListView::Key_Delete, this);
 	connect(qa_rem, SIGNAL(activated()), SLOT(doRemove()));
+	qa_vcard = new IconAction("", "psi/vCard", tr("User &Info"), QListView::CTRL+QListView::Key_I, this);
+	connect(qa_vcard, SIGNAL(activated()), SLOT(doVCard()));
 
 	if(option.lockdown.roster) {
 		qa_ren->setEnabled(false);
@@ -1939,6 +2064,11 @@ void ContactView::setShowHidden(bool x)
 	}
 }
 
+/*
+ * \brief Shows/hides the self contact in roster
+ *
+ * \param x - boolean variable specifies whether to show self-contact or not
+ */
 void ContactView::setShowSelf(bool x)
 {
 	if (v_showSelf != x) {
@@ -1954,9 +2084,22 @@ void ContactView::setShowSelf(bool x)
 				cp->removeSelf();
 			}
 		}
+
+		recalculateSize();
 	}
 }
 
+/*
+ * \brief Event filter. Nuff said.
+ */
+bool ContactView::eventFilter( QObject *obj, QEvent *event )
+{
+	if ( event->type() == QEvent::Move )
+		d->determineAutoRosterSizeGrowSide();
+
+	return QListView::eventFilter( obj, event );
+}
+
 
 void ContactView::setShowAgents(bool x)
 {
@@ -2010,7 +2153,11 @@ void ContactView::qlv_singleclick(int button, QListViewItem *i, const QPoint &po
 			item->contactProfile()->scActionDefault(item);
 	}
 	else {
-		if(option.useleft) {
+		const QPixmap * pix = item->pixmap(0);			
+		if (button == QListView::LeftButton && item->type() == ContactViewItem::Group && pix && viewport()->mapFromGlobal(pos).x() <= pix->width() + treeStepSize()) {
+			setOpen(item, !item->isOpen());
+		}
+		else if(option.useleft) {
 			if(button == QListView::LeftButton) {
 				if(option.singleclick) {
 					qlv_contextPopup(i, pos, c);
@@ -2093,6 +2240,10 @@ void ContactView::optionsUpdate()
 		item->optionsUpdate();
 	}
 
+	// resize if necessary
+	if (option.autoRosterSize)
+		recalculateSize();
+
 	update();
 }
 
@@ -2121,22 +2272,21 @@ void ContactView::doRename()
 	i->contactProfile()->scRename(i);
 }
 
-// Avatars
-//void ContactView::doAssignAvatar()
-//{
-//	// FIXME: Should check the supported filetypes dynamically
-//	QString file = QFileDialog::getOpenFileName("", tr("All files (*.png *.jpg *.gif)"), this, 0, tr("Choose an image"));
-//	if (!file.isNull()) {
-//		ContactViewItem *i = (ContactViewItem *)selectedItem();
-//		i->contactProfile()->psiAccount()->avatarFactory()->importManualAvatar(i->u()->jid(),file);
-//	}
-//}
+void ContactView::doAssignAvatar()
+{
+	// FIXME: Should check the supported filetypes dynamically
+	QString file = QFileDialog::getOpenFileName("", tr("All files (*.png *.jpg *.gif)"), this, 0, tr("Choose an image"));
+	if (!file.isNull()) {
+		ContactViewItem *i = (ContactViewItem *)selectedItem();
+		i->contactProfile()->psiAccount()->avatarFactory()->importManualAvatar(i->u()->jid(),file);
+	}
+}
 
-//void ContactView::doClearAvatar()
-//{
-//	ContactViewItem *i = (ContactViewItem *)selectedItem();
-//	i->contactProfile()->psiAccount()->avatarFactory()->removeManualAvatar(i->u()->jid());
-//}
+void ContactView::doClearAvatar()
+{
+	ContactViewItem *i = (ContactViewItem *)selectedItem();
+	i->contactProfile()->psiAccount()->avatarFactory()->removeManualAvatar(i->u()->jid());
+}
 
 void ContactView::doEnter()
 {
@@ -2183,12 +2333,21 @@ void ContactView::doHistory()
 	i->contactProfile()->scHistory(i);
 }
 
+void ContactView::doVCard()
+{
+	ContactViewItem *i = (ContactViewItem *)selectedItem();
+	if(!i)
+		return;
+	i->contactProfile()->scVCard(i);
+}
+
 void ContactView::doLogon()
 {
 	ContactViewItem *i = (ContactViewItem *)selectedItem();
 	if(!i)
 		return;
-	i->contactProfile()->scAgentSetStatus(i, STATUS_ONLINE);
+	Status s=i->contactProfile()->psiAccount()->status();
+	i->contactProfile()->scAgentSetStatus(i, s);
 }
 
 void ContactView::doRemove()
@@ -2212,6 +2371,78 @@ QDragObject *ContactView::dragObject()
 	return d;
 }
 
+bool ContactView::allowResize() const
+{
+	if ( !option.autoRosterSize )
+		return false;
+
+	if ( topLevelWidget()->isMaximized() )
+		return false;
+
+	return true;
+}
+
+QSize ContactView::minimumSizeHint() const
+{
+	return QSize( minimumWidth(), minimumHeight() );
+}
+
+QSize ContactView::sizeHint() const
+{
+	// save some CPU
+	if ( !allowResize() )
+		return minimumSizeHint();
+
+	QSize s( QListView::sizeHint().width(), 0 );
+	int border = 5;
+	int h = border;
+
+	QListView *listView = (QListView *)this;
+	QListViewItemIterator it( listView );
+	while ( it.current() ) {
+		if ( it.current()->isVisible() ) {
+			// also we need to check whether the group is open or closed
+			bool show = true;
+			QListViewItem *item = it.current()->parent();
+			while ( item ) {
+				if ( !item->isOpen() ) {
+					show = false;
+					break;
+				}
+				item = item->parent();
+			}
+
+			if ( show )
+				h += it.current()->height();
+		}
+
+		++it;
+	}
+
+	QWidget *topParent = topLevelWidget();
+	QRect desktop = qApp->desktop()->availableGeometry( (QWidget *)topParent );
+	int dh = h - d->lastSize.height();
+
+	// check that our dialog's height doesn't exceed the desktop's
+	if ( allowResize() && dh > 0 && (topParent->frameGeometry().height() + dh) >= desktop.height() ) {
+		h = desktop.height() - ( topParent->frameGeometry().height() - d->lastSize.height() );
+	}
+
+	int minH = minimumSizeHint().height();
+	if ( h < minH )
+		h = minH + border;
+	s.setHeight( h );
+	return s;
+}
+
+/*
+ * \brief Adds the request to recalculate the ContactView size to the event queue
+ */
+void ContactView::recalculateSize()
+{
+	d->recalculateSizeTimer->start( 0, true );
+}
+
 //----------------------------------------------------------------------------
 // ContactViewItem
 //----------------------------------------------------------------------------
@@ -2497,17 +2728,20 @@ void ContactViewItem::paintCell(QPainter *p, const QColorGroup & cg, int column,
 	}
 	else if ( d->type == Group || d->type == Profile ) {
 		QColorGroup xcg = cg;
-		xcg.setColor(QColorGroup::Text, option.color[cGroupFore]);
 
-		if(d->type == Group && option.clNewHeadings) {
-			//xcg.setColor(QColorGroup::Text, option.color[cGroupBack]);
+		if(d->type == Profile) {
+			xcg.setColor(QColorGroup::Text, option.color[cProfileFore]);
+			xcg.setColor(QColorGroup::Base, option.color[cProfileBack]);
+		}
+		else if(d->type == Group) {
 			QFont f = p->font();
 			f.setPointSize(option.smallFontSize);
 			p->setFont(f);
-		} else {
-			//xcg.setColor(QColorGroup::Text, option.color[cGroupFore]);
-			xcg.setColor(QColorGroup::Base, option.color[cGroupBack]);
-		}
+			xcg.setColor(QColorGroup::Text, option.color[cGroupFore]);
+			if (!option.clNewHeadings) {
+				xcg.setColor(QColorGroup::Base, option.color[cGroupBack]);
+			}
+		} 
 
 		QListViewItem::paintCell(p, xcg, column, width, alignment);
 
@@ -2527,8 +2761,14 @@ void ContactViewItem::paintCell(QPainter *p, const QColorGroup & cg, int column,
 		else
 			p->setPen(xcg.text());
 
-		int y = ((height() - fm.height()) / 2) + fm.ascent();
-		p->drawText(x, y, d->groupInfo);
+		QFont f_info = p->font();
+		f_info.setPointSize(option.smallFontSize);
+		p->setFont(f_info);
+		QFontMetrics fm_info(p->font());
+		//int info_x = width - fm_info.width(d->groupInfo) - 8;
+		int info_x = x;
+		int info_y = ((height() - fm_info.height()) / 2) + fm_info.ascent();
+		p->drawText((info_x > x ? info_x : x), info_y, d->groupInfo);
 
 		if(d->type == Group && option.clNewHeadings && !isSelected()) {
 			x += fm.width(d->groupInfo) + 8;
@@ -2543,15 +2783,27 @@ void ContactViewItem::paintCell(QPainter *p, const QColorGroup & cg, int column,
 				p->setPen(QPen(option.color[cGroupBack], 2));*/
 				p->drawLine(x, h, width - 8, h);
 			}
-		} else {
-			p->setPen(QPen(option.color[cGroupFore]));
-			p->drawRect(0, 0, width, height());
+		} 
+		else {
+			if (option.outlineHeadings) {
+				p->setPen(QPen(option.color[cGroupFore]));
+				p->drawRect(0, 0, width, height());
+			}
 		}
 	}
 }
 
+/*
+ * \brief "Opens" or "closes the ContactViewItem
+ *
+ * When the item is in "open" state, all it's children items are visible.
+ *
+ * \param o - if true, the item will be "open"
+ */
 void ContactViewItem::setOpen(bool o)
 {
+	((ContactView *)listView())->recalculateSize();
+
 	QListViewItem::setOpen(o);
 	drawGroupIcon();
 
