@@ -26,9 +26,7 @@
 #include<qtooltip.h>
 #include<qvaluelist.h>
 #include"xmpp.h"
-
-typedef QValueList<XMPP::Jid> JidList;
-typedef QValueListIterator<XMPP::Jid> JidListIt;
+#include"common.h"
 
 class IconAction;
 class UserListItem;
@@ -76,7 +74,7 @@ public:
 
 	void ensureVisible(const Jid &);
 	void clear();
-	
+
 	QString makeTip(bool trim, bool doLinkify) const;
 
 	ContactViewItem *checkGroup(int type);
@@ -95,10 +93,9 @@ signals:
 	void actionRename(const Jid &, const QString &);
 	void actionGroupRename(const QString &, const QString &);
 	void actionHistory(const Jid &);
-	void actionStatusShow(const Jid &);
 	void actionOpenChat(const Jid &);
 	void actionOpenChatSpecific(const Jid &);
-	void actionAgentSetStatus(const Jid &, int);
+	void actionAgentSetStatus(const Jid &, Status &);
 	void actionInfo(const Jid &);
 	void actionAuth(const Jid &);
 	void actionAuthRequest(const Jid &);
@@ -119,8 +116,8 @@ private slots:
 
 public:
 	class Entry;
-private:
 	class Private;
+private:
 	Private *d;
 
 	ContactViewItem *addGroup(int type);
@@ -159,9 +156,10 @@ private:
 	void scRecvEvent(ContactViewItem *);
 	void scSendMessage(ContactViewItem *);
 	void scRename(ContactViewItem *);
+	void scVCard(ContactViewItem *);
 	void scHistory(ContactViewItem *);
 	void scOpenChat(ContactViewItem *);
-	void scAgentSetStatus(ContactViewItem *, int);
+	void scAgentSetStatus(ContactViewItem *, Status &);
 	void scRemove(ContactViewItem *);
 	void doItemRenamed(ContactViewItem *, const QString &);
 	void doContextMenu(ContactViewItem *, const QPoint &);
@@ -189,15 +187,17 @@ public:
 	void resetAnim();
 	QTimer *animTimer() const;
 
-	IconAction *qa_send, *qa_chat, *qa_ren, *qa_hist, *qa_logon, *qa_recv, *qa_rem;
-	// Avatars
-	//IconAction *qa_assignAvatar, *qa_clearAvatar;
+	IconAction *qa_send, *qa_chat, *qa_ren, *qa_hist, *qa_logon, *qa_recv, *qa_rem, *qa_vcard;
+	IconAction *qa_assignAvatar, *qa_clearAvatar;
 
+	QSize minimumSizeHint() const;
+	QSize sizeHint() const;
 
 protected:
 	// reimplemented
 	void maybeTip(const QPoint &);
 	void keyPressEvent(QKeyEvent *);
+	bool eventFilter( QObject *, QEvent * );
 	QDragObject *dragObject();
 
 signals:
@@ -214,6 +214,7 @@ public slots:
 	void setShowHidden(bool);
 	void setShowSelf(bool);
 	void optionsUpdate();
+	void recalculateSize();
 
 private slots:
 	void qlv_singleclick(int, QListViewItem *, const QPoint &, int);
@@ -230,15 +231,16 @@ private slots:
 	void doSendMessage();
 	void doOpenChat();
 	void doHistory();
+	void doVCard();
 	void doLogon();
 	void doRemove();
-	
-	// Avatars
-	//void doAssignAvatar();
-	//void doClearAvatar();
+
+	void doAssignAvatar();
+	void doClearAvatar();
 
 public:
 	class Private;
+	friend class Private;
 private:
 	Private *d;
 
@@ -247,10 +249,12 @@ private:
 	bool lcto_active; // double click active?
 	QPoint lcto_pos;
 	QListViewItem *lcto_item;
+	QSize lastSize;
 
 	friend class ContactProfile;
 	void link(ContactProfile *);
 	void unlink(ContactProfile *);
+	bool allowResize() const;
 };
 
 // ContactViewItem: an entry in the ContactView (profile, group, or contact)
