@@ -25,7 +25,6 @@
 #include <qcheckbox.h>
 #include <qmessagebox.h>
 #include <qaction.h>
-#include <qtoolbar.h>
 #include <qstatusbar.h>
 #include <qpopupmenu.h>
 #include <qsignalmapper.h>
@@ -37,6 +36,7 @@
 #include "im.h"
 #include "xmpp_tasks.h"
 
+#include "psitoolbar.h"
 #include "tasklist.h"
 #include "psiaccount.h"
 #include "psicon.h"
@@ -184,6 +184,8 @@ private:
 	void updateInfo(const DiscoItem &);
 	void updateItemsFinished(const DiscoList &);
 	void autoItemsChildren() const; // automatically call disco#items for children :-)
+	QString hash() { return computeHash( item().jid().full(), item().node() ); }
+	QString computeHash( QString jid, QString node );
 
 	// helper functions
 	void init(DiscoItem it, DiscoData *dd);
@@ -529,54 +531,43 @@ void DiscoListItem::agentsFinished()
 	alreadyItems = true;
 }
 
+QString DiscoListItem::computeHash( QString jid, QString node )
+{
+	QString ret = jid.replace( '@', "\\@" );
+	ret += "@";
+	ret += node.replace( '@', "\\@" );
+	return ret;
+}
+
 void DiscoListItem::updateItemsFinished(const DiscoList &list)
 {
-	// add/update items
-	for(DiscoList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-		const DiscoItem a = *it;
-		bool found = false;
-
-		DiscoListItem *child = (DiscoListItem *)firstChild();
-		while ( child ) {
-			if ( child->item().jid().full() == a.jid().full() &&
-			     child->item().node()       == a.node() )
-			{
-				child->copyItem ( a );
-				found = true;
-				break;
-			}
-
-			child = (DiscoListItem *)child->nextSibling();
-		}
-
-		if ( !found )
-			new DiscoListItem (a, d, this);
-	}
-
-	// check for removed items
-	QPtrList<DiscoListItem> removeList;
-	removeList.setAutoDelete (true);
+	QDict<DiscoListItem> children;
 	DiscoListItem *child = (DiscoListItem *)firstChild();
 	while ( child ) {
-		bool found = false;
-
-		for(DiscoList::ConstIterator it = list.begin(); it != list.end(); ++it) {
-			const DiscoItem a = *it;
-
-			if ( child->item().jid().full() == a.jid().full() &&
-			     child->item().node()       == a.node() )
-			{
-				found = true;
-				break;
-			}
-		}
-
-		if ( !found )
-			removeList.append ( child ); // items will be deleted later
+		children.insert( child->hash(), child );
 
 		child = (DiscoListItem *)child->nextSibling();
 	}
-	removeList.clear();
+
+	// add/update items
+	for(DiscoList::ConstIterator it = list.begin(); it != list.end(); ++it) {
+		const DiscoItem a = *it;
+
+		QString key = computeHash(a.jid().full(), a.node());
+		DiscoListItem *child = children[ key ];
+
+		if ( child ) {
+			child->copyItem ( a );
+			children.remove( key );
+		}
+		else {
+			new DiscoListItem (a, d, this);
+		}
+	}
+
+	// remove all items that are not on new DiscoList
+	children.setAutoDelete( true );
+	children.clear();
 
 	if ( autoItems && isOpen() )
 		autoItemsChildren();
@@ -795,7 +786,7 @@ public: // data
 
 	DiscoData data;
 
-	QToolBar *toolBar;
+	PsiToolBar *toolBar;
 	IconAction *actBrowse, *actBack, *actForward, *actRefresh, *actStop;
 
 	// custom actions, that will be added to toolbar and context menu
@@ -915,7 +906,8 @@ DiscoDlg::Private::Private(DiscoDlg *parent, PsiAccount *pa)
 	sm->setMapping(actAdd, Features::FID_Add);
 
 	// create toolbar
-	toolBar = new QToolBar(dlg);
+	toolBar = new PsiToolBar(dlg);
+	toolBar->setCustomizeable( false );
 
 	actBack->addTo(toolBar);
 	actBrowse->addTo(toolBar);
