@@ -450,7 +450,7 @@ public:
 	bool enc;
 	int transid;
 	IconButton *pb_next;
-	IconButton *pb_close, *pb_quote, *pb_deny, *pb_send, *pb_reply, *pb_auth;
+	IconButton *pb_close, *pb_quote, *pb_deny, *pb_send, *pb_reply, *pb_chat, *pb_auth;
 	ChatView *mle;
 	AttachView *attachView;
 	QTimer *whois;
@@ -499,7 +499,7 @@ public slots:
 };
 
 EventDlg::EventDlg(const QString &to, PsiCon *psi, PsiAccount *pa)
-:QWidget(0, 0, WDestructiveClose | WGroupLeader)
+:AdvancedWidget<QWidget>(0, 0, WDestructiveClose | WGroupLeader)
 {
 	d = new Private(this);
 	d->composing = true;
@@ -565,7 +565,7 @@ EventDlg::EventDlg(const QString &to, PsiCon *psi, PsiAccount *pa)
 }
 
 EventDlg::EventDlg(const Jid &j, PsiAccount *pa, bool unique)
-:QWidget(0, 0, WDestructiveClose | WGroupLeader)
+:AdvancedWidget<QWidget>(0, 0, WDestructiveClose | WGroupLeader)
 {
 	d = new Private(this);
 	d->composing = false;
@@ -818,6 +818,12 @@ void EventDlg::init()
 	d->pb_send->hide();
 	d->pb_send->setMinimumWidth(96);
 	hb4->addWidget(d->pb_send);
+	d->pb_chat = new IconButton(this);
+	d->pb_chat->setText(tr("&Chat"));
+	connect(d->pb_chat, SIGNAL(clicked()), SLOT(doChat()));
+	d->pb_chat->hide();
+	d->pb_chat->setMinimumWidth(96);
+	hb4->addWidget(d->pb_chat);
 	d->pb_reply = new IconButton(this);
 	d->pb_reply->setText(tr("&Reply"));
 	connect(d->pb_reply, SIGNAL(clicked()), SLOT(doReply()));
@@ -1239,6 +1245,8 @@ void EventDlg::keyPressEvent(QKeyEvent *e)
 		doSend();
 	else if(e->key() == Key_H && (e->state() & ControlButton))
 		doHistory();
+	else if(e->key() == Key_I && (e->state() & ControlButton))
+		doInfo();
 	else
 		e->ignore();
 }
@@ -1317,6 +1325,19 @@ void EventDlg::doReadNext()
 	aReadNext(d->realJid);
 }
 
+void EventDlg::doChat()
+{
+	QStringList list = stringToList(d->le_from->text());
+	if(list.isEmpty())
+		return;
+
+	// FIXME: Maybe it's better without bare(), but then PsiAccount::actionChat
+	// doesn't find the UserListItem to chat with :-(
+	Jid jf(list[0]);
+	Jid j(jf.bare());
+	aChat(j);
+}
+
 void EventDlg::doReply()
 {
 	QStringList list = stringToList(d->le_from->text());
@@ -1489,6 +1510,7 @@ void EventDlg::updateEvent(PsiEvent *e)
 		d->pb_auth->hide();
 		d->pb_deny->hide();
 
+		d->pb_chat->show();
 		d->pb_reply->show();
 		d->pb_quote->show();
 
@@ -1529,6 +1551,7 @@ void EventDlg::updateEvent(PsiEvent *e)
 			d->mle->setTextFormat(RichText);
 			d->mle->setText("<qt>" + body + "</qt>");
 
+			d->pb_chat->show();
 			d->pb_reply->hide();
 			d->pb_quote->hide();
 
@@ -1544,6 +1567,7 @@ void EventDlg::updateEvent(PsiEvent *e)
 
 			d->pb_auth->hide();
 			d->pb_deny->hide();
+			d->pb_chat->show();
 			d->pb_reply->show();
 			d->pb_quote->show();
 		}
@@ -1555,6 +1579,7 @@ void EventDlg::updateEvent(PsiEvent *e)
 
 			d->pb_auth->hide();
 			d->pb_deny->hide();
+			d->pb_chat->show();
 			d->pb_reply->show();
 			d->pb_quote->show();
 		}
