@@ -21,7 +21,7 @@
 #ifndef EVENTDLG_H
 #define EVENTDLG_H
 
-#include<qwidget.h>
+#include"advwidget.h"
 #define private protected
 #include<qlineedit.h>
 #undef private
@@ -101,7 +101,7 @@ public:
 	~AddUrlDlg();
 };
 
-class EventDlg : public QWidget
+class EventDlg : public AdvancedWidget<QWidget>
 {
 	Q_OBJECT
 public:
@@ -122,6 +122,7 @@ public:
 	static QSize defaultSize();
 
 signals:
+	void aChat(const Jid& jid);
 	void aReply(const Jid &jid, const QString &body, const QString &subject, const QString &thread);
 	void aReadNext(const Jid &);
 	void aDeny(const Jid &);
@@ -151,6 +152,7 @@ private slots:
 	void doWhois(bool force=false);
 	void doSend();
 	void doReadNext();
+	void doChat();
 	void doReply();
 	void doQuote();
 	void doDeny();
