@@ -473,7 +473,6 @@ void FileTransferHandler::mapSignals()
 //----------------------------------------------------------------------------
 // FileRequestDlg
 //----------------------------------------------------------------------------
-static QString lastPath, lastSavePath;
 
 class FileRequestDlg::Private
 {
@@ -564,7 +563,7 @@ FileRequestDlg::FileRequestDlg(const Jid &jid, PsiCon *psi, PsiAccount *pa, cons
 			return;
 		}
 		
-		lastPath = fi.dirPath();
+		option.lastPath = fi.dirPath();
 		le_fname->setText(QDir::convertSeparators(fi.filePath()));
 		lb_size->setText(tr("%1 byte(s)").arg(fi.size())); // TODO: large file support
 	}
@@ -712,16 +711,16 @@ void FileRequestDlg::unblockWidgets()
 void FileRequestDlg::chooseFile()
 {
 	while(1) {
-		if(lastPath.isEmpty())
-			lastPath = QDir::homeDirPath();
-		QString str = QFileDialog::getOpenFileName(lastPath, tr("All files (*)"), this, 0, tr("Choose a file"));
+		if(option.lastPath.isEmpty())
+			option.lastPath = QDir::homeDirPath();
+		QString str = QFileDialog::getOpenFileName(option.lastPath, tr("All files (*)"), this, 0, tr("Choose a file"));
 		if(!str.isEmpty()) {
 			QFileInfo fi(str);
 			if(!fi.exists()) {
 				QMessageBox::information(this, tr("Error"), tr("The file specified does not exist."));
 				continue;
 			}
-			lastPath = fi.dirPath();
+			option.lastPath = fi.dirPath();
 			le_fname->setText(QDir::convertSeparators(fi.filePath()));
 			lb_size->setText(tr("%1 byte(s)").arg(fi.size())); // TODO: large file support
 		}
@@ -768,9 +767,9 @@ void FileRequestDlg::doStart()
 		QString fname, savename;
 		bool overwrite = false;
 		while(1) {
-			if(lastSavePath.isEmpty())
-				lastSavePath = QDir::homeDirPath();
-			fname = QFileDialog::getSaveFileName(QDir(lastSavePath).filePath(d->fileName), tr("All files (*)"), this, 0, tr("Save As"));
+			if(option.lastSavePath.isEmpty())
+				option.lastSavePath = QDir::homeDirPath();
+			fname = QFileDialog::getSaveFileName(QDir(option.lastSavePath).filePath(d->fileName), tr("All files (*)"), this, 0, tr("Save As"));
 			if(!fname.isEmpty()) {
 				QFileInfo fi(fname);
 				if(fi.exists()) {
@@ -779,7 +778,7 @@ void FileRequestDlg::doStart()
 						continue;
 					overwrite = true;
 				}
-				lastSavePath = fi.dirPath();
+				option.lastSavePath = fi.dirPath();
 				savename = fname + ".part";
 				fname = fi.fileName();
 			}
