@@ -35,6 +35,7 @@
 #include<qaction.h>
 #include<qobjectlist.h>
 #include<qpopupmenu.h>
+#include<qcursor.h>
 #include"psicon.h"
 #include"psiaccount.h"
 #include"userlist.h"
@@ -44,6 +45,7 @@
 #include"msgmle.h"
 #include"iconwidget.h"
 #include"iconselect.h"
+#include"psitoolbar.h"
 #include"iconaction.h"
 
 #ifdef Q_WS_WIN
@@ -74,15 +76,15 @@ GCJoinDlg::GCJoinDlg(PsiCon *psi, PsiAccount *pa)
 	d->psi = psi;
 	d->pa = 0;
 	d->psi->dialogRegister(this);
+	d->busy = busy;
+
 	updateIdentity(pa);
 
-	d->cb_ident = d->psi->accountsComboBox(this);
+	d->cb_ident = d->psi->accountsComboBox(this,true);
 	connect(d->cb_ident, SIGNAL(activated(PsiAccount *)), SLOT(updateIdentity(PsiAccount *)));
 	d->cb_ident->setAccount(pa);
 	replaceWidget(lb_ident, d->cb_ident);
 
-	d->busy = busy;
-
 	d->rl = d->psi->recentGCList();
 	for(QStringList::ConstIterator it = d->rl.begin(); it != d->rl.end(); ++it) {
 		Jid j(*it);
@@ -135,10 +137,10 @@ void GCJoinDlg::updateIdentity(PsiAccount *pa)
 		disconnect(d->pa, SIGNAL(disconnected()), this, SLOT(pa_disconnected()));
 
 	d->pa = pa;
+	pb_join->setEnabled(d->pa);
 
 	if(!d->pa) {
 		d->busy->stop();
-		close();
 		return;
 	}
 
@@ -149,7 +151,6 @@ void GCJoinDlg::pa_disconnected()
 {
 	if(d->busy->isActive()) {
 		d->busy->stop();
-		close();
 	}
 }
 
@@ -191,7 +192,7 @@ void GCJoinDlg::doJoin()
 
 	Jid j = room + '@' + host + '/' + nick;
 	if(!j.isValid()) {
-		QMessageBox::information(this, tr("Error"), tr("You entered an invalid room."));
+		QMessageBox::information(this, tr("Error"), tr("You entered an invalid room name."));
 		return;
 	}
 
@@ -361,7 +362,7 @@ void GCUserView::qlv_contextMenuRequested(QListViewItem *i, const QPoint &pos, i
 
 	QPopupMenu *pm = new QPopupMenu;
 	pm->insertItem(IconsetFactory::icon("psi/sendMessage"), tr("Send &message"), 0);
-	pm->insertItem(IconsetFactory::icon("psi/chat"), tr("Open &chat window"), 1);
+	pm->insertItem(IconsetFactory::icon("psi/start-chat"), tr("Open &chat window"), 1);
 	pm->insertSeparator();
 	//pm->insertItem(tr("Send &file"), 4);
 	//pm->insertSeparator();
@@ -400,8 +401,10 @@ public:
 	QLineEdit *le_topic;
 	GCUserView *lv_users;
 	QPushButton *pb_topic;
-	IconAction *act_find;
-	IconToolButton *tb_clear, *tb_icon;
+	PsiToolBar *toolbar;
+	IconAction *act_find, *act_clear, *act_icon;
+	QPopupMenu *pm_settings;
+	bool smallChat;
 	int pending;
 
 	bool trackBar;
@@ -661,7 +664,7 @@ public:
 };
 
 GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j)
-:QWidget(0, 0, WDestructiveClose)
+:AdvancedWidget<QWidget>(0, 0, WDestructiveClose)
 {
 	nicknumber=0;
 	d = new Private(this);
@@ -682,38 +685,46 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j)
 
 	d->state = Private::Connected;
 
+#ifndef Q_WS_MAC
 	setIcon(IconsetFactory::icon("psi/groupChat"));
+#endif
 
-	d->act_find = new IconAction(tr("Find"), "psi/search", tr("&Find"), CTRL+Key_F, this);
-	connect(d->act_find, SIGNAL(activated()), SLOT(openFind()));
+	QVBoxLayout *dlg_layout = new QVBoxLayout(this, 4);
 
-	QVBoxLayout *dlg_layout = new QVBoxLayout(this);
-
-	QSplitter *vsplit = new QSplitter(this);
-	vsplit->setOrientation( QSplitter::Vertical );
-	dlg_layout->addWidget(vsplit);
+	QWidget *vsplit;
+	if ( !option.chatLineEdit ) {
+		vsplit = new QSplitter(this);
+		((QSplitter *)vsplit)->setOrientation( QSplitter::Vertical );
+		dlg_layout->addWidget(vsplit);
+	}
+	else
+		vsplit = this;
 
 	// --- top part ---
 	QWidget *sp_top = new QWidget(vsplit);
-	QVBoxLayout *vb_top = new QVBoxLayout(sp_top, 4);
+	sp_top->setSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum );
+	if ( option.chatLineEdit )
+		dlg_layout->addWidget( sp_top );
+	QVBoxLayout *vb_top = new QVBoxLayout(sp_top, 0, 4);
 
 	// top row
-	QHBoxLayout *hb_top = new QHBoxLayout(vb_top);
+	QWidget *sp_top_top = new QWidget( sp_top );
+	vb_top->addWidget( sp_top_top );
+	QHBoxLayout *hb_top = new QHBoxLayout( sp_top_top, 0, 4 );
 
-	d->pb_topic = new QPushButton(tr("Topic:"), sp_top);
+	d->pb_topic = new QPushButton(tr("Topic:"), sp_top_top);
 	connect(d->pb_topic, SIGNAL(clicked()), SLOT(doTopic()));
 	hb_top->addWidget(d->pb_topic);
 
-	d->le_topic = new QLineEdit(sp_top);
+	d->le_topic = new QLineEdit(sp_top_top);
 	d->le_topic->setReadOnly(true);
 	hb_top->addWidget(d->le_topic);
 
-	IconToolButton *tb_find = new IconToolButton(sp_top);
-	tb_find->setIcon(IconsetFactory::iconPtr("psi/search"));
-	connect(tb_find, SIGNAL(clicked()), SLOT(openFind()));
-	hb_top->addWidget(tb_find);
+	d->act_find = new IconAction(tr("Find"), "psi/search", tr("&Find"), CTRL+Key_F, this);
+	connect(d->act_find, SIGNAL(activated()), SLOT(openFind()));
+	d->act_find->addTo( sp_top_top );
 
-	QLabel *lb_ident = d->pa->accountLabel(sp_top, true);
+	QLabel *lb_ident = d->pa->accountLabel(sp_top_top, true);
 	lb_ident->setSizePolicy(QSizePolicy( QSizePolicy::Minimum, QSizePolicy::Minimum ));
 	hb_top->addWidget(lb_ident);
 
@@ -725,6 +736,10 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j)
 
 	d->te_log = new ChatView(hsp);
 	d->te_log->setTextFormat( RichText );
+#ifdef Q_WS_MAC
+	connect(d->te_log,SIGNAL(selectionChanged()),SLOT(logSelectionChanged()));
+	d->te_log->setFocusPolicy(QWidget::NoFocus);
+#endif
 
 	d->lv_users = new GCUserView(hsp);
 	d->lv_users->setMinimumWidth(20);
@@ -732,33 +747,50 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j)
 
 	// --- bottom part ---
 	QWidget *sp_bottom = new QWidget(vsplit);
-	QVBoxLayout *vb_bottom = new QVBoxLayout(sp_bottom, 4);
+	sp_bottom->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Maximum );
+	if ( option.chatLineEdit )
+		dlg_layout->addWidget( sp_bottom );
+	QVBoxLayout *vb_bottom = new QVBoxLayout(sp_bottom);
+
+	// toolbar
+	d->act_clear = new IconAction (tr("Clear chat window"), "psi/clearChat", tr("Clear chat window"), 0, this);
+	connect( d->act_clear, SIGNAL( activated() ), SLOT( doClearButton() ) );
 
-	// top row
-	// icon selector
-	//connect(pa->psi->iconSelectPopup(), SIGNAL(iconSelected(const Icon *)), d, SLOT(addEmoticon(const Icon *)));
 	connect(pa->psi()->iconSelectPopup(), SIGNAL(textSelected(QString)), d, SLOT(addEmoticon(QString)));
+	d->act_icon = new IconAction( tr( "Select icon" ), "psi/smile", tr( "Select icon" ), 0, this );
+	d->act_icon->setPopup( pa->psi()->iconSelectPopup() );
 
-	d->tb_clear = new IconToolButton(sp_bottom) ;
-	d->tb_clear->setIcon(IconsetFactory::iconPtr("psi/clearChat"));
-	connect(d->tb_clear, SIGNAL(clicked()), SLOT(doClearButton()));
+	d->toolbar = new PsiToolBar( tr("Groupchat toolbar"), 0, sp_bottom );
+	d->toolbar->setCustomizeable( false ); // it isn't ready now, and we don't want segfaults
+	d->toolbar->setFrameShape( QFrame::NoFrame );
+	vb_bottom->addWidget( d->toolbar );
 
-	d->tb_icon = new IconToolButton(sp_bottom);
-	d->tb_icon->setIcon(IconsetFactory::iconPtr("psi/smile"));
-	d->tb_icon->setPopup(pa->psi()->iconSelectPopup());
-	d->tb_icon->setPopupDelay (1);
-
-	QHBoxLayout *toolbox = new QHBoxLayout(vb_bottom);
-	toolbox->addWidget(d->tb_clear);
-	toolbox->addStretch();
-	toolbox->addWidget(d->tb_icon);
+	d->act_clear->addTo( d->toolbar );
+	d->toolbar->setStretchableWidget(new StretchWidget(d->toolbar));
+	d->act_icon->addTo( d->toolbar );
 
 	// chat edit
-	d->mle = new ChatEdit(sp_bottom);
-	//d->mle->setFixedHeight(48);
-	vb_bottom->addWidget(d->mle);
+	if ( !option.chatLineEdit ) {
+		d->mle = new ChatEdit(sp_bottom);
+		vb_bottom->addWidget(d->mle);
+	}
+	else {
+		QHBoxLayout *hb5 = new QHBoxLayout( dlg_layout );
+		d->mle = new LineEdit( vsplit );
+#ifdef Q_WS_MAC
+		hb5->addSpacing( 16 );
+#endif
+		hb5->addWidget( d->mle );
+#ifdef Q_WS_MAC
+		hb5->addSpacing( 16 );
+#endif
+	}
+
 	d->mle->installEventFilter( d );
 
+	d->pm_settings = new QPopupMenu(this);
+	connect(d->pm_settings, SIGNAL(aboutToShow()), SLOT(buildMenu()));
+
 	// resize the horizontal splitter
 	QValueList<int> list;
 	list << 500;
@@ -768,10 +800,12 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j)
 	list.clear();
 	list << 324;
 	list << 10;
-	vsplit->setSizes(list);
+	if ( !option.chatLineEdit )
+		(( QSplitter *)vsplit)->setSizes(list);
 
 	resize(580,420);
 
+	d->smallChat = option.smallChats;
 	X11WM_CLASS("groupchat");
 
 	d->mle->setFocus();
@@ -829,6 +863,18 @@ void GCMainDlg::windowActivationChange(bool oldstate)
 	}
 }
 
+
+void GCMainDlg::logSelectionChanged()
+{
+#ifdef Q_WS_MAC
+	// A hack to only give the message log focus when text is selected
+	if (d->te_log->hasSelectedText()) 
+		d->te_log->setFocus();
+	else 
+		d->mle->setFocus();
+#endif
+}
+
 void GCMainDlg::mle_returnPressed()
 {
 	if(d->mle->text().isEmpty())
@@ -1318,17 +1364,17 @@ void GCMainDlg::setLooks()
 	f.fromString(option.font[fRoster]);
 	d->lv_users->QListView::setFont(f);
 
-	if ( option.useEmoticons ) {
-		//d->tb_clear->show();
-		d->tb_icon->show();
+	if ( d->smallChat ) {
+		d->toolbar->hide();
 	}
 	else {
-		//d->tb_clear->hide();
-		d->tb_icon->hide();
+		d->toolbar->show();
 	}
 
 	// update the widget icon
+#ifndef Q_WS_MAC
 	setIcon(IconsetFactory::icon("psi/groupChat"));
+#endif
 }
 
 void GCMainDlg::optionsUpdate()
@@ -1373,6 +1419,28 @@ void GCMainDlg::lv_action(const QString &nick, const Status &s, int x)
 	}
 }
 
+void GCMainDlg::contextMenuEvent(QContextMenuEvent *)
+{
+	d->pm_settings->exec(QCursor::pos());
+}
+
+void GCMainDlg::buildMenu()
+{
+	// Dialog menu
+	d->pm_settings->clear();
+	d->pm_settings->insertItem(tr("Toggle Compact/Full Size"), this, SLOT(toggleSmallChat()));
+
+	d->act_clear->addTo( d->pm_settings );
+	d->pm_settings->insertSeparator();
+
+	d->act_icon->addTo( d->pm_settings );
+}
+
+void GCMainDlg::toggleSmallChat()
+{
+	d->smallChat = !d->smallChat;
+	setLooks();
+}
 
 //----------------------------------------------------------------------------
 // GCFindDlg
@@ -1433,7 +1501,7 @@ void GCFindDlg::error(const QString &str)
 
 void GCFindDlg::doFind()
 {
-	find(para, index, le_input->text());
+	emit find(para, index, le_input->text());
 }
 
 #include "groupchatdlg.moc"
