@@ -38,8 +38,6 @@
 #include"eventdb.h"
 #include"userlist.h"
 
-static QString lastPath;
-
 static QString getNext(QString *str)
 {
 	// are we in space?
@@ -126,7 +124,9 @@ HistoryDlg::HistoryDlg(const Jid &jid, PsiAccount *pa)
 	d->exp = 0;
 
 	setCaption(d->jid.full());
+#ifndef Q_WS_MAC
 	setIcon(IconsetFactory::icon("psi/history"));
+#endif
 
 	d->h = new EDBHandle(d->pa->edb());
 	connect(d->h, SIGNAL(finished()), SLOT(edb_finished()));
@@ -272,14 +272,14 @@ void HistoryDlg::doNext()
 
 void HistoryDlg::doSave()
 {
-	if(lastPath.isEmpty())
-		lastPath = QDir::homeDirPath();
+	if(option.lastSavePath.isEmpty())
+		option.lastSavePath = QDir::homeDirPath();
 
 	UserListItem *u = d->pa->findFirstRelavent(d->jid);
 	QString them = jidnick(u->jid().full(), u->name());
 	QString s = qstrlower(jidEncode(them));
 
-	QString str = lastPath + "/" + s + ".txt";
+	QString str = option.lastSavePath + "/" + s + ".txt";
 	while(1) {
 		str = QFileDialog::getSaveFileName(str, tr("Text files (*.txt);;All files (*.*)"), this, 0, tr("Export message history"));
 		if(str.isEmpty())
@@ -292,7 +292,7 @@ void HistoryDlg::doSave()
 				continue;
 		}
 
-		lastPath = fi.dirPath();
+		option.lastSavePath = fi.dirPath();
 		exportHistory(str);
 		break;
 	}
