@@ -27,7 +27,11 @@
 #include<qlineedit.h>
 #include<qmessagebox.h>
 #include<qtextedit.h>
+#include<qfiledialog.h> 
+#include<qbuffer.h>
 #include"xmpp.h"
+#include"msgmle.h"
+#include"userlist.h"
 #include"xmpp_vcard.h"
 #include"xmpp_tasks.h"
 #include"psiaccount.h"
@@ -36,8 +40,9 @@
 #include"vcardfactory.h"
 #include"iconwidget.h"
 
-using namespace XMPP;
 
+using namespace XMPP;
+		
 class InfoDlg::Private
 {
 public:
@@ -52,6 +57,8 @@ public:
 	int actionType;
 	JT_VCard *jt;
 	bool cacheVCard;
+	PsiTextView* te_status;
+	QByteArray photo;
 };
 
 InfoDlg::InfoDlg(int type, const Jid &j, const VCard &vcard, PsiAccount *pa, QWidget *parent, const char *name, bool cacheVCard)
@@ -66,7 +73,7 @@ InfoDlg::InfoDlg(int type, const Jid &j, const VCard &vcard, PsiAccount *pa, QWi
 	d->jt = 0;
 	d->pa->dialogRegister(this, j);
 	d->cacheVCard = cacheVCard;
-
+	d->te_status = NULL;
 	d->busy = busy;
 
 	te_desc->setTextFormat(QTextEdit::PlainText);
@@ -77,13 +84,27 @@ InfoDlg::InfoDlg(int type, const Jid &j, const VCard &vcard, PsiAccount *pa, QWi
 #endif
 
 	connect(pb_refresh, SIGNAL(clicked()), this, SLOT(doRefresh()));
+	connect(pb_refresh, SIGNAL(clicked()), this, SLOT(updateStatus()));
 	connect(te_desc, SIGNAL(textChanged()), this, SLOT(textChanged()));
+	connect(pb_open, SIGNAL(clicked()), this, SLOT(selectPhoto()));
+	connect(pb_clear, SIGNAL(clicked()), this, SLOT(clearPhoto()));
 
 	if(d->type == Self) {
 		connect(pb_submit, SIGNAL(clicked()), this, SLOT(doSubmit()));
 	}
 	else {
+		// Add a status tab
+		d->te_status = new PsiTextView(tabwidget);
+		d->te_status->setReadOnly(true);
+		d->te_status->setTextFormat(RichText);
+		tabwidget->addTab(d->te_status, tr("Status"));
+		updateStatus();
+
+		// Hide buttons
 		pb_submit->hide();
+		pb_open->hide();
+		pb_clear->hide();
+		ly_photo->setSpacing(0);
 		setReadOnly(true);
 	}
 
@@ -206,10 +227,34 @@ void InfoDlg::setData(const VCard &i)
 	le_title->setText( i.title() );
 	le_role->setText( i.role() );
 	te_desc->setText( i.desc() );
+	
+	if ( !i.photo().isEmpty() ) {
+		//printf("There is a picture...\n");
+		d->photo = i.photo();
+		updatePhoto();
+	}
+	else
+		clearPhoto();
 
 	setEdited(false);
 }
 
+void InfoDlg::updatePhoto() 
+{
+	int max_width = label_photo->width() - 20; // FIXME: Ugly magic number
+	int max_height = label_photo->height() - 20; // FIXME: Ugly magic number
+	
+	QImage img(d->photo);
+	QImage img_scaled;
+	if (img.width() > max_width || img.height() > max_height) {
+		img_scaled = img.smoothScale(max_width, max_height,QImage::ScaleMin);
+	}
+	else {
+		img_scaled = img;
+	}
+	label_photo->setPixmap(QPixmap(img_scaled));
+}
+
 void InfoDlg::fieldsEnable(bool x)
 {
 	le_fullname->setEnabled(x);
@@ -218,6 +263,8 @@ void InfoDlg::fieldsEnable(bool x)
 	le_email->setEnabled(x);
 	le_homepage->setEnabled(x);
 	le_phone->setEnabled(x);
+	pb_open->setEnabled(x);
+	pb_clear->setEnabled(x);
 
 	le_street->setEnabled(x);
 	le_ext->setEnabled(x);
@@ -377,6 +424,11 @@ VCard InfoDlg::makeVCard()
 		list << p;
 		v.setPhoneList( list );
 	}
+	
+	if ( !d->photo.isEmpty() ) {
+		//printf("Adding a pixmap to the vCard...\n");
+		v.setPhoto( d->photo );
+	}
 
 	if ( !le_street->text().isEmpty() ||
 	     !le_ext->text().isEmpty()    ||
@@ -419,3 +471,79 @@ void InfoDlg::textChanged()
 {
 	d->te_edited = true;
 }
+
+/*!
+ * Opens a file browser dialog, and if selected, calls the setPreviewPhoto with the consecuent path.
+ * \see setPreviewPhoto(const QString& path)
+*/
+void InfoDlg::selectPhoto()
+{
+	while(1) {
+		if(option.lastPath.isEmpty())
+			option.lastPath = QDir::homeDirPath();
+		QString str = QFileDialog::getOpenFileName(option.lastPath, tr("Images (*.png *.xpm *.jpg *.PNG *.XPM *.JPG)"), this, 0, tr("Choose a file"));
+		if(!str.isEmpty()) {
+			QFileInfo fi(str);
+			if(!fi.exists()) {
+				QMessageBox::information(this, tr("Error"), tr("The file specified does not exist."));
+				continue;
+			}
+			option.lastPath = fi.dirPath();
+			//printf(QDir::convertSeparators(fi.filePath()));
+			
+			// put the image in the preview box
+			setPreviewPhoto(str);
+		}
+		break;
+	}
+	
+}
+
+/*!
+ * Loads the image from the requested URL, and inserts the resized image into the preview box.
+ * \param path image file to load
+*/
+void InfoDlg::setPreviewPhoto(const QString& path)
+{
+	QFile photo_file(path);
+	if (!photo_file.open(IO_ReadOnly))
+		return;
+	
+	QByteArray photo_data = photo_file.readAll();
+	QImage photo_image(photo_data);
+	if(!photo_image.isNull()) {
+		d->photo = photo_data;
+		updatePhoto();
+		d->te_edited = true;
+	}
+}
+
+/*!
+ * Clears the preview image box and marks the te_edited signal in the private.
+*/
+void InfoDlg::clearPhoto()
+{
+	// this will cause the pixmap disappear
+	label_photo->setText(tr("Picture not\navailable"));
+	d->photo = QByteArray();
+	
+	// the picture changed, so notify there are some changes done
+	d->te_edited = true;
+}
+
+/*!
+ * Updates the status info of the contact
+ */
+void InfoDlg::updateStatus()
+{
+	if (!d->te_status)
+		return;
+
+	UserListItem *u = d->pa->find(d->jid);
+	if(u) {
+		d->te_status->setText(u->makeDesc());
+	}
+	else {
+		d->te_status->clear();
+	}
+}
