@@ -42,15 +42,19 @@ public:
 protected:
 	// reimplemented
 	//void closeEvent(QCloseEvent *);
+	void updatePhoto();
 
 public slots:
 	void doRefresh();
+	void updateStatus();
 	void done(int);
 
 private slots:
 	void jt_finished();
 	void doSubmit();
 	void textChanged();
+	void selectPhoto();
+	void clearPhoto();
 
 private:
 	class Private;
@@ -62,6 +66,7 @@ private:
 	void setReadOnly(bool);
 	bool edited();
 	void setEdited(bool);
+	void setPreviewPhoto(const QString& str);
 };
 
 #endif
