@@ -94,9 +94,7 @@ public:
 	QMap<QAction *, int> statusActions;
 
 	int lastStatus;
-#ifdef Q_WS_MAC
 	QMenuBar *gm;
-#endif
 
 	QString infoString;
 
@@ -186,7 +184,7 @@ IconAction *MainWin::Private::getAction( QString name )
 //#endif
 
 MainWin::MainWin(bool _onTop, bool _asTool, PsiCon *psi, const char *name)
-:QMainWindow(0, name, 0 | (_onTop ? WStyle_StaysOnTop: 0) | (_asTool ? WStyle_Tool | TOOLW_FLAGS : 0))
+:AdvancedWidget<QMainWindow>(0, name, 0 | (_onTop ? WStyle_StaysOnTop: 0) | (_asTool ? WStyle_Tool | TOOLW_FLAGS : 0))
 {
 	d = new Private(psi, this);
 
@@ -247,9 +245,16 @@ MainWin::MainWin(bool _onTop, bool _asTool, PsiCon *psi, const char *name)
 	if ( option.showTips )
 		actTipActivated();
 
-	// create a menubar on Mac
 #ifdef Q_WS_MAC
+	// Create a global menubar
 	d->gm = new QMenuBar(0);
+#else
+	// Create a menu for the current window
+	d->gm = new QMenuBar(this);
+#endif
+
+	// Mac-only menus
+#ifdef Q_WS_MAC
 	QPopupMenu *mainMenu = new QPopupMenu(this);
 	d->gm->insertItem(tr("Menu"), mainMenu);
 	mainMenu->insertItem(tr("Preferences"), this, SIGNAL(doOptions()));
@@ -260,6 +265,9 @@ MainWin::MainWin(bool _onTop, bool _asTool, PsiCon *psi, const char *name)
 	d->mainMenu = new QPopupMenu(this);
 	d->gm->insertItem(tr("General"), d->mainMenu);
 	connect(d->mainMenu, SIGNAL(aboutToShow()), SLOT(buildMainMenu()));
+#else
+	d->gm->insertItem(tr("General"), d->optionsMenu);
+#endif
 
 	d->gm->insertItem(tr("Status"), d->statusMenu);
 
@@ -271,6 +279,8 @@ MainWin::MainWin(bool _onTop, bool _asTool, PsiCon *psi, const char *name)
 	d->getAction("show_agents")->addTo(viewMenu);
 	d->getAction("show_self")->addTo(viewMenu);
 
+	// Mac-only menus
+#ifdef Q_WS_MAC
 	d->toolsMenu = new QPopupMenu(this);
 	d->gm->insertItem(tr("Tools"), d->toolsMenu);
 	connect(d->toolsMenu, SIGNAL(aboutToShow()), SLOT(buildToolsMenu()));
@@ -281,21 +291,33 @@ MainWin::MainWin(bool _onTop, bool _asTool, PsiCon *psi, const char *name)
 	d->getAction("help_tip")->addTo (helpMenu);
 	helpMenu->insertSeparator();
 	d->getAction("help_online_help")->addTo (helpMenu);
+	d->getAction("help_online_wiki")->addTo (helpMenu);
+	d->getAction("help_online_home")->addTo (helpMenu);
 	d->getAction("help_report_bug")->addTo (helpMenu);
 
 	d->gm->show();
+#else
+	if (option.hideMenubar) 
+		d->gm->hide();
+	else 
+		d->gm->show();
+#endif
+	
+#if QT_VERSION >= 0x030300
+	setWindowOpacity(double(option.rosterOpacity)/100);
 #endif
 
 	connect(qApp, SIGNAL(dockActivated()), SLOT(dockActivated()));
 }
+	
 
 MainWin::~MainWin()
 {
 	PsiPopup::deleteAll();
 
-#ifdef Q_WS_MAC
-	delete d->gm;
-#endif
+	if (d->gm)
+		delete d->gm;
+
 	if(d->tray) {
 		delete d->tray;
 		d->tray = 0;
@@ -351,6 +373,8 @@ void MainWin::registerAction( IconAction *action )
 		{ "help_readme",      activated, this, SLOT( actReadmeActivated() ) },
 		{ "help_tip",         activated, this, SLOT( actTipActivated() ) },
 		{ "help_online_help", activated, this, SLOT( actOnlineHelpActivated() ) },
+		{ "help_online_wiki", activated, this, SLOT( actOnlineWikiActivated() ) },
+		{ "help_online_home", activated, this, SLOT( actOnlineHomeActivated() ) },
 		{ "help_report_bug",  activated, this, SLOT( actBugReportActivated() ) },
 		{ "help_about",       activated, this, SLOT( actAboutActivated() ) },
 		{ "help_about_qt",    activated, this, SLOT( actAboutQtActivated() ) },
@@ -561,6 +585,8 @@ void MainWin::buildOptionsMenu()
 	actionNames << "help_tip";
 	actionNames << "separator";
 	actionNames << "help_online_help";
+	actionNames << "help_online_wiki";
+	actionNames << "help_online_home";
 	actionNames << "help_report_bug";
 	actionNames << "separator";
 	actionNames << "help_about";
@@ -622,7 +648,7 @@ void MainWin::buildToolsMenu()
 	if ( (action = d->getAction("menu_xml_console")) )
 		action->addTo(d->toolsMenu);
 }
-
+	
 void MainWin::buildGeneralMenu(QPopupMenu *menu)
 {
 	menu->clear();
@@ -643,6 +669,7 @@ void MainWin::buildGeneralMenu(QPopupMenu *menu)
 	actionNames << "menu_file_transfer"; // TODO: probably we want to lock down filetransfer, right?
 	if(!option.lockdown.profiles)
 		actionNames << "menu_change_profile";
+	actionNames << "menu_toolbars";
 	actionNames << "menu_play_sounds";
 
 	QStringList::Iterator it;
@@ -671,12 +698,22 @@ void MainWin::actReadmeActivated ()
 
 void MainWin::actOnlineHelpActivated ()
 {
-	openURL("http://psi.affinix.com/psi_docs/");
+	openURL("http://psi-im.org/wiki/User_Guide");
+}
+
+void MainWin::actOnlineWikiActivated ()
+{
+	openURL("http://psi-im.org/wiki");
+}
+
+void MainWin::actOnlineHomeActivated ()
+{
+	openURL("http://psi-im.org");
 }
 
 void MainWin::actBugReportActivated ()
 {
-	openURL("http://psi.affinix.com/forums/index.php?act=SF&f=2");
+	openURL("http://psi-im.org/forum/forum/2");
 }
 
 void MainWin::actAboutActivated ()
@@ -863,9 +900,26 @@ void MainWin::optionsUpdate()
 	d->lastStatus = -2;
 	decorateButton(status);
 
+	if (option.hideMenubar) 
+		d->gm->hide();
+	else 
+		d->gm->show();
+	
+#if QT_VERSION >= 0x030300
+	setWindowOpacity(double(option.rosterOpacity)/100);
+#endif
+	
 	updateTray();
 }
 
+void MainWin::toggleVisible()
+{
+	if(!isHidden())
+		trayHide();
+	else
+		trayShow();
+}
+
 void MainWin::setTrayToolTip(const Status &status)
 {
 	if (!d->tray)
@@ -931,13 +985,6 @@ void MainWin::trayHide()
 
 void MainWin::updateReadNext(Icon *anim, int amount)
 {
-#ifdef Q_WS_MAC
-	if(amount > 0)
-		bounceDockTile();
-	else
-		stopDockTileBounce();
-#endif
-
 	d->nextAnim = anim;
 	if(anim == 0)
 		d->nextAmount = 0;
