@@ -669,40 +669,22 @@ MAction &MAction::operator=( const MAction &from )
 // SpacerAction
 //----------------------------------------------------------------------------
 
-class SpacerAction::Private
-{
-public:
-	Private() { }
-
-	class StretchWidget : public QWidget
-	{
-	public:
-		StretchWidget(QWidget *parent)
-		: QWidget(parent)
-		{
-			setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
-		}
-	};
-};
-
 SpacerAction::SpacerAction(QObject *parent, const char *name)
 : IconAction(parent, name)
 {
-	d = new Private;
 	setText(tr("<Spacer>"));
 	setMenuText(tr("<Spacer>"));
-	setWhatsThis (tr("Spacer provides spacing to separate actions"));
+	setWhatsThis(tr("Spacer provides spacing to separate actions"));
 }
 
 SpacerAction::~SpacerAction()
 {
-	delete d;
 }
 
 bool SpacerAction::addTo(QWidget *w)
 {
 	if ( w->inherits("QToolBar") ) {
-		new Private::StretchWidget(w);
+		new StretchWidget(w);
 		return true;
 	}
 
