@@ -32,9 +32,15 @@ QWidget *OptionsTabAdvanced::widget()
 	w = new OptAdvancedUI();
 	OptAdvancedUI *d = (OptAdvancedUI *)w;
 
+#ifdef Q_WS_X11	// auto-copy is a built-in feature on linux, we don't want user to use our own one
+	d->ck_autocopy->hide();
+#endif
+
 	QWhatsThis::add(d->ck_messageevents,
 		tr("Enables the sending and requesting of message events such as "
 		"'Contact is Typing', ..."));
+	QWhatsThis::add(d->ck_autocopy,
+		tr("Check this option if you want the selected text in incoming messages and chat log to be automatically copied to clipboard"));
 	QWhatsThis::add(d->ck_singleclick,
 		tr("Normally, a double-click on a contact will invoke the default action."
 		"  Check this option if you'd rather invoke with a single-click."));
@@ -74,6 +80,7 @@ void OptionsTabAdvanced::applyOptions(Options *opt)
 	OptAdvancedUI *d = (OptAdvancedUI *)w;
 
 	opt->messageEvents = d->ck_messageevents->isChecked();
+	opt->autoCopy = d->ck_autocopy->isChecked();
 	opt->singleclick = d->ck_singleclick->isChecked();
 	opt->jidComplete = d->ck_jidComplete->isChecked();
 	opt->grabUrls    = d->ck_grabUrls->isChecked();
@@ -95,6 +102,7 @@ void OptionsTabAdvanced::restoreOptions(const Options *opt)
 	OptAdvancedUI *d = (OptAdvancedUI *)w;
 
 	d->ck_messageevents->setChecked( opt->messageEvents );
+	d->ck_autocopy->setChecked( opt->autoCopy );
 	d->ck_singleclick->setChecked( opt->singleclick );
 	d->ck_jidComplete->setChecked( opt->jidComplete );
 	d->ck_grabUrls->setChecked( opt->grabUrls );
