@@ -1,9 +1,12 @@
 #include "opt_appearance.h"
+#include "opt_iconset.h"
 #include "common.h"
 #include "iconwidget.h"
 
 #include <qwhatsthis.h>
 #include <qcheckbox.h>
+#include <qslider.h>
+#include <qlabel.h>
 #include <qcombobox.h>
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
@@ -14,6 +17,7 @@
 #include <qlineedit.h>
 
 #include "opt_appearance-ui.h"
+#include "opt_appearance_misc-ui.h"
 
 //----------------------------------------------------------------------------
 // FontLabel
@@ -47,12 +51,88 @@ QSize FontLabel::sizeHint() const
 	return QSize(QLineEdit::sizeHint().width(), m_defaultHeight);
 }
 
+
 //----------------------------------------------------------------------------
 // OptionsTabAppearance
 //----------------------------------------------------------------------------
+OptionsTabAppearance::OptionsTabAppearance(QObject *parent) : MetaOptionsTab(parent, "appearance", "", tr("Appearance"), tr("Psi's Appearance"), "psi/appearance")
+{    
+	addTab( new OptionsTabAppearanceGeneral(this) );
+	addTab( new OptionsTabIconsetEmoticons(this) );
+	addTab( new OptionsTabIconsetRoster(this) );
+	addTab( new OptionsTabIconsetSystem(this) );
+	addTab( new OptionsTabAppearanceMisc(this) );
+}
 
-OptionsTabAppearance::OptionsTabAppearance(QObject *parent)
-: OptionsTab(parent, "appearance", "", tr("Appearance"), tr("Psi's Appearance"), "psi/ok")
+//----------------------------------------------------------------------------
+// OptionsTabAppearanceMisc
+//----------------------------------------------------------------------------
+
+OptionsTabAppearanceMisc::OptionsTabAppearanceMisc(QObject *parent)
+: OptionsTab(parent, "appearance_misc", "", tr("Misc."), tr("Miscellaneous Settings"))
+{
+	w = 0;
+	o = new Options;
+}
+
+OptionsTabAppearanceMisc::~OptionsTabAppearanceMisc()
+{
+	delete o;
+}
+
+QWidget *OptionsTabAppearanceMisc::widget()
+{
+	if ( w )
+		return 0;
+
+	w = new OptAppearanceMiscUI();
+
+#if defined(Q_WS_X11) || (QT_VERSION < 0x030300)
+	OptAppearanceMiscUI *d = (OptAppearanceMiscUI *)w;
+	d->gb_opacity->hide();
+#endif
+
+	return w;
+}
+
+void OptionsTabAppearanceMisc::applyOptions(Options *opt)
+{
+	if ( !w )
+		return;
+
+	OptAppearanceMiscUI *d = (OptAppearanceMiscUI *)w;
+
+	opt->clNewHeadings = d->ck_newHeadings->isChecked();	
+	opt->outlineHeadings = d->ck_outlineHeadings->isChecked();	
+	opt->rosterOpacity = d->sl_rosterop->value();
+	opt->chatOpacity = d->sl_chatdlgop->value();
+}
+
+void OptionsTabAppearanceMisc::restoreOptions(const Options *opt)
+{
+	if ( !w )
+		return;
+
+	OptAppearanceMiscUI *d = (OptAppearanceMiscUI *)w;
+
+	d->ck_newHeadings->setChecked( opt->clNewHeadings );
+	d->ck_outlineHeadings->setChecked( opt->outlineHeadings );
+	
+	d->sl_rosterop->setValue( opt->rosterOpacity );
+	d->sl_chatdlgop->setValue( opt->chatOpacity );
+}
+
+void OptionsTabAppearanceMisc::setData(PsiCon *, QWidget *parentDialog)
+{
+	parentWidget = parentDialog;
+}
+
+//----------------------------------------------------------------------------
+// OptionsTabAppearanceGeneral: Fonts & Colours
+//----------------------------------------------------------------------------
+
+OptionsTabAppearanceGeneral::OptionsTabAppearanceGeneral(QObject *parent)
+: OptionsTab(parent, "appearance_general", "", tr("Fonts && Colors"), tr("Fonts && Color Settings"))
 {
 	w = 0;
 	bg_font = 0;
@@ -60,7 +140,7 @@ OptionsTabAppearance::OptionsTabAppearance(QObject *parent)
 	o = new Options;
 }
 
-OptionsTabAppearance::~OptionsTabAppearance()
+OptionsTabAppearanceGeneral::~OptionsTabAppearanceGeneral()
 {
 	if ( bg_font )
 		delete bg_font;
@@ -83,7 +163,7 @@ static QPixmap name2color(QString name) // taken from opt_general.cpp
 	return pix;
 }
 
-QWidget *OptionsTabAppearance::widget()
+QWidget *OptionsTabAppearanceGeneral::widget()
 {
 	if ( w )
 		return 0;
@@ -123,11 +203,13 @@ QWidget *OptionsTabAppearance::widget()
 	bg_color->insert(d->pb_cOffline, 1);
 	bg_color->insert(d->pb_cAway, 2);
 	bg_color->insert(d->pb_cDND, 3);
-	bg_color->insert(d->pb_cGroupFore, 4);
-	bg_color->insert(d->pb_cGroupBack, 5);
-	bg_color->insert(d->pb_cListBack, 6);
-	bg_color->insert(d->pb_cAnimFront, 7);
-	bg_color->insert(d->pb_cAnimBack, 8);
+	bg_color->insert(d->pb_cProfileFore, 4);
+	bg_color->insert(d->pb_cProfileBack, 5);
+	bg_color->insert(d->pb_cGroupFore, 6);
+	bg_color->insert(d->pb_cGroupBack, 7);
+	bg_color->insert(d->pb_cListBack, 8);
+	bg_color->insert(d->pb_cAnimFront, 9);
+	bg_color->insert(d->pb_cAnimBack, 10);
 	connect(bg_color, SIGNAL(clicked(int)), SLOT(chooseColor(int)));
 
 	QString s = tr("Specifies the text color for a contact name in the main window when that user is \"%1\".");
@@ -139,6 +221,8 @@ QWidget *OptionsTabAppearance::widget()
 		s.arg(tr("away")));
 	QWhatsThis::add(d->pb_cDND,
 		s.arg(tr("do not disturb")));
+	QWhatsThis::add(d->pb_cProfileBack,
+		tr("Specifies the background color for an account name in the main window."));
 	QWhatsThis::add(d->pb_cGroupBack,
 		tr("Specifies the background color for a group name in the main window."));
 	QWhatsThis::add(d->pb_cListBack,
@@ -155,7 +239,7 @@ QWidget *OptionsTabAppearance::widget()
 	return w;
 }
 
-void OptionsTabAppearance::applyOptions(Options *opt)
+void OptionsTabAppearanceGeneral::applyOptions(Options *opt)
 {
 	if ( !w )
 		return;
@@ -167,11 +251,11 @@ void OptionsTabAppearance::applyOptions(Options *opt)
 	for (n = 0; n < 4; ++n)
 		opt->font[n] = le_font[n]->fontName();
 
-	for (n = 0; n < 9; ++n)
+	for (n = 0; n < 11; ++n)
 		opt->color[n] = o->color[n];
 }
 
-void OptionsTabAppearance::restoreOptions(const Options *opt)
+void OptionsTabAppearanceGeneral::restoreOptions(const Options *opt)
 {
 	if ( !w )
 		return;
@@ -183,18 +267,18 @@ void OptionsTabAppearance::restoreOptions(const Options *opt)
 	for (n = 0; n < 4; ++n)
 		le_font[n]->setFont(opt->font[n]);
 
-	for (n = 0; n < 9; ++n) {
+	for (n = 0; n < 11; ++n) {
 		o->color[n] = opt->color[n];
 		((QPushButton *)bg_color->find(n))->setPixmap(name2color(opt->color[n].name()));
 	}
 }
 
-void OptionsTabAppearance::setData(PsiCon *, QWidget *parentDialog)
+void OptionsTabAppearanceGeneral::setData(PsiCon *, QWidget *parentDialog)
 {
 	parentWidget = parentDialog;
 }
 
-void OptionsTabAppearance::chooseFont(int x)
+void OptionsTabAppearanceGeneral::chooseFont(int x)
 {
 	bool ok;
 	QFont font;
@@ -207,7 +291,7 @@ void OptionsTabAppearance::chooseFont(int x)
 		emit dataChanged();
 }
 
-void OptionsTabAppearance::chooseColor(int x)
+void OptionsTabAppearanceGeneral::chooseColor(int x)
 {
 	QColor c = o->color[x];
 
