@@ -1,5 +1,5 @@
-#ifndef OPT_APPEARANCE_H
-#define OPT_APPEARANCE_H
+#ifndef OPT_APPEARANCEGENERAL_H
+#define OPT_APPEARANCEGENERAL_H
 
 #include "optionstab.h"
 
@@ -26,12 +26,38 @@ struct Options;
 class QButtonGroup;
 class QLineEdit;
 
-class OptionsTabAppearance : public OptionsTab
+class OptionsTabAppearance : public MetaOptionsTab
 {
 	Q_OBJECT
 public:
 	OptionsTabAppearance(QObject *parent);
-	~OptionsTabAppearance();
+};
+
+class OptionsTabAppearanceMisc : public OptionsTab
+{
+	Q_OBJECT
+public:
+	OptionsTabAppearanceMisc(QObject *parent);
+	~OptionsTabAppearanceMisc();
+
+	QWidget *widget();
+	void applyOptions(Options *opt);
+	void restoreOptions(const Options *opt);
+
+private slots:
+	void setData(PsiCon *, QWidget *);
+
+private:
+	QWidget *w, *parentWidget;
+	Options *o;
+};
+
+class OptionsTabAppearanceGeneral : public OptionsTab
+{
+	Q_OBJECT
+public:
+	OptionsTabAppearanceGeneral(QObject *parent);
+	~OptionsTabAppearanceGeneral();
 
 	QWidget *widget();
 	void applyOptions(Options *opt);
