@@ -34,12 +34,17 @@ QWidget *OptionsTabApplication::widget()
 
 	QWhatsThis::add(d->ck_alwaysOnTop,
 		tr("Makes the main Psi window always be in front of other windows."));
+	QWhatsThis::add(d->ck_autoRosterSize,
+		tr("Makes the main Psi window resize automatically to fit all contacts."));
 	QWhatsThis::add(d->ck_keepSizes,
 		tr("Makes Psi remember window size and positions for chats and messages."
 		"  If disabled, the windows will always appear in their default positions and sizes."));
 	QWhatsThis::add(d->ck_useleft,
 		tr("Normally, right-clicking with the mouse on a contact will activate the context-menu."
 		"  Check this option if you'd rather use a left-click."));
+	QWhatsThis::add(d->ck_hideMenubar,
+		tr("Hides the menubar in the application window."));
+	connect(d->ck_hideMenubar, SIGNAL(toggled(bool)), this, SLOT(hideMenubarToggled(bool)));
 
 	// links
 	QWhatsThis::add(d->cb_link,
@@ -66,8 +71,15 @@ QWidget *OptionsTabApplication::widget()
 	QWhatsThis::add(d->ck_dockUseWM,
 		tr("If checked, Psi will use the Window Maker docklet instead of FreeDesktop one."));
 
+#ifdef Q_WS_MAC
+	d->ck_alwaysOnTop->hide();
+	d->ck_hideMenubar->hide();
+	d->gb_links->hide();
+	d->ck_docklet->hide();
+	d->gb_docklet->hide();
+#endif
 #ifndef Q_WS_X11
-	d->ck_dockUseWM->setEnabled(false);
+	d->ck_dockUseWM->hide();
 #endif
 
 	return w;
@@ -83,8 +95,10 @@ void OptionsTabApplication::applyOptions(Options *opt)
 	OptApplicationUI *d = (OptApplicationUI *)w;
 
 	opt->alwaysOnTop = d->ck_alwaysOnTop->isChecked();
+	opt->autoRosterSize = d->ck_autoRosterSize->isChecked();
 	opt->keepSizes   = d->ck_keepSizes->isChecked();
 	opt->useleft = d->ck_useleft->isChecked();
+	opt->hideMenubar = d->ck_hideMenubar->isChecked();
 
 	// links
 #ifdef Q_WS_X11
@@ -114,12 +128,10 @@ void OptionsTabApplication::restoreOptions(const Options *opt)
 
 	OptApplicationUI *d = (OptApplicationUI *)w;
 
-#ifdef Q_WS_MAC
-	d->ck_alwaysOnTop->setEnabled( false );
-#else
 	d->ck_alwaysOnTop->setChecked( opt->alwaysOnTop );
-#endif
+	d->ck_autoRosterSize->setChecked( opt->autoRosterSize );
 	d->ck_keepSizes->setChecked( opt->keepSizes );
+	d->ck_hideMenubar->setChecked( opt->hideMenubar );
 	d->ck_useleft->setChecked( opt->useleft );
 
 	// links
@@ -139,7 +151,7 @@ void OptionsTabApplication::restoreOptions(const Options *opt)
 	selectBrowser( rbi );
 #endif
 #ifdef Q_WS_MAC
-	d->cb_link->insertItem(tr("MacOS Default Browser/Mail"));
+	d->cb_link->insertItem(tr("Mac OS Default Browser/Mail"));
 	d->cb_link->setCurrentItem( opt->browser );
 	selectBrowser( opt->browser );
 #endif
@@ -147,16 +159,11 @@ void OptionsTabApplication::restoreOptions(const Options *opt)
 	d->le_linkMailer->setText( opt->customMailer );
 
 	// docklet
-#ifdef Q_WS_MAC
-	d->ck_docklet->setChecked( false );
-	d->ck_docklet->setEnabled( false );
-#else
 	d->ck_docklet->setChecked( opt->useDock );
 	d->ck_dockDCstyle->setChecked( opt->dockDCstyle );
 	d->ck_dockHideMW->setChecked( opt->dockHideMW );
 	d->ck_dockToolMW->setChecked( opt->dockToolMW );
 	d->ck_dockUseWM->setChecked( opt->isWMDock );
-#endif
 
 	// data transfer
 	d->le_dtPort->setText( QString::number(opt->dtPort) );
@@ -186,3 +193,31 @@ void OptionsTabApplication::selectBrowser(int x)
 	OptApplicationUI *d = (OptApplicationUI *)w;
 	d->gb_linkCustom->setEnabled(enableCustom);
 }
+
+#ifndef Q_WS_MAC
+void OptionsTabApplication::hideMenubarToggled(bool toggle)
+{
+	if (toggle == true) {
+		// check if all toolbars are disabled
+		bool toolbarsVisible = false;
+		QValueList<Options::ToolbarPrefs>::ConstIterator it = option.toolbars["mainWin"].begin();
+		for ( ; it != option.toolbars["mainWin"].end() && !toolbarsVisible; ++it) {
+			toolbarsVisible = toolbarsVisible || (*it).on;
+		}
+
+		// Check whether it is legal to disable the menubar
+		if ( !toolbarsVisible ) {
+			QMessageBox::warning(0, tr("Warning"),
+				tr("You can not disable <i>all</i> toolbars <i>and</i> the menubar. If you do so, you will be unable to enable them back, when you'll change your mind.\n"
+					"<br><br>\n"
+					"If you really-really want to disable all toolbars and the menubar, you need to edit the config.xml file by hand."),
+				tr("I understand"));
+			((OptApplicationUI *)w)->ck_hideMenubar->setChecked(false);
+		}
+	}
+}
+#else
+void OptionsTabApplication::hideMenubarToggled(bool)
+{
+}
+#endif
