@@ -15,7 +15,7 @@
 //----------------------------------------------------------------------------
 
 OptionsTabChat::OptionsTabChat(QObject *parent)
-: OptionsTab(parent, "chat", "", tr("Chat"), tr("Configure the chat dialog"), "psi/chat")
+: OptionsTab(parent, "chat", "", tr("Chat"), tr("Configure the chat dialog"), "psi/start-chat")
 {
 	w = 0;
 	bg_delChats = bg_defAct = 0;
@@ -73,8 +73,10 @@ QWidget *OptionsTabChat::widget()
 	QWhatsThis::add(d->ck_raiseChatWindow,
 		tr("Makes Psi bring an open chat window to the front of your screen when you receive a new message."
 		" It does not take the keyboard focus, so it will not interfere with your work."));
-        QWhatsThis::add(d->ck_smallChats,
-                tr("Makes Psi open chat windows in compact mode."));
+	QWhatsThis::add(d->ck_smallChats,
+		tr("Makes Psi open chat windows in compact mode."));
+	QWhatsThis::add(d->ck_tabChats,
+		tr("Makes Psi open chats in a tabbed window."));
 	QString s = tr("<P>Controls how long the chat log will be kept in memory after the"
 		" chat window is closed.</P>");
 	QWhatsThis::add(d->rb_delChatsClose, s +
@@ -101,9 +103,11 @@ void OptionsTabChat::applyOptions(Options *opt)
 	opt->chatSoftReturn  = d->ck_chatSoftReturn->isChecked();
 	opt->alertOpenChats  = d->ck_alertOpenChats->isChecked();
 	opt->raiseChatWindow = d->ck_raiseChatWindow->isChecked();
-	opt->oldSmallChats = opt->smallChats;
-        opt->smallChats      = d->ck_smallChats->isChecked();
+	opt->oldSmallChats 	 = opt->smallChats;
+	opt->smallChats      = d->ck_smallChats->isChecked();
 	opt->delChats        = bg_delChats->id( bg_delChats->selected() );
+	opt->useTabs		 = d->ck_tabChats->isChecked();
+	opt->chatLineEdit    = d->ck_autoResize->isChecked();
 }
 
 void OptionsTabChat::restoreOptions(const Options *opt)
@@ -118,6 +122,8 @@ void OptionsTabChat::restoreOptions(const Options *opt)
 	d->ck_chatSoftReturn->setChecked( opt->chatSoftReturn );
 	d->ck_alertOpenChats->setChecked( opt->alertOpenChats );
 	d->ck_raiseChatWindow->setChecked( opt->raiseChatWindow );
-        d->ck_smallChats->setChecked( opt->smallChats );
+	d->ck_smallChats->setChecked( opt->smallChats );
+	d->ck_tabChats->setChecked( opt->useTabs );
+	d->ck_autoResize->setChecked( opt->chatLineEdit );
 	bg_delChats->setButton( opt->delChats );
 }
