@@ -6,6 +6,7 @@
 #include <qwhatsthis.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
+#include <qlabel.h>
 #include <qcombobox.h>
 #include <qlineedit.h>
 
@@ -16,7 +17,7 @@
 //----------------------------------------------------------------------------
 
 OptionsTabEvents::OptionsTabEvents(QObject *parent)
-: OptionsTab(parent, "events", "", tr("Events"), tr("The events behaviour"), "psi/system")
+: OptionsTab(parent, "events", "", tr("Events"), tr("The events behaviour"), "psi/events")
 {
 	w = 0;
 }
@@ -55,6 +56,13 @@ QWidget *OptionsTabEvents::widget()
 		tr("Animates incoming event icons on the main window as events are recieved."));
 	QWhatsThis::add(d->ck_autoAuth,
 		tr("Makes Psi automatically accept all authorization requests from <b>anyone</b>."));
+	QWhatsThis::add(d->ck_notifyAuth,
+		tr("Makes Psi notify you when your authorization request was approved."));
+
+#ifndef Q_WS_MAC
+	d->cb_bounce->hide();
+	d->lb_bounce->hide();
+#endif
 
 	return w;
 }
@@ -75,6 +83,8 @@ void OptionsTabEvents::applyOptions(Options *opt)
 	opt->ignoreNonRoster = d->ck_ignoreNonRoster->isChecked();
 	opt->alertStyle = alertStyle;
 	opt->autoAuth = d->ck_autoAuth->isChecked();
+	opt->notifyAuth = d->ck_notifyAuth->isChecked();
+	opt->bounceDock = (Options::BounceDockSetting) d->cb_bounce->currentItem();
 
 	opt->ppIsOn = d->ck_popupOn->isChecked();
 	opt->ppMessage = d->ck_popupOnMessage->isChecked();
@@ -102,6 +112,8 @@ void OptionsTabEvents::restoreOptions(const Options *opt)
 	alertStyle = opt->alertStyle;
 	d->bg_alerts->setButton( alertStyle );
 	d->ck_autoAuth->setChecked( opt->autoAuth );
+	d->ck_notifyAuth->setChecked( opt->notifyAuth );
+	d->cb_bounce->setCurrentItem( opt->bounceDock );
 
 	d->ck_popupOn->setChecked( true );
 	d->ck_popupOn->setChecked( opt->ppIsOn );
