@@ -390,6 +390,7 @@ void OptionsTabGeneralNotifications::applyOptions(Options *opt)
 	opt->ppMessage = d->ck_popupOnMessage->isChecked();
 	opt->ppChat    = d->ck_popupOnChat->isChecked();
 	opt->ppHeadline = d->ck_popupOnHeadline->isChecked();
+	opt->ppFile    = d->ck_popupOnFile->isChecked();
 	opt->ppStatus  = d->ck_popupOnStatus->isChecked();
 	opt->ppOnline  = d->ck_popupOnOnline->isChecked();
 	opt->ppOffline = d->ck_popupOnOffline->isChecked();
@@ -406,6 +407,7 @@ void OptionsTabGeneralNotifications::restoreOptions(const Options *opt)
 	d->ck_popupOnMessage->setChecked( opt->ppMessage );
 	d->ck_popupOnChat->setChecked( opt->ppChat );
 	d->ck_popupOnHeadline->setChecked( opt->ppHeadline );
+	d->ck_popupOnFile->setChecked( opt->ppFile );
 	d->ck_popupOnStatus->setChecked( opt->ppStatus );
 	d->ck_popupOnOnline->setChecked( opt->ppOnline );
 	d->ck_popupOnOffline->setChecked( opt->ppOffline );
