@@ -28,10 +28,9 @@
 
 static void isDetails(const Iconset &is, QWidget *parent)
 {
-	IconsetDetailsDlg *isd = new IconsetDetailsDlg(parent, "IconsetDetailsDlg", true);
+	IconsetDetailsDlg *isd = new IconsetDetailsDlg(parent, "IconsetDetailsDlg", false, QWidget::WDestructiveClose);
 	isd->setIconset(is);
-	isd->exec();
-	delete isd;
+	isd->show();
 }
 
 static QStringList dirs;
@@ -264,7 +263,7 @@ getout:
 //----------------------------------------------------------------------------
 
 OptionsTabIconsetSystem::OptionsTabIconsetSystem(QObject *parent)
-: OptionsTab(parent, "iconset_system", "", tr("System Iconset"), tr("Select the system iconset"), "psi/info")
+: OptionsTab(parent, "iconset_system", "", tr("System Icons"), tr("Select the system iconset"))
 {
 	w = 0;
 	thread = 0;
@@ -417,7 +416,7 @@ void OptionsTabIconsetSystem::cancelThread()
 //----------------------------------------------------------------------------
 
 OptionsTabIconsetEmoticons::OptionsTabIconsetEmoticons(QObject *parent)
-: OptionsTab(parent, "iconset_emoticons", "", tr("Emoticons"), tr("Select your emoticon iconsets"), "psi/smile")
+: OptionsTab(parent, "iconset_emoticons", "", tr("Emoticons"), tr("Select your emoticon iconsets"))
 {
 	w = 0;
 	thread = 0;
@@ -445,7 +444,7 @@ QWidget *OptionsTabIconsetEmoticons::widget()
 	QWhatsThis::add(d->ck_useEmoticons,
 		tr("<P>Emoticons are short sequences of characters that are used to convey an emotion or idea.</P>"
 		"<P>Enable this option if you want Psi to replace common emoticons with a graphical image.</P>"
-		"<P>For example, <B>:-)</B> would be relaced by <icon name=\"psi/smile\"></P>"));
+		"<P>For example, <B>:-)</B> would be replaced by <icon name=\"psi/smile\"></P>"));
 
 	// TODO: add QWhatsThis
 
@@ -607,7 +606,7 @@ void OptionsTabIconsetEmoticons::cancelThread()
 //----------------------------------------------------------------------------
 
 OptionsTabIconsetRoster::OptionsTabIconsetRoster(QObject *parent)
-: OptionsTab(parent, "iconset_roster", "", tr("Roster Iconsets"), tr("Select iconsets for your roster"), "psi/www")
+: OptionsTab(parent, "iconset_roster", "", tr("Roster Icons"), tr("Select iconsets for your roster"))
 {
 	w = 0;
 	thread = 0;
