@@ -29,7 +29,8 @@ void OptionsTabLookFeelToolbars::applyOptions(Options *o)
 		//if ( toolbarPositionInProgress && posTbDlg->n() == (int)i )
 		//	continue;
 
-		mainWin->getLocation ( mainWin->toolbars.at(i), o->toolbars[i].dock, o->toolbars[i].index, o->toolbars[i].nl, o->toolbars[i].extraOffset );
+		Options::ToolbarPrefs &tbPref = o->toolbars["mainWin"][i];
+		mainWin->getLocation ( mainWin->toolbars.at(i), tbPref.dock, tbPref.index, tbPref.nl, tbPref.extraOffset );
 	}
 }
 
