@@ -19,7 +19,7 @@
 //----------------------------------------------------------------------------
 
 OptionsTabStatus::OptionsTabStatus(QObject *parent)
-: OptionsTab(parent, "status", "", tr("Status"), tr("Status preferences"), "status/online")
+: OptionsTab(parent, "status", "", tr("Status"), tr("Status preferences"), "psi/status")
 {
 	w = 0;
 	o = new Options;
