@@ -225,7 +225,6 @@ ToolbarDlg::ToolbarDlg(PsiCon *_psi, QWidget *parent, const char *name)
 	IconButton *pb_ok = new IconButton( this );
 	hbox->addWidget( pb_ok );
 	pb_ok->setText( tr("&OK") );
-	pb_ok->setIcon( "psi/ok" );
 	connect(pb_ok, SIGNAL(clicked()), SLOT(doApply()));
 	connect(pb_ok, SIGNAL(clicked()), SLOT(accept()));
 
@@ -239,7 +238,6 @@ ToolbarDlg::ToolbarDlg(PsiCon *_psi, QWidget *parent, const char *name)
 	IconButton *pb_cancel = new IconButton( this );
 	hbox->addWidget( pb_cancel );
 	pb_cancel->setText( tr("&Cancel") );
-	pb_cancel->setIcon( "psi/cancel" );
 	connect(pb_cancel, SIGNAL(clicked()), SLOT(reject()));
 
 	restoreOptions( &option );
@@ -317,6 +315,7 @@ void ToolbarDlg::restoreOptions(const Options *o)
 
 	LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
 	opt->toolbars = o->toolbars;
+	opt->hideMenubar = o->hideMenubar;
 
 	rebuildToolbarList();
 
@@ -666,21 +665,21 @@ void ToolbarDlg::toolbarPositionApply()
 
 void ToolbarDlg::doApply()
 {
-	int count = 0;
-	QValueList<Options::ToolbarPrefs>::Iterator it = opt->toolbars["mainWin"].begin();
-	for ( ; it != opt->toolbars["mainWin"].end(); ++it) {
-		if ( (*it).on )
-			count++;
+	// Check if all toolbars are disabled
+	bool toolbarsVisible = false;
+	QValueList<Options::ToolbarPrefs>::ConstIterator it = opt->toolbars["mainWin"].begin();
+	for ( ; it != opt->toolbars["mainWin"].end() && !toolbarsVisible; ++it) {
+		toolbarsVisible = toolbarsVisible || (*it).on;
 	}
 
 	// Undar MacOS, we have the toolbar in a menu anyway
 #ifndef Q_WS_MAC
-	if ( !count ) {
+	if ( !toolbarsVisible && opt->hideMenubar) {
 		QMessageBox::warning(this, tr("Warning"),
-				     tr("You can not disable <i>all</i> toolbars. If you do so, you will be unable to enable them back, when you'll change your mind.\n"
-					"<br><br>\n"
-					"If you really-really want to disable all toolbars, you need to edit the config.xml file by hand."),
-				     tr("I understand"));
+			tr("You can not disable <i>all</i> toolbars <i>and</i> the menubar. If you do so, you will be unable to enable them back, when you'll change your mind.\n"
+				"<br><br>\n"
+				"If you really-really want to disable all toolbars and the menubar, you need to edit the config.xml file by hand."),
+			tr("OK"));
 		return;
 	}
 #endif
