@@ -30,6 +30,7 @@
 #include"contactview.h"
 #include"xmpp_xmlcommon.h"
 #include"fancylabel.h"
+#include"advwidget.h"
 
 using namespace XMPP;
 using namespace XMLHelper;
@@ -64,8 +65,6 @@ void UserAccount::reset()
 	opt_log = TRUE;
 	opt_reconn = FALSE;
 	opt_ignoreSSLWarnings = false;
-	opt_passphrase = false;
-	pgpPassphrase = "";
 	pgpSecretKeyID = "";
 
 	proxy_index = 0;
@@ -117,9 +116,6 @@ QDomElement UserAccount::toXml(QDomDocument &doc, const QString &tagName)
 	a.appendChild(textTag(doc, "OLR", olr_string));
 	a.appendChild(textTag(doc, "pgpSecretKeyID", pgpSecretKeyID));
 
-	if(opt_passphrase)
-		a.appendChild(textTag(doc, "pgpPassphrase", encodePassword(pgpPassphrase, jid) ));
-
 	QDomElement r = doc.createElement("roster");
 	a.appendChild(r);
 	Roster::ConstIterator rit = roster.begin();
@@ -245,11 +241,9 @@ void UserAccount::fromXml(const QDomElement &a)
 
 	// read password (we must do this after reading the jid, to decode properly)
 	readEntry(a, "password", &pass);
-	if(pass.isEmpty())
-		opt_pass = FALSE;
-	else {
-		pass = decodePassword(pass, jid);
+	if(!pass.isEmpty()) {
 		opt_pass = TRUE;
+		pass = decodePassword(pass, jid);
 	}
 
 	readEntry(a, "resource", &resource);
@@ -257,14 +251,6 @@ void UserAccount::fromXml(const QDomElement &a)
 	readEntry(a, "OLR", &olr_string);
 	readEntry(a, "pgpSecretKeyID", &pgpSecretKeyID);
 
-	QDomElement pp = findSubTag(a, "pgpPassphrase", &found);
-	if(found) {
-		opt_passphrase = true;
-		pgpPassphrase = decodePassword(tagContent(pp), jid);
-	}
-	else
-		opt_passphrase = false;
-
 	QDomElement r = findSubTag(a, "roster", &found);
 	if(found) {
 		for(QDomNode n = r.firstChild(); !n.isNull(); n = n.nextSibling()) {
@@ -348,13 +334,14 @@ void UserProfile::reset()
 	// prefs
 	prefs.useleft = FALSE;
 	prefs.singleclick = FALSE;
+ 	prefs.hideMenubar = TRUE;
 	prefs.defaultAction = 1;
 	prefs.delChats = dcHour;
 	prefs.showJoins = TRUE;
 	prefs.browser = 0;
 	prefs.customBrowser = "";
 	prefs.customMailer = "";
-	prefs.alwaysOnTop = win ? TRUE : FALSE;
+	prefs.alwaysOnTop = FALSE;
 	prefs.keepSizes = TRUE;
 	prefs.ignoreHeadline = FALSE;
 	prefs.ignoreNonRoster = FALSE;
@@ -396,6 +383,16 @@ void UserProfile::reset()
 	prefs.chatSoftReturn = true;
 	prefs.showGroupCounts = true;
 	prefs.smallChats = false;
+	prefs.chatLineEdit = true;
+	prefs.useTabs = false;
+	prefs.usePerTabCloseButton = true;
+	prefs.putTabsAtBottom = false;
+	prefs.autoRosterSize = false;
+	prefs.autoRosterSizeGrowTop = false;
+	prefs.autoResolveNicksOnAdd = false;
+	prefs.chatBgImage = "";
+	prefs.rosterBgImage = "";
+	prefs.autoCopy = false;
 
 	prefs.sp.clear();
 	prefs.sp.set(QObject::tr("Away from desk"), QObject::tr("I am away from my desk.  Leave a message."));
@@ -410,27 +407,17 @@ void UserProfile::reset()
 	prefs.sp.set(QObject::tr("Greece"), QObject::tr("I have gone to a far away place.  I will be back someday!"));
 	prefs.recentStatus.clear();
 
-#ifdef Q_WS_MAC
-	prefs.color[cOnline]    = QColor("#31549F");
-	prefs.color[cListBack]  = QColor("#F0F0F0");
-	prefs.color[cAway]      = QColor("#3A8268");
-	prefs.color[cDND]       = QColor("#800000");
-	prefs.color[cOffline]   = QColor("#000000");
-	prefs.color[cGroupFore] = QColor("#000000");
-	prefs.color[cGroupBack] = QColor("#9CBCFE");
-	prefs.color[cAnimFront] = QColor("#FF0000");
-	prefs.color[cAnimBack] 	= QColor("#000000");
-#else
-	prefs.color[cOnline]    = QColor("#0060C0");
-	prefs.color[cListBack]  = QColor("#C0C0C0");
-	prefs.color[cAway]      = QColor("#008080");
-	prefs.color[cDND]       = QColor("#800000");
-	prefs.color[cOffline]   = QColor("#000000");
-	prefs.color[cGroupFore] = QColor("#000000");
-	prefs.color[cGroupBack] = QColor("#FFFFFF");
-	prefs.color[cAnimFront] = QColor("#FF0000");
-	prefs.color[cAnimBack] 	= QColor("#000000");
-#endif
+	prefs.color[cOnline]    = QColor("#000000");
+	prefs.color[cListBack]  = QColor("#FFFFFF");
+	prefs.color[cAway]      = QColor("#004BB4");
+	prefs.color[cDND]       = QColor("#7E0000");
+	prefs.color[cOffline]   = QColor("#646464");
+	prefs.color[cProfileFore] = QColor("#FFFFFF");
+	prefs.color[cProfileBack] = QColor("#969696");
+	prefs.color[cGroupFore] = QColor("#5A5A5A");
+	prefs.color[cGroupBack] = QColor("#F0F0F0");
+	prefs.color[cAnimFront] = QColor("#000000");
+	prefs.color[cAnimBack] 	= QColor("#969696");
 
 	prefs.font[fRoster] = QApplication::font().toString();
 	prefs.font[fMessage] = QApplication::font().toString();
@@ -449,7 +436,10 @@ void UserProfile::reset()
 		prefs.smallFontSize = minimumFontSize;
 	FancyLabel::setSmallFontSize( prefs.smallFontSize );
 
-	prefs.clNewHeadings = true;
+	prefs.clNewHeadings = false;
+	prefs.chatOpacity = 100;
+	prefs.rosterOpacity = 95;
+	prefs.outlineHeadings = false;
 
 	prefs.player = "play";
 	prefs.noAwaySound = FALSE;
@@ -470,6 +460,7 @@ void UserProfile::reset()
 
 	prefs.sizeEventDlg = EventDlg::defaultSize();
 	prefs.sizeChatDlg = ChatDlg::defaultSize();
+	prefs.sizeTabDlg = ChatDlg::defaultSize(); //TODO: no!
 
 	prefs.jidComplete = true;
 	prefs.grabUrls = false;
@@ -500,7 +491,7 @@ void UserProfile::reset()
 			tb[i] = tbDef;
 			tb[i].index = i + 1;
 		}
-		
+
 		bool defaultEnableToolbars;
 #ifdef Q_WS_MAC
 		defaultEnableToolbars = false;
@@ -561,6 +552,9 @@ void UserProfile::reset()
 	prefs.ppHideTime    = 10000; // 10 sec
 	prefs.ppBorderColor = QColor (0x52, 0x97, 0xF9);
 
+	// Bouncing of the dock (Mac OS X)
+	prefs.bounceDock = Options::BounceForever;
+
 	// lockdown
 	prefs.lockdown.roster   = false;
 	prefs.lockdown.options  = false;
@@ -576,13 +570,13 @@ void UserProfile::reset()
 	prefs.defaultRosterIconset = "default";
 
 	prefs.serviceRosterIconset.clear();
-	prefs.serviceRosterIconset["transport"]	= "transport";
-	prefs.serviceRosterIconset["aim"]	= "aim";
-	prefs.serviceRosterIconset["gadugadu"]	= "gadugadu";
-	prefs.serviceRosterIconset["icq"]	= "icq";
-	prefs.serviceRosterIconset["msn"]	= "msn";
-	prefs.serviceRosterIconset["yahoo"]	= "yahoo";
-	prefs.serviceRosterIconset["sms"]	= "sms";
+	prefs.serviceRosterIconset["transport"]	= "crystal-service.jisp";
+	prefs.serviceRosterIconset["aim"]	= "crystal-aim.jisp";
+	prefs.serviceRosterIconset["gadugadu"]	= "crystal-gadugadu.jisp";
+	prefs.serviceRosterIconset["icq"]	= "crystal-icq.jisp";
+	prefs.serviceRosterIconset["msn"]	= "crystal-msn.jisp";
+	prefs.serviceRosterIconset["yahoo"]	= "crystal-yahoo.jisp";
+	prefs.serviceRosterIconset["sms"]	= "crystal-sms.jisp";
 
 	prefs.customRosterIconset.clear();
 
@@ -601,7 +595,10 @@ void UserProfile::reset()
 
 	// auto-auth
 	prefs.autoAuth = false;
-	
+
+	// Notify authorization
+	prefs.notifyAuth = true;
+
 	// message events
 	prefs.messageEvents = true;
 
@@ -612,14 +609,28 @@ void UserProfile::reset()
 	prefs.eventPriorityAuth     = 2;
 	prefs.eventPriorityFile     = 3;
 
+	// Last used path remembering
+	prefs.lastPath = QDir::homeDirPath();
+	prefs.lastSavePath = QDir::homeDirPath();
+
 	// data transfer
 	prefs.dtPort = 8010;
 	prefs.dtExternal = "";
 
 	// Avatars
-	//prefs.avatarsEnabled = true;
-	//prefs.avatarsChatdlgEnabled = true;
-	//prefs.avatarsSize = 48;
+	prefs.avatarsEnabled = true;
+	prefs.avatarsChatdlgEnabled = true;
+	prefs.avatarsSize = 48;
+
+	// global accelerators
+	prefs.globalAccels.clear();
+	prefs.globalAccels.append(QKeySequence()); // process next event
+	prefs.globalAccels.append(QKeySequence()); // show/hide roster
+
+	// advanced widget
+	GAdvancedWidget::setStickEnabled( false ); //until this is bugless
+	GAdvancedWidget::setStickToWindows( false ); //again
+	GAdvancedWidget::setStickAt( 5 );
 }
 
 static Options::ToolbarPrefs loadToolbarData( const QDomElement &e )
@@ -708,7 +719,9 @@ bool UserProfile::toFile(const QString &fname)
 			p_general.appendChild(p_roster);
 
 			p_roster.appendChild(textTag(doc, "useleft", prefs.useleft));
+			p_roster.appendChild(textTag(doc, "rosterBgImage", prefs.rosterBgImage));
 			p_roster.appendChild(textTag(doc, "singleclick", prefs.singleclick));
+			p_roster.appendChild(textTag(doc, "hideMenubar", prefs.hideMenubar));
 			p_roster.appendChild(textTag(doc, "defaultAction", prefs.defaultAction));
 			p_roster.appendChild(textTag(doc, "useTransportIconsForContacts", prefs.useTransportIconsForContacts));
 
@@ -734,18 +747,26 @@ bool UserProfile::toFile(const QString &fname)
 		}
 
 		// Avatars
-		//{
-			//QDomElement p_avatars = doc.createElement("avatars");
-			//p_general.appendChild(p_avatars);
-			//p_avatars.appendChild(textTag(doc, "use", prefs.avatarsEnabled));
-			//p_avatars.appendChild(textTag(doc, "use_chatdlg", prefs.avatarsChatdlgEnabled));
-			//p_avatars.appendChild(textTag(doc, "size", prefs.avatarsSize));
-		//}
+		{
+			QDomElement p_avatars = doc.createElement("avatars");
+			p_general.appendChild(p_avatars);
+			p_avatars.appendChild(textTag(doc, "use", prefs.avatarsEnabled));
+			p_avatars.appendChild(textTag(doc, "use_chatdlg", prefs.avatarsChatdlgEnabled));
+			p_avatars.appendChild(textTag(doc, "size", prefs.avatarsSize));
+		}
 		{
 			QDomElement p_misc = doc.createElement("misc");
 			p_general.appendChild(p_misc);
 
+			p_misc.appendChild(textTag(doc, "chatBgImage", prefs.chatBgImage));
 			p_misc.appendChild(textTag(doc, "smallChats", prefs.smallChats));
+			p_misc.appendChild(textTag(doc, "chatLineEdit", prefs.chatLineEdit));
+			p_misc.appendChild(textTag(doc, "useTabs", prefs.useTabs));
+			p_misc.appendChild(textTag(doc, "usePerTabCloseButton", prefs.usePerTabCloseButton));
+			p_misc.appendChild(textTag(doc, "putTabsAtBottom", prefs.putTabsAtBottom));
+			p_misc.appendChild(textTag(doc, "autoRosterSize", prefs.autoRosterSize));
+			p_misc.appendChild(textTag(doc, "autoRosterSizeGrowTop", prefs.autoRosterSizeGrowTop));
+			p_misc.appendChild(textTag(doc, "autoResolveNicksOnAdd", prefs.autoResolveNicksOnAdd));
 			p_misc.appendChild(textTag(doc, "delChats", prefs.delChats));
 			p_misc.appendChild(textTag(doc, "showJoins", prefs.showJoins));
 			p_misc.appendChild(textTag(doc, "browser", prefs.browser));
@@ -768,6 +789,9 @@ bool UserProfile::toFile(const QString &fname)
 			p_misc.appendChild(textTag(doc, "jidComplete", prefs.jidComplete));
 			p_misc.appendChild(textTag(doc, "grabUrls", prefs.grabUrls));
 			p_misc.appendChild(textTag(doc, "messageEvents", prefs.messageEvents));
+			p_misc.appendChild(textTag(doc, "lastPath", prefs.lastPath));
+			p_misc.appendChild(textTag(doc, "lastSavePath", prefs.lastSavePath));
+			p_misc.appendChild(textTag(doc, "autoCopy", prefs.autoCopy));
 		}
 		{
 			QDomElement p_dock = doc.createElement("dock");
@@ -801,7 +825,8 @@ bool UserProfile::toFile(const QString &fname)
 
 		p_events.appendChild(textTag(doc, "alertstyle", prefs.alertStyle));
 		p_events.appendChild(textTag(doc, "autoAuth", prefs.autoAuth));
-		
+		p_events.appendChild(textTag(doc, "notifyAuth", prefs.notifyAuth));
+
 
 		{
 			QDomElement p_receive = doc.createElement("receive");
@@ -877,6 +902,9 @@ bool UserProfile::toFile(const QString &fname)
 		p.appendChild(p_lnf);
 
 		p_lnf.appendChild(textTag(doc, "newHeadings", prefs.clNewHeadings));
+		p_lnf.appendChild(textTag(doc, "chat-opacity", prefs.chatOpacity));
+		p_lnf.appendChild(textTag(doc, "roster-opacity", prefs.rosterOpacity));
+		p_lnf.appendChild(textTag(doc, "outline-headings", prefs.outlineHeadings));
 
 		{
 			QDomElement tag = doc.createElement("colors");
@@ -887,6 +915,8 @@ bool UserProfile::toFile(const QString &fname)
 			tag.appendChild(textTag(doc, "away", prefs.color[cAway].name() ));
 			tag.appendChild(textTag(doc, "dnd", prefs.color[cDND].name() ));
 			tag.appendChild(textTag(doc, "offline", prefs.color[cOffline].name() ));
+			tag.appendChild(textTag(doc, "profilefore", prefs.color[cProfileFore].name() ));
+			tag.appendChild(textTag(doc, "profileback", prefs.color[cProfileBack].name() ));
 			tag.appendChild(textTag(doc, "groupfore", prefs.color[cGroupFore].name() ));
 			tag.appendChild(textTag(doc, "groupback", prefs.color[cGroupBack].name() ));
 			tag.appendChild(textTag(doc, "animfront", prefs.color[cAnimFront].name() ));
@@ -935,6 +965,7 @@ bool UserProfile::toFile(const QString &fname)
 
 		p_sizes.appendChild(textTag(doc, "eventdlg", prefs.sizeEventDlg));
 		p_sizes.appendChild(textTag(doc, "chatdlg", prefs.sizeChatDlg));
+		p_sizes.appendChild(textTag(doc, "tabdlg", prefs.sizeTabDlg));
 	}
 
 	{
@@ -1008,6 +1039,25 @@ bool UserProfile::toFile(const QString &fname)
 		pp.appendChild(textTag(doc, "hideTime", prefs.ppHideTime));
 		pp.appendChild(textTag(doc, "borderColor", prefs.ppBorderColor.name()));
 	}
+	
+	{
+		// Bouncing dock (on Mac OS X)
+		QDomElement dock = doc.createElement("dock");
+		p.appendChild(dock);
+		switch (prefs.bounceDock) {
+			case Options::NoBounce :
+				dock.setAttribute("bounce", "never");
+				break;
+			case Options::BounceOnce :
+				dock.setAttribute("bounce", "once");
+				break;
+			case Options::BounceForever :
+				dock.setAttribute("bounce", "forever");
+				break;
+			default:
+				break;
+		}
+	}
 
 	{
 		//group chat
@@ -1108,6 +1158,39 @@ bool UserProfile::toFile(const QString &fname)
 		p_dt.appendChild( textTag(doc, "external", prefs.dtExternal ) );
 	}
 
+	{
+		// global accelerators
+		QDomElement p_globalAccel = doc.createElement("globalAccel");
+		p.appendChild(p_globalAccel);
+
+		QStringList accelNames;
+		accelNames << "processNextEvent";
+		accelNames << "showHideRoster";
+
+		QStringList::Iterator it1 = accelNames.begin();
+		QValueList<QKeySequence>::iterator it2 = prefs.globalAccels.begin();
+
+		for ( ; it2 != prefs.globalAccels.end(); ++it1, ++it2 ) {
+			QDomElement item = doc.createElement("command");
+			p_globalAccel.appendChild(item);
+			item.setAttribute("type", *it1);
+			item.appendChild( doc.createTextNode(*it2) );
+		}
+	}
+
+	{
+		// advanced widget
+		QDomElement p_advWidget = doc.createElement("advancedWidget");
+		p.appendChild(p_advWidget);
+
+		QDomElement stick = doc.createElement("sticky");
+		p_advWidget.appendChild(stick);
+
+		setBoolAttribute(stick, "enabled", GAdvancedWidget::stickEnabled());
+		stick.appendChild( textTag(doc, "offset", GAdvancedWidget::stickAt()) );
+		stick.appendChild( textTag(doc, "stickToWindows", GAdvancedWidget::stickToWindows()) );
+	}
+
 	QFile f(fname);
 	if(!f.open(IO_WriteOnly))
 		return FALSE;
@@ -1211,8 +1294,10 @@ bool UserProfile::fromFile(const QString &fname)
 
 			QDomElement p_roster = findSubTag(p_general, "roster", &found);
 			if(found) {
+				readEntry(p_roster, "rosterBgImage", &prefs.rosterBgImage);
 				readBoolEntry(p_roster, "useleft", &prefs.useleft);
 				readBoolEntry(p_roster, "singleclick", &prefs.singleclick);
+				readBoolEntry(p_roster, "hideMenubar", &prefs.hideMenubar);
 				readNumEntry(p_roster, "defaultAction", &prefs.defaultAction);
 				readBoolEntry(p_roster, "useTransportIconsForContacts", &prefs.useTransportIconsForContacts);
 
@@ -1241,15 +1326,16 @@ bool UserProfile::fromFile(const QString &fname)
 			}
 
 			// Avatars
-			//QDomElement avTag = findSubTag(p_general, "avatars", &found);
-			//if(found) {
-			//	readBoolEntry(avTag, "use", &prefs.avatarsEnabled);
-			//	readBoolEntry(avTag, "use_chatdlg", &prefs.avatarsChatdlgEnabled);
-			//	readNumEntry(avTag, "size", &prefs.avatarsSize);
-			//}
+			QDomElement avTag = findSubTag(p_general, "avatars", &found);
+			if(found) {
+				readBoolEntry(avTag, "use", &prefs.avatarsEnabled);
+				readBoolEntry(avTag, "use_chatdlg", &prefs.avatarsChatdlgEnabled);
+				readNumEntry(avTag, "size", &prefs.avatarsSize);
+			}
 
 			QDomElement tag = findSubTag(p_general, "misc", &found);
 			if(found) {
+				readEntry(tag, "chatBgImage", &prefs.chatBgImage);
 				readNumEntry(tag, "delChats", &prefs.delChats);
 				readBoolEntry(tag, "showJoins", &prefs.showJoins);
 				readNumEntry(tag, "browser", &prefs.browser);
@@ -1272,7 +1358,17 @@ bool UserProfile::fromFile(const QString &fname)
 				readBoolEntry(tag, "jidComplete", &prefs.jidComplete);
 				readBoolEntry(tag, "grabUrls", &prefs.grabUrls);
 				readBoolEntry(tag, "smallChats", &prefs.smallChats);
+				readBoolEntry(tag, "chatLineEdit", &prefs.chatLineEdit);
+				readBoolEntry(tag, "useTabs", &prefs.useTabs);
+				readBoolEntry(tag, "usePerTabCloseButton", &prefs.usePerTabCloseButton);
+				readBoolEntry(tag, "putTabsAtBottom", &prefs.putTabsAtBottom);
+				readBoolEntry(tag, "autoRosterSize", &prefs.autoRosterSize);
+				readBoolEntry(tag, "autoRosterSizeGrowTop", &prefs.autoRosterSizeGrowTop);
+				readBoolEntry(tag, "autoResolveNicksOnAdd", &prefs.autoResolveNicksOnAdd);
 				readBoolEntry(tag, "messageEvents", &prefs.messageEvents);
+				readEntry(tag, "lastPath", &prefs.lastPath);
+				readEntry(tag, "lastSavePath", &prefs.lastSavePath);
+				readBoolEntry(tag, "autoCopy", &prefs.autoCopy);
 			}
 
 			tag = findSubTag(p_general, "dock", &found);
@@ -1302,6 +1398,7 @@ bool UserProfile::fromFile(const QString &fname)
 
 			readNumEntry(p_events, "alertstyle", &prefs.alertStyle);
 			readBoolEntry(p_events, "autoAuth", &prefs.autoAuth);
+			readBoolEntry(p_events, "notifyAuth", &prefs.notifyAuth);
 
 			QDomElement tag = findSubTag(p_events, "receive", &found);
 			if(found) {
@@ -1383,6 +1480,9 @@ bool UserProfile::fromFile(const QString &fname)
 			bool found;
 
 			readBoolEntry(p_lnf, "newHeadings", &prefs.clNewHeadings);
+			readBoolEntry(p_lnf, "outline-headings", &prefs.outlineHeadings);
+			readNumEntry(p_lnf, "chat-opacity", &prefs.chatOpacity);
+			readNumEntry(p_lnf, "roster-opacity", &prefs.rosterOpacity);
 
 			QDomElement tag = findSubTag(p_lnf, "colors", &found);
 			if(found) {
@@ -1393,6 +1493,8 @@ bool UserProfile::fromFile(const QString &fname)
 				readColorEntry(tag, "offline", &prefs.color[cOffline]);
 				readColorEntry(tag, "groupfore", &prefs.color[cGroupFore]);
 				readColorEntry(tag, "groupback", &prefs.color[cGroupBack]);
+				readColorEntry(tag, "profilefore", &prefs.color[cProfileFore]);
+				readColorEntry(tag, "profileback", &prefs.color[cProfileBack]);
 				readColorEntry(tag, "animfront", &prefs.color[cAnimFront]);
 				readColorEntry(tag, "animback", &prefs.color[cAnimBack]);
 			}
@@ -1433,6 +1535,7 @@ bool UserProfile::fromFile(const QString &fname)
 		if(found) {
 			readSizeEntry(p_sizes, "eventdlg", &prefs.sizeEventDlg);
 			readSizeEntry(p_sizes, "chatdlg", &prefs.sizeChatDlg);
+			readSizeEntry(p_sizes, "tabdlg", &prefs.sizeTabDlg);
 		}
 
 
@@ -1532,6 +1635,20 @@ bool UserProfile::fromFile(const QString &fname)
 			xmlToStringList(p_groupchat, "nickcolors", &prefs.gcNickColors);
 		}
 
+		// Bouncing dock icon (Mac OS X)
+		QDomElement p_dock = findSubTag(p, "dock", &found);
+		if(found) {
+			if (p_dock.attribute("bounce") == "once") {
+				prefs.bounceDock = Options::BounceOnce;
+			}
+			else if (p_dock.attribute("bounce") == "forever") {
+				prefs.bounceDock = Options::BounceForever;
+			}
+			else if (p_dock.attribute("bounce") == "never") {
+				prefs.bounceDock = Options::NoBounce;
+			}
+		}
+
 		QDomElement p_popup = findSubTag(p, "popups", &found);
 		if(found) {
 			readBoolEntry(p_popup, "on", &prefs.ppIsOn);
@@ -1624,6 +1741,41 @@ bool UserProfile::fromFile(const QString &fname)
 			readNumEntry(p_dt, "port", &prefs.dtPort);
 			readEntry(p_dt, "external", &prefs.dtExternal);
 		}
+
+		QDomElement p_globalAccel = findSubTag(p, "globalAccel", &found);
+		if (found) {
+			QMap<QString, int> accelNames;
+			accelNames["processNextEvent"] = 0;
+			accelNames["showHideRoster"] = 1;
+
+			for (QDomNode n = p_globalAccel.firstChild(); !n.isNull(); n = n.nextSibling()) {
+				QDomElement i = n.toElement();
+				if ( i.isNull() )
+					continue;
+
+				if ( i.tagName() == "command" && i.hasAttribute("type") ) {
+					int n = accelNames[i.attribute("type")];
+					prefs.globalAccels[n] = QKeySequence(i.text());
+				}
+			}
+		}
+
+		QDomElement p_advWidget = findSubTag(p, "advancedWidget", &found);
+		if (found) {
+			QDomElement stick = findSubTag(p_advWidget, "sticky", &found);
+			if (found) {
+				bool enabled, toWindows;
+				int  offs;
+
+				readBoolAttribute(stick, "enabled", &enabled);
+				readNumEntry(stick, "offset", &offs);
+				readBoolEntry(stick, "stickToWindows", &toWindows);
+
+				GAdvancedWidget::setStickEnabled( enabled );
+				GAdvancedWidget::setStickAt( offs );
+				GAdvancedWidget::setStickToWindows( toWindows );
+			}
+		}
 	}
 
 	return TRUE;
