@@ -1,12 +1,17 @@
 /*
  * psiaccount.h - handles a Psi account
- * Copyright (C) 2001, 2002  Justin Karneges
+ * Copyright (C) 2001-2005  Justin Karneges
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  *
+ * You can also redistribute and/or modify this program under the
+ * terms of the Psi License, specified in the accompanied COPYING
+ * file, as published by the Psi Project; either dated January 1st,
+ * 2005, or (at your option) any later version.
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -26,8 +31,9 @@
 #include<qdom.h>
 #include"xmpp.h"
 #include"openpgp.h"
-#include"contactview.h"
 #include"ui_pgpkey.h"
+#include"common.h"
+
 
 namespace XMPP
 {
@@ -56,7 +62,7 @@ class ChatDlg;
 class EDB;
 class QSSLCert;
 class QHostAddress;
-//class AvatarFactory;
+class AvatarFactory;
 
 class PGPKeyDlg : public PGPKeyUI
 {
@@ -146,10 +152,7 @@ public:
 	EventQueue *eventQueue() const;
 	EDB *edb() const;
 	PsiCon *psi() const;
-
-	// Avatars
-	//AvatarFactory *avatarFactory() const;
-
+	AvatarFactory *avatarFactory() const;
 	Status status() const;
 	void setStatusDirect(const Status &);
 	void setStatusActual(const Status &);
@@ -216,6 +219,7 @@ signals:
 	void nickChanged();
 	void pgpKeyChanged();
 	void encryptedMessageSent(int, bool);
+	void enabledChanged();
 
 public slots:
 	void setStatus(const Status &);
@@ -243,10 +247,9 @@ public slots:
 	void actionRename(const Jid &, const QString &);
 	void actionGroupRename(const QString &, const QString &);
 	void actionHistory(const Jid &);
-	void actionStatusShow(const Jid &);
 	void actionOpenChat(const Jid &);
 	void actionOpenChatSpecific(const Jid &);
-	void actionAgentSetStatus(const Jid &, int);
+	void actionAgentSetStatus(const Jid &, Status &s);
 	void actionInfo(const Jid &);
 	void actionAuth(const Jid &);
 	void actionAuthRequest(const Jid &);
@@ -284,6 +287,8 @@ private slots:
 	void cs_warning(int);
 	void cs_error(int);
 	void client_rosterRequestFinished(bool, int, const QString &);
+	void resolveContactName();
+	void client_rosterItemAdded(const RosterItem &);
 	void client_rosterItemUpdated(const RosterItem &);
 	void client_rosterItemRemoved(const RosterItem &);
 	void client_resourceAvailable(const Jid &, const Resource &);
@@ -361,6 +366,8 @@ private:
 
 	bool isDisconnecting, notifyOnlineOk, doReconnect, usingAutoStatus, rosterDone, presenceSent, v_isActive;
 	void cleanupStream();
+
+	friend class Private;
 };
 
 #endif
