@@ -44,6 +44,8 @@ public:
 
 signals:
 	void dockActivated();
+	void newTrayOwner();
+	void trayOwnerDied();
 
 private:
 	void init(bool GUIenabled);
