@@ -58,6 +58,14 @@
 #include"filetransfer.h"
 #include"filetransdlg.h"
 #include"psiactionlist.h"
+#include"systemwatch.h"
+#include"globalaccelman.h"
+#include "tabdlg.h"
+#include "chatdlg.h"
+
+#ifdef Q_WS_MAC
+#include "mac_dock.h"
+#endif
 
 //----------------------------------------------------------------------------
 // PsiIconFactory
@@ -291,6 +299,9 @@ class PsiCon::Private
 public:
 	Private() {
 		iconSelect = 0;
+		//the list 'owns' the tabs
+		tabs.setAutoDelete( true );
+		tabControlledChats.setAutoDelete( false );
 	}
 	~Private() {
 		if ( iconSelect )
@@ -327,6 +338,33 @@ public:
 		iconSelect->setIconset(iss);
 	}
 
+	PsiAccount *queueLowestEventId(bool includeDND)
+	{
+		PsiAccount *low = 0;
+		int low_id = 0;
+		int low_prior = option.EventPriorityDontCare;
+
+		PsiAccountListIt it(listEnabled);
+		for ( PsiAccount *pa; (pa = it.current()); ++it ) {
+			int n = pa->eventQueue()->nextId();
+			if ( n == -1 )
+				continue;
+
+			if ( !includeDND && pa->status().show() == "dnd" )
+				continue;
+
+			int p = pa->eventQueue()->peekNext()->priority();
+			if ( !low || (n < low_id && p == low_prior) || p > low_prior ) {
+				low = pa;
+				low_id = n;
+				low_prior = p;
+			}
+		}
+
+		return low;
+	}
+
+
 	PsiAccountList list;
 	PsiAccountList listEnabled;
 	UserProfile pro;
@@ -334,6 +372,8 @@ public:
 	MainWin *mainwin;
 	Idle idle;
 	QPtrList<item_dialog> dialogList;
+	QPtrList<TabDlg> tabs;
+	QPtrList<ChatDlg> tabControlledChats;
 	int eventId;
 	QStringList recentGCList, recentBrowseList, recentNodeList;
 	EDB *edb;
@@ -345,6 +385,7 @@ public:
 	QRect mwgeom;
 	FileTransDlg *ftwin;
 	PsiActionList *actionList;
+	GlobalAccelManager *globalAccelManager;
 };
 
 //----------------------------------------------------------------------------
@@ -488,6 +529,18 @@ bool PsiCon::init()
 	// load accounts
 	loadAccounts(d->pro.acc);
 
+	// Connect to the system monitor
+	SystemWatch* sw = SystemWatch::instance();
+	connect(sw, SIGNAL(sleep()), this, SLOT(doSleep()));
+	connect(sw, SIGNAL(idleSleep()), this, SLOT(doSleep()));
+	connect(sw, SIGNAL(wakeup()), this, SLOT(doWakeup()));
+
+	// global accelerator manager
+	d->globalAccelManager = new GlobalAccelManager;
+	d->globalAccelManager->setAccel(option.globalAccels[0]);
+	d->globalAccelManager->setAccel(option.globalAccels[1]);
+	connect(d->globalAccelManager, SIGNAL(activated(int)), SLOT(accel_activated(int)));
+
 	return true;
 }
 
@@ -538,6 +591,7 @@ PsiAccount *PsiCon::loadAccount(const UserAccount &acc)
 	connect(pa, SIGNAL(updatedActivity()), SLOT(pa_updatedActivity()));
 	connect(pa, SIGNAL(updatedAccount()), SLOT(pa_updatedAccount()));
 	connect(pa, SIGNAL(queueChanged()), SLOT(queueChanged()));
+	connect(pa, SIGNAL(enabledChanged()), SIGNAL(accountCountChanged()));
 	accountAdded(pa);
 	if(d->s5bServer)
 		pa->client()->s5bManager()->setServer(d->s5bServer);
@@ -712,6 +766,92 @@ QWidget *PsiCon::dialogFind(const char *className)
 	return 0;
 }
 
+TabDlg* PsiCon::newTabs()
+{
+	TabDlg *tab;
+	tab=new TabDlg(this);
+	d->tabs.append(tab);
+	connect (tab, SIGNAL ( isDying(TabDlg*) ), SLOT ( tabDying(TabDlg*) ) );
+	return tab;
+}
+
+TabDlg* PsiCon::getTabs()
+{
+	if (!d->tabs.isEmpty())
+	{
+		return d->tabs.getFirst();
+	}
+	else
+	{
+		return newTabs();
+	}
+}
+
+void PsiCon::tabDying(TabDlg* tab)
+{
+	d->tabs.remove(tab);
+}
+
+bool PsiCon::isChatTabbed(ChatDlg* chat)
+{
+	for (uint i = 0; i < d->tabs.count(); ++i)
+	{
+		if ( d->tabs.at(i)->managesChat(chat) )
+				return true;
+	}
+	return false;
+}
+
+ChatDlg* PsiCon::getChatInTabs(QString jid){
+	for (uint i = 0; i < d->tabs.count(); ++i)
+	{
+		if ( d->tabs.at(i)->getChatPointer(jid) )
+				return d->tabs.at(i)->getChatPointer(jid);
+	}
+	return NULL;
+
+}
+
+TabDlg* PsiCon::getManagingTabs(ChatDlg* chat)
+{
+	for (uint i = 0; i < d->tabs.count(); ++i)
+	{
+		if ( d->tabs.at(i)->managesChat(chat) )
+				return d->tabs.at(i);
+	}
+	return NULL;
+
+}
+
+QPtrList<TabDlg>* PsiCon::getTabSets()
+{
+	return &d->tabs;
+}
+
+bool PsiCon::isChatActiveWindow(ChatDlg* chat)
+{
+	//returns true if chat is on top of a tab pile
+	if ( chat->isHidden() )
+	{
+		return false;
+	}
+	if (!option.useTabs)
+	{
+		return chat->isActiveWindow();
+	}
+	for (uint i = 0; i < d->tabs.count(); ++i)
+	{
+		if ( d->tabs.at(i)->isActiveWindow() )
+		{
+			if ( d->tabs.at(i)->chatOnTop( chat ) )
+			{
+				return true;
+			}
+		}
+	}
+	return false;
+}
+
 void PsiCon::dialogRegister(QWidget *w)
 {
 	item_dialog *i = new item_dialog;
@@ -759,7 +899,7 @@ void PsiCon::createAccount(const QString &name, const Jid &j, const QString &pas
 	acc.name = name;
 
 	acc.jid = j.full();
-	if(!pass.isEmpty()) {
+	if(!pass.isEmpty()) { 
 		acc.opt_pass = true;
 		acc.pass = pass;
 	}
@@ -969,9 +1109,15 @@ void PsiCon::slotApplyOptions(const Options &opt)
 {
 	QString oldpgp = option.pgp;
 	Options oldOpt = option;
+	bool notifyRestart = true;
 
 	option = opt;
 
+	if ( option.useTabs != oldOpt.useTabs || opt.chatLineEdit != oldOpt.chatLineEdit ) {
+		QMessageBox::information(0, tr("Information"), tr("Some of the options you changed will only have full effect upon restart."));
+		notifyRestart = false;
+	}
+
 	// change icon set
 	if ( option.systemIconset		!= oldOpt.systemIconset		||
 	     option.emoticons			!= oldOpt.emoticons		||
@@ -979,7 +1125,7 @@ void PsiCon::slotApplyOptions(const Options &opt)
 	     option.serviceRosterIconset	!= oldOpt.serviceRosterIconset	||
 	     option.customRosterIconset		!= oldOpt.customRosterIconset )
 	{
-		if ( is->optionsChanged(&oldOpt) )
+		if ( notifyRestart && is->optionsChanged(&oldOpt) )
 			QMessageBox::information(0, tr("Information"), tr("The complete iconset update will happen on next Psi start."));
 
 		// update icon selector
@@ -1039,22 +1185,12 @@ int PsiCon::queueCount()
 PsiAccount *PsiCon::queueLowestEventId()
 {
 	PsiAccount *low = 0;
-	int low_id = 0;
-	int low_prior = option.EventPriorityDontCare;
 
-	PsiAccountListIt it(d->listEnabled);
-	for(PsiAccount *pa; (pa = it.current()); ++it) {
-		int n = pa->eventQueue()->nextId();
-		if(n == -1)
-			continue;
+	low = d->queueLowestEventId( false ); // first try to get event from non-dnd account
 
-		int p = pa->eventQueue()->peekNext()->priority();
-		if(!low || (n < low_id && p == low_prior)|| p > low_prior ) {
-			low = pa;
-			low_id = n;
-			low_prior = p;
-		}
-	}
+	// if failed, then get the event from dnd account instead
+	if ( !low )
+		low = d->queueLowestEventId( true );
 
 	return low;
 }
@@ -1067,6 +1203,39 @@ void PsiCon::queueChanged()
 	if(pa)
 		nextAnim = is->event2icon(pa->eventQueue()->peekNext());
 
+#ifdef Q_WS_MAC
+	{
+		// The Mac Dock icon
+
+		// Update the event count
+		if (nextAmount) 
+			MacDock::overlay(QString::number(nextAmount));
+		else 
+			MacDock::overlay(QString::null);
+
+		// Check if bouncing is necessary
+		bool doBounce = false;
+		PsiAccountListIt it(d->listEnabled);
+		for(PsiAccount *pa; (pa = it.current()); ++it) {
+			if ( pa->eventQueue()->count() && pa->status().show() != "dnd" ) {
+				doBounce = true;
+				break;
+			}
+		}
+
+		// Bouncy bouncy
+		if (doBounce) {
+			if (option.bounceDock != Options::NoBounce) {
+				MacDock::startBounce();
+				if (option.bounceDock == Options::BounceOnce) 
+					MacDock::stopBounce();
+			}
+		}
+		else 
+			MacDock::stopBounce();
+	}
+#endif
+
 	d->mainwin->updateReadNext(nextAnim, nextAmount);
 }
 
@@ -1216,6 +1385,18 @@ void PsiCon::proxy_settingsChanged()
 	saveAccounts();
 }
 
+void PsiCon::accel_activated(int x)
+{
+	switch (x) {
+	case 1:
+		recvNextEvent();
+		break;
+	case 2:
+		d->mainwin->toggleVisible();
+		break;
+	}
+}
+
 MainWin *PsiCon::mainWin() const
 {
 	return d->mainwin;
@@ -1281,7 +1462,13 @@ void PsiCon::processEvent(PsiEvent *e)
 				return; // should never happen
 
 			e->account()->processChats(e->from()); // this will delete all events, corresponding to that chat dialog
+			//KIS: I changed the following line with the one following that to attempt to get tabs to behave correctly. Lots of this stuff isn't great.
 			bringToFront((QWidget *)c);
+			if ( option.useTabs)
+			{
+				TabDlg* tabSet = getManagingTabs(c);
+				tabSet->selectTab(c);
+			}
 		}
 		else
 			e->account()->openChat(e->from());
@@ -1365,11 +1552,25 @@ void PsiCon::s5b_init()
 	if(d->s5bServer->isActive())
 		d->s5bServer->stop();
 
-	if(!d->s5bServer->start(option.dtPort)) {
-		QMessageBox::information(0, tr("Error"), tr("Unable to bind to port %1 for Data Transfer").arg(option.dtPort));
+	if (option.dtPort) {
+		if(!d->s5bServer->start(option.dtPort)) {
+			QMessageBox::information(0, tr("Error"), tr("Unable to bind to port %1 for Data Transfer").arg(option.dtPort));
+		}
 	}
 }
 
+void PsiCon::doSleep()
+{
+	setGlobalStatus(Status("",tr("Computer went to sleep"),0,false));
+}
+
+void PsiCon::doWakeup()
+{
+	// TODO: Restore the status from before the log out. Make it an (hidden) option for people with a bad wireless connection.
+	//setGlobalStatus(Status());
+}
+
+
 QPtrList<PsiToolBar> *PsiCon::toolbarList() const
 {
 	QPtrList<PsiToolBar> *list = new QPtrList<PsiToolBar>();
