@@ -42,6 +42,8 @@ class IconSelectPopup;
 class QThread;
 class PsiActionList;
 class PsiToolBar;
+class	TabDlg;
+class ChatDlg;
 
 namespace OpenPGP
 {
@@ -92,6 +94,14 @@ public:
 	ProxyManager *proxy() const;
 	FileTransDlg *ftdlg() const;
 
+	TabDlg* getTabs();
+	TabDlg*	newTabs();
+	bool isChatTabbed(ChatDlg*);
+	bool isChatActiveWindow(ChatDlg*);
+	ChatDlg* getChatInTabs(QString);
+	TabDlg* getManagingTabs(ChatDlg*);
+	QPtrList<TabDlg>* getTabSets();
+
 	QWidget *dialogFind(const char *className);
 	void dialogRegister(QWidget *w);
 	void dialogUnregister(QWidget *w);
@@ -146,6 +156,8 @@ public slots:
 	QWidget *doToolbars();
 
 private slots:
+	void doSleep();
+	void doWakeup();
 	void closeProgram();
 	void changeProfile();
 	void doManageAccounts();
@@ -163,7 +175,9 @@ private slots:
 	void pgp_initFinished(bool, const QString &);
 	void pgp_keysUpdated();
 	void proxy_settingsChanged();
+	void accel_activated(int);
 	void updateMainwinStatus();
+	void tabDying(TabDlg*);
 
 	void mainWinGeomChanged(int x, int y, int w, int h);
 
