@@ -138,7 +138,7 @@ void PsiEvent::setTimeStamp(const QDateTime &t)
 	v_ts = t;
 }
 
-QDomElement *PsiEvent::toXml(QDomDocument *doc) const
+QDomElement PsiEvent::toXml(QDomDocument *doc) const
 {
 	QDomElement e = doc->createElement("event");
 	e.setAttribute("type", className());
@@ -152,11 +152,10 @@ QDomElement *PsiEvent::toXml(QDomDocument *doc) const
 	if ( v_account )
 		e.appendChild( textTag(*doc, "account",	v_account->name()) );
 
-	QDomElement *ret = new QDomElement(e);
-	return ret;
+	return e;
 }
 
-bool PsiEvent::fromXml(PsiCon *psi, const QDomElement *e)
+bool PsiEvent::fromXml(PsiCon *psi, PsiAccount *account, const QDomElement *e)
 {
 	if ( e->tagName() != "event" )
 		return false;
@@ -168,7 +167,10 @@ bool PsiEvent::fromXml(PsiCon *psi, const QDomElement *e)
 	v_ts  = QDateTime::fromString(subTagText(*e, "ts"), ISODate);
 	v_jid = Jid( subTagText(*e, "jid") );
 
-	if ( hasSubTag(*e, "account") ) {
+	if ( account ) {
+		v_account = account;
+	}
+	else if ( hasSubTag(*e, "account") ) {
 		PsiAccountList list = psi->accountList();
 		PsiAccountListIt it(list);
 		QString accName = subTagText(*e, "account");
@@ -188,6 +190,11 @@ int PsiEvent::priority() const
 	return Options::EventPriorityDontCare;
 }
 
+PsiEvent *PsiEvent::copy() const
+{
+	return 0;
+}
+
 //----------------------------------------------------------------------------
 // MessageEvent
 //----------------------------------------------------------------------------
@@ -251,22 +258,20 @@ void MessageEvent::setMessage(const XMPP::Message &m)
 	setLate ( v_m.spooled() );
 }
 
-QDomElement *MessageEvent::toXml(QDomDocument *doc) const
+QDomElement MessageEvent::toXml(QDomDocument *doc) const
 {
-	QDomElement *e = PsiEvent::toXml(doc);
-	if ( !e )
-		return 0;
+	QDomElement e = PsiEvent::toXml(doc);
 
 	DummyStream stream;
 	Stanza s = v_m.toStanza(&stream);
-	e->appendChild( s.element() );
+	e.appendChild( s.element() );
 
 	return e;
 }
 
-bool MessageEvent::fromXml(PsiCon *psi, const QDomElement *e)
+bool MessageEvent::fromXml(PsiCon *psi, PsiAccount *account, const QDomElement *e)
 {
-	if ( !PsiEvent::fromXml(psi, e) )
+	if ( !PsiEvent::fromXml(psi, account, e) )
 		return false;
 
 	bool found = false;
@@ -291,6 +296,11 @@ int MessageEvent::priority() const
 	return option.eventPriorityMessage;
 }
 
+PsiEvent *MessageEvent::copy() const
+{
+	return new MessageEvent( *this );
+}
+
 //----------------------------------------------------------------------------
 // AuthEvent
 //----------------------------------------------------------------------------
@@ -331,21 +341,19 @@ QString AuthEvent::authType() const
 	return v_at;
 }
 
-QDomElement *AuthEvent::toXml(QDomDocument *doc) const
+QDomElement AuthEvent::toXml(QDomDocument *doc) const
 {
-	QDomElement *e = PsiEvent::toXml(doc);
-	if ( !e )
-		return 0;
+	QDomElement e = PsiEvent::toXml(doc);
 
-	e->appendChild( textTag(*doc, "from",	 v_from.full()) );
-	e->appendChild( textTag(*doc, "authType", v_at) );
+	e.appendChild( textTag(*doc, "from",	 v_from.full()) );
+	e.appendChild( textTag(*doc, "authType", v_at) );
 
-	return 0;
+	return e;
 }
 
-bool AuthEvent::fromXml(PsiCon *psi, const QDomElement *e)
+bool AuthEvent::fromXml(PsiCon *psi, PsiAccount *account, const QDomElement *e)
 {
-	if ( !PsiEvent::fromXml(psi, e) )
+	if ( !PsiEvent::fromXml(psi, account, e) )
 		return false;
 
 	v_from = Jid( subTagText(*e, "from") );
@@ -359,6 +367,11 @@ int AuthEvent::priority() const
 	return option.eventPriorityAuth;
 }
 
+PsiEvent *AuthEvent::copy() const
+{
+	return new AuthEvent( *this );
+}
+
 //----------------------------------------------------------------------------
 // FileEvent
 //----------------------------------------------------------------------------
@@ -443,13 +456,15 @@ public:
 
 	QPtrList<EventItem> list;
 	PsiCon *psi;
+	PsiAccount *account;
 };
 
-EventQueue::EventQueue(PsiCon *psi)
+EventQueue::EventQueue(PsiAccount *account)
 {
 	d = new Private();
 
-	d->psi = psi;
+	d->account = account;
+	d->psi = account->psi();
 }
 
 EventQueue::EventQueue(const EventQueue &from)
@@ -679,7 +694,7 @@ EventQueue &EventQueue::operator= (const EventQueue &from)
 	return *this;
 }
 
-QDomElement *EventQueue::toXml(QDomDocument *doc) const
+QDomElement EventQueue::toXml(QDomDocument *doc) const
 {
 	QDomElement e = doc->createElement("eventQueue");
 	e.setAttribute("version", "1.0");
@@ -687,16 +702,11 @@ QDomElement *EventQueue::toXml(QDomDocument *doc) const
 
 	QPtrListIterator<EventItem> it(d->list);
 	for(EventItem *i; (i = it.current()); ++it) {
-		QDomElement *event = (*it)->event()->toXml(doc);
-
-		if ( event ) {
-			e.appendChild( *event );
-			delete event;
-		}
+		QDomElement event = (*it)->event()->toXml(doc);
+		e.appendChild( event );
 	}
 
-	QDomElement *ret = new QDomElement(e);
-	return ret;
+	return e;
 }
 
 bool EventQueue::fromXml(const QDomElement *q)
@@ -724,14 +734,14 @@ bool EventQueue::fromXml(const QDomElement *q)
 		QString eventType = e.attribute("type");
 		if ( eventType == "MessageEvent" ) {
 			event = new MessageEvent(0);
-			if ( !event->fromXml(d->psi, &e) ) {
+			if ( !event->fromXml(d->psi, d->account, &e) ) {
 				delete event;
 				event = 0;
 			}
 		}
 		else if ( eventType == "AuthEvent" ) {
 			event = new AuthEvent("", "", 0);
-			if ( !event->fromXml(d->psi, &e) ) {
+			if ( !event->fromXml(d->psi, d->account, &e) ) {
 				delete event;
 				event = 0;
 			}
@@ -748,10 +758,8 @@ bool EventQueue::toFile(const QString &fname)
 {
 	QDomDocument doc;
 
-	QDomElement *element = toXml(&doc);
-	if ( !element )
-		return FALSE;
-	doc.appendChild(*element);
+	QDomElement element = toXml(&doc);
+	doc.appendChild(element);
 
 	QFile f( fname );
 	if( !f.open(IO_WriteOnly) )
