@@ -436,7 +436,7 @@ void PsiPopup::show()
 	if ( !d->id.isEmpty() /*&& option.ppNoDupes*/ ) {
 		PsiPopup *pp = psiPopupList->first();
 		while ( pp ) {
-			if ( d->id == pp->id() ) {
+			if ( d->id == pp->id() && pp->popup() ) {
 				pp->popup()->restartHideTimer();
 
 				d->display = false;
@@ -447,10 +447,6 @@ void PsiPopup::show()
 		}
 	}
 
-	// do not show popups when DND
-	if ( d->account->status().show() == "dnd" )
-		d->display = false;
-
 	if ( d->display ) {
 		psiPopupList->prepend( this );
 		d->popup->show();
