@@ -23,6 +23,11 @@
 
 #include <qtoolbar.h>
 
+#include "common.h"
+#include "psiactionlist.h"
+
+class PsiCon;
+
 class PsiToolBar : public QToolBar
 {
 	Q_OBJECT
@@ -30,8 +35,33 @@ class PsiToolBar : public QToolBar
 public:
 	PsiToolBar(const QString &label, QMainWindow *mainWindow, QWidget *parent, bool newLine = FALSE, const char *name = 0, WFlags f = 0);
 	PsiToolBar(QMainWindow *parent = 0, const char *name = 0);
+	~PsiToolBar();
 
+	void setPsiCon( PsiCon *psi );
+
+	PsiActionList::ActionsType type() const;
+	void setType( PsiActionList::ActionsType );
+	void initialize( Options::ToolbarPrefs &, bool createUniqueActions );
+
+	QString group() const;
+	int groupIndex() const;
+	void setGroup( QString group, int index );
+	
+	bool isCustomizeable() const;
+	void setCustomizeable( bool );
+
+	bool isMoveable() const;
+	void setMoveable( bool );
+	
+signals:
+	void registerAction( IconAction * );
+
+protected:
 	void contextMenuEvent(QContextMenuEvent *e);
+
+private:
+	class Private;
+	Private *d;
 };
 
 #endif
