@@ -40,187 +40,73 @@
 #include"common.h"
 #include"busywidget.h"
 #include"iconwidget.h"
+#include"xdata_widget.h"
+#include"xmpp_xdata.h"
+#include"xmpp_xmlcommon.h"
+
+using namespace XMLHelper;
+
 
 //----------------------------------------------------------------------------
-// ServicesDlg
+// JT_XRegister
 //----------------------------------------------------------------------------
-class ServicesDlg::Private
+
+class JT_XRegister : public JT_Register
 {
+	Q_OBJECT
 public:
-	Private() {}
+	JT_XRegister(Task *parent);
 
-	Jid jid;
-	PsiAccount *pa;
-	BusyWidget *busy;
-	JT_GetServices *jt_gs;
-	AgentList agents;
+	void setXForm(const Form &frm, const XData &_form);
+
+	bool take(const QDomElement &);
+	QDomElement iq() const;
+
+	void onGo();
+
+private:
+	QDomElement _iq;
 };
 
-ServicesDlg::ServicesDlg(const Jid &j, PsiAccount *pa)
-:ServicesUI(0, 0, false, WDestructiveClose)
+JT_XRegister::JT_XRegister( Task *parent )
+	: JT_Register( parent )
 {
-	d = new Private;
-	d->pa = pa;
-	d->jid = j;
-	d->pa->dialogRegister(this);
-	d->jt_gs = 0;
-
-	setCaption(CAP(tr("Manage Services")));
-	setIcon(is->transportStatus("transport", STATUS_ONLINE));
-
-	d->busy = new BusyWidget(this);
-	replaceWidget(lb_busywidget, d->busy);
-
-	cb_browse->setInsertionPolicy(QComboBox::NoInsertion);
-	cb_browse->insertStringList(d->pa->psi()->recentBrowseList());
-
-	connect(pb_close, SIGNAL(clicked()), SLOT(close()));
-	connect(pb_browse, SIGNAL(clicked()), SLOT(doBrowse()));
-	connect(cb_browse, SIGNAL(activated(const QString &)), SLOT(doBrowse(const QString &)));
-	connect(li_services, SIGNAL(highlighted(int)), SLOT(serviceSelected(int)));
-	connect(li_services, SIGNAL(doubleClicked(QListBoxItem *)), SLOT(doubleClicked(QListBoxItem *)));
-	connect(pb_register, SIGNAL(clicked()), SLOT(serviceRegister()));
-	connect(pb_search, SIGNAL(clicked()), SLOT(serviceSearch()));
-	connect(pb_join, SIGNAL(clicked()), SLOT(serviceJoin()));
-
-	pb_browse->setDefault(true);
-	cb_browse->setCurrentText(d->jid.full());
-
-	pb_register->setEnabled(false);
-	pb_search->setEnabled(false);
-	pb_join->setEnabled(false);
-	pb_join->hide();
-
-	cb_browse->setFocus();
-
-	if(d->pa->loggedIn())
-		doBrowse();
 }
 
-ServicesDlg::~ServicesDlg()
+bool JT_XRegister::take( const QDomElement &x )
 {
-	delete d->jt_gs;
-	d->pa->dialogUnregister(this);
-	delete d;
+	_iq = x;
+
+	return JT_Register::take( x );
 }
 
-void ServicesDlg::restoreWidgets()
+QDomElement JT_XRegister::iq() const
 {
-	pb_browse->setEnabled(true);
-	cb_browse->setEnabled(true);
-	li_services->setEnabled(true);
-	serviceSelected(li_services->currentItem());
+	return _iq;
 }
 
-void ServicesDlg::doBrowse(const QString &host)
+void JT_XRegister::setXForm(const Form &frm, const XData &_form)
 {
-	if(!d->pa->checkConnected(this))
-		return;
+	JT_Register::setForm( frm );
 
-	Jid j;
-	if(!host.isEmpty())
-		j = host;
+	_iq = createIQ(doc(), "set", frm.jid().full(), id());
+	QDomElement query = doc()->createElement("query");
+	query.setAttribute("xmlns", "jabber:iq:register");
+	_iq.appendChild(query);
+
+	XData form( _form );
+	form.setType( XData::Data_Submit );
+	query.appendChild( form.toXml( doc() ) );
+}
+
+void JT_XRegister::onGo()
+{
+	if ( !_iq.isNull() )
+		send( _iq );
 	else
-		j = cb_browse->currentText();
-
-	if(!j.isValid())
-		return;
-	d->jid = j;
-	d->pa->psi()->recentBrowseAdd(d->jid.full());
-	cb_browse->clear();
-	cb_browse->insertStringList(d->pa->psi()->recentBrowseList());
-
-	li_services->clear();
-	d->agents.clear();
-	d->busy->start();
-
-	pb_browse->setEnabled(false);
-	cb_browse->setEnabled(false);
-	pb_register->setEnabled(false);
-	pb_search->setEnabled(false);
-	pb_join->setEnabled(false);
-
-	d->jt_gs = new JT_GetServices(d->pa->client()->rootTask());
-	connect(d->jt_gs, SIGNAL(finished()), SLOT(jt_gs_finished()));
-	d->jt_gs->get(d->jid);
-	d->jt_gs->go(true);
+		JT_Register::onGo();
 }
 
-void ServicesDlg::jt_gs_finished()
-{
-	d->busy->stop();
-	restoreWidgets();
-
-	JT_GetServices *jt = d->jt_gs;
-	d->jt_gs = 0;
-
-	if(jt->success()) {
-		const AgentList & agents = jt->agents();
-		for(AgentList::ConstIterator it = agents.begin(); it != agents.end(); ++it)
-			li_services->insertItem(is->status((*it).jid(), STATUS_ONLINE), (*it).name());
-		d->agents = agents;
-		if(li_services->count() > 0)
-			li_services->setSelected(0, true);
-	}
-	else {
-		QMessageBox::critical(this, tr("Error"), tr("There was an error browsing the service list.\nReason: %1").arg(jt->statusString()));
-	}
-}
-
-void ServicesDlg::doubleClicked(QListBoxItem *)
-{
-	int x = li_services->currentItem();
-	if(x < 0 || x >= (int)d->agents.count())
-		return;
-	const Features &f = (*(d->agents.at(x))).features();
-	if(f.canGroupchat())
-		serviceJoin();
-	else if(f.canRegister())
-		serviceRegister();
-	else if(f.canSearch())
-		serviceSearch();
-}
-
-void ServicesDlg::serviceSelected(int x)
-{
-	if(x < 0 || x >= (int)d->agents.count())
-		return;
-
-	const Features &f = (*(d->agents.at(x))).features();
-
-	pb_register->setEnabled(f.canRegister());
-	pb_search->setEnabled(f.canRegister());
-	pb_join->setEnabled(f.canGroupchat());
-}
-
-void ServicesDlg::serviceRegister()
-{
-	int x = li_services->currentItem();
-	if(x < 0 || x >= (int)d->agents.count())
-		return;
-	const AgentItem &a = *(d->agents.at(x));
-	signalRegister(a.jid());
-}
-
-void ServicesDlg::serviceSearch()
-{
-	int x = li_services->currentItem();
-	if(x < 0 || x >= (int)d->agents.count())
-		return;
-	const AgentItem &a = *(d->agents.at(x));
-	signalSearch(a.jid());
-}
-
-void ServicesDlg::serviceJoin()
-{
-	int x = li_services->currentItem();
-	if(x < 0 || x >= (int)d->agents.count())
-		return;
-	const AgentItem &a = *(d->agents.at(x));
-	signalJoin(a.jid());
-}
-
-
 //----------------------------------------------------------------------------
 // RegistrationDlg
 //----------------------------------------------------------------------------
@@ -233,7 +119,7 @@ public:
 	PsiAccount *pa;
 
 	QPushButton *pb_close, *pb_reg;
-	QGuardedPtr<JT_Register> jt;
+	QGuardedPtr<JT_XRegister> jt;
 	int type;
 	BusyWidget *busy;
 	QLabel *lb_top;
@@ -242,6 +128,7 @@ public:
 
 	QPtrList<QLabel> lb_field;
 	QPtrList<QLineEdit> le_field;
+	XDataWidget *xdata;
 };
 
 RegistrationDlg::RegistrationDlg(const Jid &jid, PsiAccount *pa)
@@ -252,6 +139,7 @@ RegistrationDlg::RegistrationDlg(const Jid &jid, PsiAccount *pa)
 	d->pa = pa;
 	d->pa->dialogRegister(this, d->jid);
 	d->jt = 0;
+	d->xdata = 0;
 
 	d->lb_field.setAutoDelete(true);
 	d->le_field.setAutoDelete(true);
@@ -321,7 +209,7 @@ void RegistrationDlg::doRegGet()
 	d->busy->start();
 
 	d->type = 0;
-	d->jt = new JT_Register(d->pa->client()->rootTask());
+	d->jt = new JT_XRegister(d->pa->client()->rootTask());
 	connect(d->jt, SIGNAL(finished()), SLOT(jt_finished()));
 	d->jt->getForm(d->jid);
 	d->jt->go(true);
@@ -332,16 +220,28 @@ void RegistrationDlg::doRegSet()
 	if(!d->pa->checkConnected(this))
 		return;
 
-	Form submitForm = d->form;
+	d->jt = new JT_XRegister(d->pa->client()->rootTask());
 
-	// import the changes back into the form.
-	// the QPtrList of QLineEdits should be in the same order
-	QPtrListIterator<QLineEdit> lit(d->le_field);
-	for(Form::Iterator it = submitForm.begin(); it != submitForm.end(); ++it) {
-		FormField &f = *it;
-		QLineEdit *le = lit.current();
-		f.setValue(le->text());
-		++lit;
+	if ( !d->xdata ) {
+		Form submitForm = d->form;
+
+		// import the changes back into the form.
+		// the QPtrList of QLineEdits should be in the same order
+		QPtrListIterator<QLineEdit> lit(d->le_field);
+		for(Form::Iterator it = submitForm.begin(); it != submitForm.end(); ++it) {
+			FormField &f = *it;
+			QLineEdit *le = lit.current();
+			f.setValue(le->text());
+			++lit;
+		}
+
+		d->jt->setForm(submitForm);
+	}
+	else {
+		XData form;
+		form.setFields( d->xdata->fields() );
+
+		d->jt->setXForm( d->form, form );
 	}
 
 	d->gr_form->setEnabled(false);
@@ -349,9 +249,7 @@ void RegistrationDlg::doRegSet()
 	d->busy->start();
 
 	d->type = 1;
-	d->jt = new JT_Register(d->pa->client()->rootTask());
 	connect(d->jt, SIGNAL(finished()), SLOT(jt_finished()));
-	d->jt->setForm(submitForm);
 	d->jt->go(true);
 }
 
@@ -360,40 +258,73 @@ void RegistrationDlg::jt_finished()
 	d->busy->stop();
 	d->gr_form->setEnabled(true);
 	d->pb_reg->setEnabled(true);
-	JT_Register *jt = d->jt;
+	JT_XRegister *jt = d->jt;
 	d->jt = 0;
 
 	if(jt->success()) {
 		if(d->type == 0) {
 			d->form = jt->form();
-			QString str = tr("<b>Registration for \"%1\":</b><br><br>").arg(d->jid.full());
-			str += plain2rich(d->form.instructions());
-			d->lb_top->setText(str);
-			d->lb_top->setFixedWidth(300);
 
-			for(Form::ConstIterator it = d->form.begin(); it != d->form.end(); ++it) {
-				const FormField &f = *it;
+			bool useXData = false;
+			{
+				QDomNode n = queryTag( jt->iq() ).firstChild();
+				for( ; !n.isNull(); n = n.nextSibling()) {
+					QDomElement i = n.toElement();
+					if(i.isNull())
+						continue;
 
-				QLabel *lb = new QLabel(f.fieldName(), d->gr_form);
-				QLineEdit *le = new QLineEdit(d->gr_form);
-				if(f.isSecret())
-					le->setEchoMode(QLineEdit::Password);
-				le->setText(f.value());
+					if( i.attribute( "xmlns" ) == "jabber:x:data" ) {
+						useXData = true;
 
-				d->lb_field.append(lb);
-				d->le_field.append(le);
+						XData form;
+						form.fromXml( i );
+
+						if ( !form.title().isEmpty() )
+							setCaption( form.title() );
+
+						QString str = tr("<b>Registration for \"%1\":</b><br><br>").arg(d->jid.full());
+						str += plain2rich( form.instructions() );
+						d->lb_top->setText(str);
+
+						d->xdata = new XDataWidget( d->gr_form );
+						d->xdata->setFields( form.fields() );
+
+						d->xdata->show();
+
+						break;
+					}
+				}
 			}
 
-			if (!d->le_field.isEmpty())
-				d->le_field.first()->setFocus();
+			if ( !useXData ) {
+				QString str = tr("<b>Registration for \"%1\":</b><br><br>").arg(d->jid.full());
+				str += plain2rich(d->form.instructions());
+				d->lb_top->setText(str);
+				d->lb_top->setFixedWidth(300);
+
+				for(Form::ConstIterator it = d->form.begin(); it != d->form.end(); ++it) {
+					const FormField &f = *it;
+
+					QLabel *lb = new QLabel(f.fieldName(), d->gr_form);
+					QLineEdit *le = new QLineEdit(d->gr_form);
+					if(f.isSecret())
+						le->setEchoMode(QLineEdit::Password);
+					le->setText(f.value());
+
+					d->lb_field.append(lb);
+					d->le_field.append(le);
+				}
+
+				if (!d->le_field.isEmpty())
+					d->le_field.first()->setFocus();
+			}
 
 			d->gr_form->show();
 			d->pb_reg->show();
+			show();
 
 			qApp->processEvents();
-			//QDesktopWidget *w = QApplication::desktop();
-			//setGeometry((w->width()/2)-(width()/2), (w->height()/2)-(height()/2), minimumWidth(), minimumHeight());
-			resize(minimumSize());
+			resize(sizeHint());
 		}
 		else {
 			closeDialogs(this);
@@ -414,6 +345,65 @@ void RegistrationDlg::jt_finished()
 	}
 }
 
+//----------------------------------------------------------------------------
+// JT_XSearch
+//----------------------------------------------------------------------------
+
+class JT_XSearch : public JT_Search
+{
+	Q_OBJECT
+public:
+	JT_XSearch(Task *parent);
+
+	void setForm(const Form &frm, const XData &_form);
+
+	bool take(const QDomElement &);
+	QDomElement iq() const;
+
+	void onGo();
+
+private:
+	QDomElement _iq;
+};
+
+JT_XSearch::JT_XSearch( Task *parent )
+	: JT_Search( parent )
+{
+}
+
+bool JT_XSearch::take( const QDomElement &x )
+{
+	_iq = x;
+
+	return JT_Search::take( x );
+}
+
+QDomElement JT_XSearch::iq() const
+{
+	return _iq;
+}
+
+void JT_XSearch::setForm(const Form &frm, const XData &_form)
+{
+	JT_Search::set( frm );
+
+	_iq = createIQ(doc(), "set", frm.jid().full(), id());
+	QDomElement query = doc()->createElement("query");
+	query.setAttribute("xmlns", "jabber:iq:search");
+	_iq.appendChild(query);
+
+	XData form( _form );
+	form.setType( XData::Data_Submit );
+	query.appendChild( form.toXml( doc() ) );
+}
+
+void JT_XSearch::onGo()
+{
+	if ( !_iq.isNull() )
+		send( _iq );
+	else
+		JT_Search::onGo();
+}
 
 //----------------------------------------------------------------------------
 // SearchDlg
@@ -427,12 +417,14 @@ public:
 	Jid jid;
 	Form form;
 	BusyWidget *busy;
-	QGuardedPtr<JT_Search> jt;
+	QGuardedPtr<JT_XSearch> jt;
 	QGrid *gr_form;
 	int type;
 
 	QPtrList<QLabel> lb_field;
 	QPtrList<QLineEdit> le_field;
+	XDataWidget *xdata;
+	XData xdata_form;
 };
 
 SearchDlg::SearchDlg(const Jid &jid, PsiAccount *pa)
@@ -443,6 +435,7 @@ SearchDlg::SearchDlg(const Jid &jid, PsiAccount *pa)
 	d->jid = jid;
 	d->pa->dialogRegister(this, d->jid);
 	d->jt = 0;
+	d->xdata = 0;
 
 	setCaption(caption().arg(d->jid.full()));
 
@@ -518,7 +511,7 @@ void SearchDlg::doSearchGet()
 	d->busy->start();
 
 	d->type = 0;
-	d->jt = new JT_Search(d->pa->client()->rootTask());
+	d->jt = new JT_XSearch(d->pa->client()->rootTask());
 	connect(d->jt, SIGNAL(finished()), SLOT(jt_finished()));
 	d->jt->get(d->jid);
 	d->jt->go(true);
@@ -532,16 +525,28 @@ void SearchDlg::doSearchSet()
 	if(!d->pa->checkConnected(this))
 		return;
 
-	Form submitForm = d->form;
+	d->jt = new JT_XSearch(d->pa->client()->rootTask());
 
-	// import the changes back into the form.
-	// the QPtrList of QLineEdits should be in the same order
-	QPtrListIterator<QLineEdit> lit(d->le_field);
-	for(Form::Iterator it = submitForm.begin(); it != submitForm.end(); ++it) {
-		FormField &f = *it;
-		QLineEdit *le = lit.current();
-		f.setValue(le->text());
-		++lit;
+	if ( !d->xdata ) {
+		Form submitForm = d->form;
+
+		// import the changes back into the form.
+		// the QPtrList of QLineEdits should be in the same order
+		QPtrListIterator<QLineEdit> lit(d->le_field);
+		for(Form::Iterator it = submitForm.begin(); it != submitForm.end(); ++it) {
+			FormField &f = *it;
+			QLineEdit *le = lit.current();
+			f.setValue(le->text());
+			++lit;
+		}
+
+		d->jt->set(submitForm);
+	}
+	else {
+		XData form;
+		form.setFields( d->xdata->fields() );
+
+		d->jt->setForm( d->form, form );
 	}
 
 	clear();
@@ -552,16 +557,14 @@ void SearchDlg::doSearchSet()
 	d->busy->start();
 
 	d->type = 1;
-	d->jt = new JT_Search(d->pa->client()->rootTask());
 	connect(d->jt, SIGNAL(finished()), SLOT(jt_finished()));
-	d->jt->set(submitForm);
 	d->jt->go(true);
 }
 
 void SearchDlg::jt_finished()
 {
 	d->busy->stop();
-	JT_Search *jt = d->jt;
+	JT_XSearch *jt = d->jt;
 	d->jt = 0;
 
 	if(d->type == 1) {
@@ -573,37 +576,112 @@ void SearchDlg::jt_finished()
 	if(jt->success()) {
 		if(d->type == 0) {
 			d->form = jt->form();
-			QString str = plain2rich(d->form.instructions());
-			lb_instructions->setText(str);
 
-			for(Form::ConstIterator it = d->form.begin(); it != d->form.end(); ++it) {
-				const FormField &f = *it;
+			bool useXData = false;
+			{
+				QDomNode n = queryTag( jt->iq() ).firstChild();
+				for( ; !n.isNull(); n = n.nextSibling()) {
+					QDomElement i = n.toElement();
+					if(i.isNull())
+						continue;
 
-				QLabel *lb = new QLabel(f.fieldName(), d->gr_form);
-				QLineEdit *le = new QLineEdit(d->gr_form);
-				if(f.isSecret())
-					le->setEchoMode(QLineEdit::Password);
-				le->setText(f.value());
+					if( i.attribute( "xmlns" ) == "jabber:x:data" ) {
+						useXData = true;
 
-				d->lb_field.append(lb);
-				d->le_field.append(le);
+						XData form;
+						form.fromXml( i );
 
-				connect(le, SIGNAL(returnPressed()), this, SLOT(doSearchSet()));
+						//if ( !form.title().isEmpty() )
+						//	setCaption( form.title() );
+
+						QString str = plain2rich( form.instructions() );
+						lb_instructions->setText(str);
+
+						d->xdata = new XDataWidget( d->gr_form );
+						d->xdata->setFields( form.fields() );
+
+						d->xdata->show();
+
+						break;
+					}
+				}
+			}
+
+			if ( !useXData ) {
+				QString str = plain2rich(d->form.instructions());
+				lb_instructions->setText(str);
+
+				for(Form::ConstIterator it = d->form.begin(); it != d->form.end(); ++it) {
+					const FormField &f = *it;
+
+					QLabel *lb = new QLabel(f.fieldName(), d->gr_form);
+					QLineEdit *le = new QLineEdit(d->gr_form);
+					if(f.isSecret())
+						le->setEchoMode(QLineEdit::Password);
+					le->setText(f.value());
+
+					d->lb_field.append(lb);
+					d->le_field.append(le);
+
+					connect(le, SIGNAL(returnPressed()), this, SLOT(doSearchSet()));
+				}
 			}
 
 			d->gr_form->show();
 			pb_search->setEnabled(true);
+			show();
+
+			qApp->processEvents();
+			resize(sizeHint());
 		}
 		else {
-			const QValueList<SearchResult> &list = jt->results();
-			if(list.isEmpty())
-				QMessageBox::information(this, tr("Search Results"), tr("Search returned 0 results."));
-			else {
-				for(QValueList<SearchResult>::ConstIterator it = list.begin(); it != list.end(); ++it) {
-					const SearchResult &r = *it;
-					addEntry(r.jid().full(), r.nick(), r.first(), r.last(), r.email());
+			if ( !d->xdata ) {
+				const QValueList<SearchResult> &list = jt->results();
+				if(list.isEmpty())
+					QMessageBox::information(this, tr("Search Results"), tr("Search returned 0 results."));
+				else {
+					for(QValueList<SearchResult>::ConstIterator it = list.begin(); it != list.end(); ++it) {
+						const SearchResult &r = *it;
+						addEntry(r.jid().full(), r.nick(), r.first(), r.last(), r.email());
+					}
 				}
 			}
+			else {
+				XData form;
+				QDomNode n = queryTag( jt->iq() ).firstChild();
+				for( ; !n.isNull(); n = n.nextSibling()) {
+					QDomElement i = n.toElement();
+					if(i.isNull())
+						continue;
+
+					if( i.attribute( "xmlns" ) == "jabber:x:data" ) {
+						form.fromXml( i );
+						break;
+					}
+				}
+
+				while ( lv_results->columns() )
+					lv_results->removeColumn( 0 );
+
+				QValueList<XData::ReportField>::ConstIterator it = form.report().begin();
+				for ( ; it != form.report().end(); ++it ) {
+					lv_results->addColumn( ( *it ).label );
+				}
+
+				QValueList<XData::ReportItem>::ConstIterator iit = form.reportItems().begin();
+				for ( ; iit != form.reportItems().end(); ++iit ) {
+					QListViewItem *lvi = new QListViewItem(lv_results);
+
+					int i = 0;
+					it = form.report().begin();
+					for ( ; it != form.report().end(); ++it ) {
+						QString name = ( *it ).name;
+						lvi->setText( i++, ( *iit )[name] );
+					}
+				}
+
+				d->xdata_form = form;
+			}
 		}
 	}
 	else {
@@ -669,16 +747,39 @@ void SearchDlg::selectionChanged()
 
 void SearchDlg::doAdd()
 {
-	int d = 0;
 	QListViewItem *i = lv_results->firstChild();
 	QString name;
 
 	if(!i)
 		return;
 
+	int jid;
+	int nick;
+	if ( !d->xdata ) {
+		jid  = 4;
+		nick = 0;
+	}
+	else {
+		jid = 0;
+		nick = 0;
+
+		int i = 0;
+		QValueList<XData::ReportField>::ConstIterator it = d->xdata_form.report().begin();
+		for ( ; it != d->xdata_form.report().end(); ++it, ++i ) {
+			QString name = ( *it ).name;
+			if ( name == "jid" )
+				jid = i;
+
+			if ( name == "nickname" || name == "nick" )
+				nick = i;
+		}
+	}
+
+	int d = 0;
+
 	if( i->isSelected() ) {
-		name = jidnick(i->text(4), i->text(0));
-		add(Jid(i->text(4)), i->text(0), QStringList(), true);
+		name = jidnick(i->text(jid), i->text(nick));
+		add(Jid(i->text(jid)), i->text(nick), QStringList(), true);
 		d++;
 	}
 
@@ -686,8 +787,8 @@ void SearchDlg::doAdd()
 		while( i->nextSibling() ) {
 			i = i->nextSibling();
 			if( i->isSelected() ) {
-				name = jidnick(i->text(4), i->text(0));
-				add(Jid(i->text(4)), i->text(0), QStringList(), true);
+				name = jidnick(i->text(jid), i->text(nick));
+				add(Jid(i->text(jid)), i->text(nick), QStringList(), true);
 				d++;
 			}
 		}
@@ -707,16 +808,34 @@ void SearchDlg::doInfo()
 	if(!i)
 		return;
 
+	int jid;
+	if ( !d->xdata ) {
+		jid  = 4;
+	}
+	else {
+		jid = 0;
+
+		int i = 0;
+		QValueList<XData::ReportField>::ConstIterator it = d->xdata_form.report().begin();
+		for ( ; it != d->xdata_form.report().end(); ++it, ++i ) {
+			QString name = ( *it ).name;
+			if ( name == "jid" )
+				jid = i;
+		}
+	}
+
 	if( i->isSelected() ) {
-		aInfo(Jid(i->text(4)));
+		aInfo(Jid(i->text(jid)));
 	}
 
 	if( i ) {
 		while( i->nextSibling() ) {
 			i = i->nextSibling();
 			if( i->isSelected() ) {
-				aInfo(Jid(i->text(4)));
+				aInfo(Jid(i->text(jid)));
 			}
 		}
 	}
 }
+
+#include "servicesdlg.moc"
