@@ -21,44 +21,15 @@
 #ifndef SERVICESDLG_H
 #define SERVICESDLG_H
 
-#include"ui_services.h"
 #include"ui_search.h"
 #include"xmpp.h"
 
+#include<qdialog.h>
+
 using namespace XMPP;
 
 class PsiAccount;
 
-class ServicesDlg : public ServicesUI
-{
-	Q_OBJECT
-public:
-	ServicesDlg(const Jid &, PsiAccount *);
-	~ServicesDlg();
-
-signals:
-	void signalRegister(const Jid &);
-	void signalSearch(const Jid &);
-	void signalJoin(const Jid &);
-
-public slots:
-	void doBrowse(const QString &host = "");
-
-private slots:
-	void jt_gs_finished();
-	void doubleClicked(QListBoxItem *i);
-	void serviceSelected(int);
-	void serviceRegister();
-	void serviceSearch();
-	void serviceJoin();
-
-private:
-	class Private;
-	Private *d;
-
-	void restoreWidgets();
-};
-
 class RegistrationDlg : public QDialog
 {
 	Q_OBJECT
