@@ -26,6 +26,8 @@
 #include<qvaluelist.h>
 #include"im.h"
 
+class AvatarFactory;
+
 class UserResource : public XMPP::Resource
 {
 public:
@@ -35,8 +37,11 @@ public:
 
 	void setResource(const XMPP::Resource &);
 
-	const QString & versionString() const;
-	void setVersionString(const QString &);
+	const QString& versionString() const;
+	const QString& clientVersion() const;
+	const QString& clientName() const;
+	const QString& clientOS() const;
+	void setClient(const QString& name, const QString& version, const QString& os);
 
 	const QString & publicKeyID() const;
 	int pgpVerifyStatus() const;
@@ -46,7 +51,7 @@ public:
 	void setSigTimestamp(const QDateTime &);
 
 private:
-	QString v_ver, v_keyID;
+	QString v_ver, v_clientName, v_clientVersion, v_clientOS, v_keyID;
 	int v_pgpVerifyStatus;
 	QDateTime sigts;
 };
@@ -89,6 +94,7 @@ public:
 	const QString & presenceError() const;
 	bool isSelf() const;
 	QString makeTip(bool trim = true, bool doLinkify = true) const;
+	QString makeBareTip(bool trim, bool doLinkify) const;
 	QString makeDesc() const;
 	bool isPrivate() const;
 
@@ -108,6 +114,9 @@ public:
 
 	const QString & publicKeyID() const;
 	void setPublicKeyID(const QString &);
+	
+	AvatarFactory* avatarFactory() const;
+	void setAvatarFactory(AvatarFactory* av);
 
 private:
 	int lastmsgtype;
@@ -119,6 +128,8 @@ private:
 	bool v_private;
 	QStringList secList;
 	QString v_keyID;
+	AvatarFactory* v_avatarFactory;
+
 };
 
 typedef QPtrListIterator<UserListItem> UserListIt;
