@@ -40,6 +40,9 @@ public:
 
 	// call this when you need to retrieve fresh vCard from server (and store it in cache afterwards)
 	static JT_VCard *getVCard(const Jid &, Task *rootTask, const QObject *, const char *slot, bool cacheVCard = true);
+
+	// Register for updates to vcard changes
+	static void registerVCardChanged(const QObject*, const char* slot);
 };
 
 #endif
